import { computed, h, defineAsyncComponent, defineComponent, ref, withCtx, unref, createVNode, isRef, openBlock, createBlock, Fragment, renderList, createCommentVNode, toDisplayString, useSSRContext } from 'vue';
import { l as createComponent, d as useRoute } from './server.mjs';
import { u as useFetch, e as endpoints } from './endpoints-CieCsF2j.mjs';
import { ssrRenderComponent, ssrRenderList, ssrInterpolate } from 'vue/server-renderer';
import { p as pitLib } from './pitLib-BR8GY8Gr.mjs';
import { c as useAlignProps, u as useAlign, d as useRouterLinkProps, a as useRouterLink } from '../_/use-router-link.mjs';
import { h as hSlot, b as hMergeSlot } from '../_/use-dark.mjs';
import { d as getNormalizedVNodes, Q as QIcon } from '../_/vm.mjs';
import { _ as __nuxt_component_0$1, Q as QSeparator } from '../_/use-timeout.mjs';
import { _ as __nuxt_component_3, a as __nuxt_component_4, b as __nuxt_component_6, c as __nuxt_component_7 } from '../_/QTabPanel.mjs';
import { _ as __nuxt_component_0$2 } from '../_/QMarkupTable.mjs';
import { _ as __nuxt_component_1$1 } from '../_/QSkeleton.mjs';
import '../runtime.mjs';
import 'node:http';
import 'node:https';
import 'fs';
import 'path';
import 'node:fs';
import 'node:url';
import 'unhead';
import '@unhead/shared';
import 'vue-router';
import './env-B2a7_Xo2.mjs';
import '../_/nuxt-storage.mjs';
import 'sweetalert2';
import '../_/QResizeObserver.mjs';
import '../_/use-tick.mjs';

const disabledValues = [ '', true ];

const __nuxt_component_0 = createComponent({
  name: 'QBreadcrumbs',

  props: {
    ...useAlignProps,

    separator: {
      type: String,
      default: '/'
    },
    separatorColor: String,

    activeColor: {
      type: String,
      default: 'primary'
    },

    gutter: {
      type: String,
      validator: v => [ 'none', 'xs', 'sm', 'md', 'lg', 'xl' ].includes(v),
      default: 'sm'
    }
  },

  setup (props, { slots }) {
    const alignClass = useAlign(props);

    const classes = computed(() =>
      `flex items-center ${ alignClass.value }${ props.gutter === 'none' ? '' : ` q-gutter-${ props.gutter }` }`
    );

    const sepClass = computed(() => (props.separatorColor ? ` text-${ props.separatorColor }` : ''));
    const activeClass = computed(() => ` text-${ props.activeColor }`);

    return () => {
      if (slots.default === void 0) return

      const vnodes = getNormalizedVNodes(
        hSlot(slots.default)
      );

      if (vnodes.length === 0) return

      let els = 1;

      const
        child = [],
        len = vnodes.filter(c => c.type !== void 0 && c.type.name === 'QBreadcrumbsEl').length,
        separator = slots.separator !== void 0
          ? slots.separator
          : () => props.separator;

      vnodes.forEach(comp => {
        if (comp.type !== void 0 && comp.type.name === 'QBreadcrumbsEl') {
          const middle = els < len;
          const disabled = comp.props !== null && disabledValues.includes(comp.props.disable);
          const cls = (middle === true ? '' : ' q-breadcrumbs--last')
            + (disabled !== true && middle === true ? activeClass.value : '');

          els++;

          child.push(
            h('div', {
              class: `flex items-center${ cls }`
            }, [ comp ])
          );

          if (middle === true) {
            child.push(
              h('div', {
                class: 'q-breadcrumbs__separator' + sepClass.value
              }, separator())
            );
          }
        }
        else {
          child.push(comp);
        }
      });

      return h('div', {
        class: 'q-breadcrumbs'
      }, [
        h('div', { class: classes.value }, child)
      ])
    }
  }
});

const __nuxt_component_1 = createComponent({
  name: 'QBreadcrumbsEl',

  props: {
    ...useRouterLinkProps,

    label: String,
    icon: String,

    tag: {
      type: String,
      default: 'span'
    }
  },

  emits: [ 'click' ],

  setup (props, { slots }) {
    const { linkTag, linkAttrs, linkClass, navigateOnClick } = useRouterLink();

    const data = computed(() => {
      return {
        class: 'q-breadcrumbs__el q-link '
          + 'flex inline items-center relative-position '
          + (props.disable !== true ? 'q-link--focusable' + linkClass.value : 'q-breadcrumbs__el--disable'),
        ...linkAttrs.value,
        onClick: navigateOnClick
      }
    });

    const iconClass = computed(() =>
      'q-breadcrumbs__el-icon'
      + (props.label !== void 0 ? ' q-breadcrumbs__el-icon--with-label' : '')
    );

    return () => {
      const child = [];

      props.icon !== void 0 && child.push(
        h(QIcon, {
          class: iconClass.value,
          name: props.icon
        })
      );

      props.label !== void 0 && child.push(props.label);

      return h(
        linkTag.value,
        { ...data.value },
        hMergeSlot(slots.default, child)
      )
    }
  }
});

const __nuxt_component_8_lazy = defineAsyncComponent(() => import('./create-ByyofMxv.mjs').then((c) => c.default || c));
const __nuxt_component_9_lazy = defineAsyncComponent(() => import('./list-CCnQ1Ddl.mjs').then((c) => c.default || c));
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  __ssrInlineRender: true,
  setup(__props) {
    var _a, _b, _c, _d;
    const target_date = ref("");
    const route = useRoute();
    const tab = ref("diet_plans");
    const { data: userResp, pending: loadingUsers } = useFetch(endpoints.user.list, {
      method: "post",
      headers: {
        Authorization: "Bearer " + ((_a = pitLib.auth.get()) == null ? void 0 : _a.token)
      },
      body: {
        _id: (_b = route.params) == null ? void 0 : _b._id
      }
    }, "$CBJF6byMhj");
    const { data: planMemrshipResp, pending: loadingplanMemrship } = useFetch(endpoints.plan.membership.list, {
      method: "post",
      headers: {
        Authorization: "Bearer " + ((_c = pitLib.auth.get()) == null ? void 0 : _c.token)
      },
      body: {
        _id: (_d = route.params) == null ? void 0 : _d.membership_id
      }
    }, "$POmxYrp6DL");
    return (_ctx, _push, _parent, _attrs) => {
      const _component_q_breadcrumbs = __nuxt_component_0;
      const _component_q_breadcrumbs_el = __nuxt_component_1;
      const _component_q_card = __nuxt_component_0$1;
      const _component_q_tabs = __nuxt_component_3;
      const _component_q_tab = __nuxt_component_4;
      const _component_q_separator = QSeparator;
      const _component_q_tab_panels = __nuxt_component_6;
      const _component_q_tab_panel = __nuxt_component_7;
      const _component_lazy_panel_user_membership_diet_plan_create = __nuxt_component_8_lazy;
      const _component_lazy_panel_user_membership_diet_plan_list = __nuxt_component_9_lazy;
      const _component_q_markup_table = __nuxt_component_0$2;
      const _component_q_skeleton = __nuxt_component_1$1;
      _push(`<!--[--><div class="row q-ma-lg"><div class="col">`);
      _push(ssrRenderComponent(_component_q_breadcrumbs, null, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          var _a2, _b2, _c2, _d2, _e, _f, _g, _h, _i, _j, _k, _l;
          if (_push2) {
            _push2(ssrRenderComponent(_component_q_breadcrumbs_el, {
              to: "/panel",
              label: "Home"
            }, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_breadcrumbs_el, {
              to: "/panel/user",
              label: "Users"
            }, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_breadcrumbs_el, {
              to: "/panel/user/" + ((_c2 = (_b2 = (_a2 = unref(userResp)) == null ? void 0 : _a2.data) == null ? void 0 : _b2.data[0]) == null ? void 0 : _c2._id),
              label: (_f = (_e = (_d2 = unref(userResp)) == null ? void 0 : _d2.data) == null ? void 0 : _e.data[0]) == null ? void 0 : _f.name
            }, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_breadcrumbs_el, { label: "Membership" }, null, _parent2, _scopeId));
          } else {
            return [
              createVNode(_component_q_breadcrumbs_el, {
                to: "/panel",
                label: "Home"
              }),
              createVNode(_component_q_breadcrumbs_el, {
                to: "/panel/user",
                label: "Users"
              }),
              createVNode(_component_q_breadcrumbs_el, {
                to: "/panel/user/" + ((_i = (_h = (_g = unref(userResp)) == null ? void 0 : _g.data) == null ? void 0 : _h.data[0]) == null ? void 0 : _i._id),
                label: (_l = (_k = (_j = unref(userResp)) == null ? void 0 : _j.data) == null ? void 0 : _k.data[0]) == null ? void 0 : _l.name
              }, null, 8, ["to", "label"]),
              createVNode(_component_q_breadcrumbs_el, { label: "Membership" })
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(`</div></div><div class="row q-pa-lg"><div class="col">`);
      _push(ssrRenderComponent(_component_q_card, null, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(ssrRenderComponent(_component_q_tabs, {
              modelValue: unref(tab),
              "onUpdate:modelValue": ($event) => isRef(tab) ? tab.value = $event : null,
              dense: "",
              class: "text-grey",
              "active-color": "primary",
              "indicator-color": "primary",
              align: "justify"
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(ssrRenderComponent(_component_q_tab, {
                    name: "diet_plans",
                    label: "Diet Plans",
                    icon: "fa fa-weight-scale"
                  }, null, _parent3, _scopeId2));
                  _push3(ssrRenderComponent(_component_q_tab, {
                    name: "meetings",
                    label: "Meeting Schedules",
                    icon: "fa fa-comments-dollar"
                  }, null, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode(_component_q_tab, {
                      name: "diet_plans",
                      label: "Diet Plans",
                      icon: "fa fa-weight-scale"
                    }),
                    createVNode(_component_q_tab, {
                      name: "meetings",
                      label: "Meeting Schedules",
                      icon: "fa fa-comments-dollar"
                    })
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_separator, null, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_tab_panels, {
              modelValue: unref(tab),
              "onUpdate:modelValue": ($event) => isRef(tab) ? tab.value = $event : null,
              animated: ""
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(ssrRenderComponent(_component_q_tab_panel, {
                    name: "diet_plans",
                    class: "q-pa-none"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(ssrRenderComponent(_component_lazy_panel_user_membership_diet_plan_create, {
                          membership_id: unref(route).params.membership_id,
                          target_date: unref(target_date)
                        }, null, _parent4, _scopeId3));
                        _push4(ssrRenderComponent(_component_lazy_panel_user_membership_diet_plan_list, {
                          membership_id: unref(route).params.membership_id,
                          onHandle_date_change: ($event) => target_date.value = $event
                        }, null, _parent4, _scopeId3));
                      } else {
                        return [
                          createVNode(_component_lazy_panel_user_membership_diet_plan_create, {
                            membership_id: unref(route).params.membership_id,
                            target_date: unref(target_date)
                          }, null, 8, ["membership_id", "target_date"]),
                          createVNode(_component_lazy_panel_user_membership_diet_plan_list, {
                            membership_id: unref(route).params.membership_id,
                            onHandle_date_change: ($event) => target_date.value = $event
                          }, null, 8, ["membership_id", "onHandle_date_change"])
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(ssrRenderComponent(_component_q_tab_panel, { name: "meetings" }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(ssrRenderComponent(_component_q_markup_table, null, {
                          default: withCtx((_4, _push5, _parent5, _scopeId4) => {
                            var _a2, _b2, _c2, _d2, _e, _f;
                            if (_push5) {
                              _push5(`<thead${_scopeId4}><tr class="bg-grey-5 text-white text-h5"${_scopeId4}><th class="text-left"${_scopeId4}> Schedule </th><th class="text-left"${_scopeId4}> Action </th></tr></thead><tbody${_scopeId4}>`);
                              if (unref(loadingplanMemrship)) {
                                _push5(`<!--[-->`);
                                ssrRenderList(5, (n) => {
                                  _push5(`<tr${_scopeId4}><td class="text-right"${_scopeId4}>`);
                                  _push5(ssrRenderComponent(_component_q_skeleton, {
                                    animation: "blink",
                                    type: "text"
                                  }, null, _parent5, _scopeId4));
                                  _push5(`</td><td class="text-right"${_scopeId4}>`);
                                  _push5(ssrRenderComponent(_component_q_skeleton, {
                                    animation: "blink",
                                    type: "text"
                                  }, null, _parent5, _scopeId4));
                                  _push5(`</td></tr>`);
                                });
                                _push5(`<!--]-->`);
                              } else {
                                _push5(`<!---->`);
                              }
                              if ((_a2 = unref(planMemrshipResp)) == null ? void 0 : _a2.status) {
                                _push5(`<!--[-->`);
                                ssrRenderList((_c2 = (_b2 = unref(planMemrshipResp)) == null ? void 0 : _b2.data) == null ? void 0 : _c2.data[0].calendar_schedule, (p) => {
                                  _push5(`<tr${_scopeId4}><td${_scopeId4}>${ssrInterpolate(new Date(p))}</td><td${_scopeId4}></td></tr>`);
                                });
                                _push5(`<!--]-->`);
                              } else {
                                _push5(`<!---->`);
                              }
                              _push5(`</tbody>`);
                            } else {
                              return [
                                createVNode("thead", null, [
                                  createVNode("tr", { class: "bg-grey-5 text-white text-h5" }, [
                                    createVNode("th", { class: "text-left" }, " Schedule "),
                                    createVNode("th", { class: "text-left" }, " Action ")
                                  ])
                                ]),
                                createVNode("tbody", null, [
                                  unref(loadingplanMemrship) ? (openBlock(), createBlock(Fragment, { key: 0 }, renderList(5, (n) => {
                                    return createVNode("tr", { key: n }, [
                                      createVNode("td", { class: "text-right" }, [
                                        createVNode(_component_q_skeleton, {
                                          animation: "blink",
                                          type: "text"
                                        })
                                      ]),
                                      createVNode("td", { class: "text-right" }, [
                                        createVNode(_component_q_skeleton, {
                                          animation: "blink",
                                          type: "text"
                                        })
                                      ])
                                    ]);
                                  }), 64)) : createCommentVNode("", true),
                                  ((_d2 = unref(planMemrshipResp)) == null ? void 0 : _d2.status) ? (openBlock(true), createBlock(Fragment, { key: 1 }, renderList((_f = (_e = unref(planMemrshipResp)) == null ? void 0 : _e.data) == null ? void 0 : _f.data[0].calendar_schedule, (p) => {
                                    return openBlock(), createBlock("tr", null, [
                                      createVNode("td", null, toDisplayString(new Date(p)), 1),
                                      createVNode("td")
                                    ]);
                                  }), 256)) : createCommentVNode("", true)
                                ])
                              ];
                            }
                          }),
                          _: 1
                        }, _parent4, _scopeId3));
                      } else {
                        return [
                          createVNode(_component_q_markup_table, null, {
                            default: withCtx(() => {
                              var _a2, _b2, _c2;
                              return [
                                createVNode("thead", null, [
                                  createVNode("tr", { class: "bg-grey-5 text-white text-h5" }, [
                                    createVNode("th", { class: "text-left" }, " Schedule "),
                                    createVNode("th", { class: "text-left" }, " Action ")
                                  ])
                                ]),
                                createVNode("tbody", null, [
                                  unref(loadingplanMemrship) ? (openBlock(), createBlock(Fragment, { key: 0 }, renderList(5, (n) => {
                                    return createVNode("tr", { key: n }, [
                                      createVNode("td", { class: "text-right" }, [
                                        createVNode(_component_q_skeleton, {
                                          animation: "blink",
                                          type: "text"
                                        })
                                      ]),
                                      createVNode("td", { class: "text-right" }, [
                                        createVNode(_component_q_skeleton, {
                                          animation: "blink",
                                          type: "text"
                                        })
                                      ])
                                    ]);
                                  }), 64)) : createCommentVNode("", true),
                                  ((_a2 = unref(planMemrshipResp)) == null ? void 0 : _a2.status) ? (openBlock(true), createBlock(Fragment, { key: 1 }, renderList((_c2 = (_b2 = unref(planMemrshipResp)) == null ? void 0 : _b2.data) == null ? void 0 : _c2.data[0].calendar_schedule, (p) => {
                                    return openBlock(), createBlock("tr", null, [
                                      createVNode("td", null, toDisplayString(new Date(p)), 1),
                                      createVNode("td")
                                    ]);
                                  }), 256)) : createCommentVNode("", true)
                                ])
                              ];
                            }),
                            _: 1
                          })
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode(_component_q_tab_panel, {
                      name: "diet_plans",
                      class: "q-pa-none"
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_lazy_panel_user_membership_diet_plan_create, {
                          membership_id: unref(route).params.membership_id,
                          target_date: unref(target_date)
                        }, null, 8, ["membership_id", "target_date"]),
                        createVNode(_component_lazy_panel_user_membership_diet_plan_list, {
                          membership_id: unref(route).params.membership_id,
                          onHandle_date_change: ($event) => target_date.value = $event
                        }, null, 8, ["membership_id", "onHandle_date_change"])
                      ]),
                      _: 1
                    }),
                    createVNode(_component_q_tab_panel, { name: "meetings" }, {
                      default: withCtx(() => [
                        createVNode(_component_q_markup_table, null, {
                          default: withCtx(() => {
                            var _a2, _b2, _c2;
                            return [
                              createVNode("thead", null, [
                                createVNode("tr", { class: "bg-grey-5 text-white text-h5" }, [
                                  createVNode("th", { class: "text-left" }, " Schedule "),
                                  createVNode("th", { class: "text-left" }, " Action ")
                                ])
                              ]),
                              createVNode("tbody", null, [
                                unref(loadingplanMemrship) ? (openBlock(), createBlock(Fragment, { key: 0 }, renderList(5, (n) => {
                                  return createVNode("tr", { key: n }, [
                                    createVNode("td", { class: "text-right" }, [
                                      createVNode(_component_q_skeleton, {
                                        animation: "blink",
                                        type: "text"
                                      })
                                    ]),
                                    createVNode("td", { class: "text-right" }, [
                                      createVNode(_component_q_skeleton, {
                                        animation: "blink",
                                        type: "text"
                                      })
                                    ])
                                  ]);
                                }), 64)) : createCommentVNode("", true),
                                ((_a2 = unref(planMemrshipResp)) == null ? void 0 : _a2.status) ? (openBlock(true), createBlock(Fragment, { key: 1 }, renderList((_c2 = (_b2 = unref(planMemrshipResp)) == null ? void 0 : _b2.data) == null ? void 0 : _c2.data[0].calendar_schedule, (p) => {
                                  return openBlock(), createBlock("tr", null, [
                                    createVNode("td", null, toDisplayString(new Date(p)), 1),
                                    createVNode("td")
                                  ]);
                                }), 256)) : createCommentVNode("", true)
                              ])
                            ];
                          }),
                          _: 1
                        })
                      ]),
                      _: 1
                    })
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
          } else {
            return [
              createVNode(_component_q_tabs, {
                modelValue: unref(tab),
                "onUpdate:modelValue": ($event) => isRef(tab) ? tab.value = $event : null,
                dense: "",
                class: "text-grey",
                "active-color": "primary",
                "indicator-color": "primary",
                align: "justify"
              }, {
                default: withCtx(() => [
                  createVNode(_component_q_tab, {
                    name: "diet_plans",
                    label: "Diet Plans",
                    icon: "fa fa-weight-scale"
                  }),
                  createVNode(_component_q_tab, {
                    name: "meetings",
                    label: "Meeting Schedules",
                    icon: "fa fa-comments-dollar"
                  })
                ]),
                _: 1
              }, 8, ["modelValue", "onUpdate:modelValue"]),
              createVNode(_component_q_separator),
              createVNode(_component_q_tab_panels, {
                modelValue: unref(tab),
                "onUpdate:modelValue": ($event) => isRef(tab) ? tab.value = $event : null,
                animated: ""
              }, {
                default: withCtx(() => [
                  createVNode(_component_q_tab_panel, {
                    name: "diet_plans",
                    class: "q-pa-none"
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_lazy_panel_user_membership_diet_plan_create, {
                        membership_id: unref(route).params.membership_id,
                        target_date: unref(target_date)
                      }, null, 8, ["membership_id", "target_date"]),
                      createVNode(_component_lazy_panel_user_membership_diet_plan_list, {
                        membership_id: unref(route).params.membership_id,
                        onHandle_date_change: ($event) => target_date.value = $event
                      }, null, 8, ["membership_id", "onHandle_date_change"])
                    ]),
                    _: 1
                  }),
                  createVNode(_component_q_tab_panel, { name: "meetings" }, {
                    default: withCtx(() => [
                      createVNode(_component_q_markup_table, null, {
                        default: withCtx(() => {
                          var _a2, _b2, _c2;
                          return [
                            createVNode("thead", null, [
                              createVNode("tr", { class: "bg-grey-5 text-white text-h5" }, [
                                createVNode("th", { class: "text-left" }, " Schedule "),
                                createVNode("th", { class: "text-left" }, " Action ")
                              ])
                            ]),
                            createVNode("tbody", null, [
                              unref(loadingplanMemrship) ? (openBlock(), createBlock(Fragment, { key: 0 }, renderList(5, (n) => {
                                return createVNode("tr", { key: n }, [
                                  createVNode("td", { class: "text-right" }, [
                                    createVNode(_component_q_skeleton, {
                                      animation: "blink",
                                      type: "text"
                                    })
                                  ]),
                                  createVNode("td", { class: "text-right" }, [
                                    createVNode(_component_q_skeleton, {
                                      animation: "blink",
                                      type: "text"
                                    })
                                  ])
                                ]);
                              }), 64)) : createCommentVNode("", true),
                              ((_a2 = unref(planMemrshipResp)) == null ? void 0 : _a2.status) ? (openBlock(true), createBlock(Fragment, { key: 1 }, renderList((_c2 = (_b2 = unref(planMemrshipResp)) == null ? void 0 : _b2.data) == null ? void 0 : _c2.data[0].calendar_schedule, (p) => {
                                return openBlock(), createBlock("tr", null, [
                                  createVNode("td", null, toDisplayString(new Date(p)), 1),
                                  createVNode("td")
                                ]);
                              }), 256)) : createCommentVNode("", true)
                            ])
                          ];
                        }),
                        _: 1
                      })
                    ]),
                    _: 1
                  })
                ]),
                _: 1
              }, 8, ["modelValue", "onUpdate:modelValue"])
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(`</div></div><!--]-->`);
    };
  }
});
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("pages/panel/user/[_id]/membership/[membership_id]/index.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};

export { _sfc_main as default };
//# sourceMappingURL=index-CwYtAWDP.mjs.map
