import { l as createComponent, C as noop, r as listenOpts, D as isRuntimeSsrPreHydration, I as layoutKey, F as emptyRenderFn, m as stopAndPrevent, J as pageContainerKey, n as navigateTo } from './server.mjs';
import { computed, h, watch, getCurrentInstance, onMounted, onBeforeUnmount, ref, reactive, provide, inject, nextTick, withDirectives, Transition, shallowReactive, vShow, defineComponent, resolveComponent, mergeProps, withCtx, unref, createVNode, createTextVNode, toDisplayString, openBlock, createBlock, renderSlot, useSSRContext } from 'vue';
import { ssrRenderComponent, ssrInterpolate, ssrRenderStyle, ssrGetDirectiveProps, ssrRenderSlot } from 'vue/server-renderer';
import { p as pitLib } from './pitLib-BR8GY8Gr.mjs';
import { E as Env } from './env-B2a7_Xo2.mjs';
import { s as scrollTargetProp, e as getScrollTarget, a as getVerticalScrollPosition, g as getHorizontalScrollPosition, b as getScrollbarWidth, u as useModelToggleProps, c as useModelToggleEmits, d as useModelToggle } from '../_/scroll.mjs';
import { Q as QResizeObserver } from '../_/QResizeObserver.mjs';
import { d as hMergeSlotSafely, b as hMergeSlot, e as hUniqueSlot, h as hSlot, u as useDarkProps, a as useDark, c as hDir } from '../_/use-dark.mjs';
import { _ as __nuxt_component_2$1 } from '../_/QBtn.mjs';
import { b as useSizeProps, a as useSize, Q as QIcon, _ as __q_directive_0 } from '../_/vm.mjs';
import { u as useHistory, a as usePreventScroll, _ as __nuxt_component_1$1 } from '../_/use-prevent-scroll.mjs';
import { u as useTimeout, a as uid, Q as QSeparator, _ as __nuxt_component_0$1 } from '../_/use-timeout.mjs';
import { T as TouchPan } from '../_/TouchPan.mjs';
import { b as between } from '../_/format.mjs';
import { u as useId, Q as QItem, a as QItemSection } from '../_/QItemSection.mjs';
import { Q as QItemLabel } from '../_/QItemLabel.mjs';
import { d as useRouterLinkProps } from '../_/use-router-link.mjs';
import { _ as __nuxt_component_2$2 } from '../_/QBadge.mjs';
import '../runtime.mjs';
import 'node:http';
import 'node:https';
import 'fs';
import 'path';
import 'node:fs';
import 'node:url';
import 'unhead';
import '@unhead/shared';
import 'vue-router';
import '../_/nuxt-storage.mjs';
import 'sweetalert2';

const __nuxt_component_5 = createComponent({
  name: 'QAvatar',

  props: {
    ...useSizeProps,

    fontSize: String,

    color: String,
    textColor: String,

    icon: String,
    square: Boolean,
    rounded: Boolean
  },

  setup (props, { slots }) {
    const sizeStyle = useSize(props);

    const classes = computed(() =>
      'q-avatar'
      + (props.color ? ` bg-${ props.color }` : '')
      + (props.textColor ? ` text-${ props.textColor } q-chip--colored` : '')
      + (
        props.square === true
          ? ' q-avatar--square'
          : (props.rounded === true ? ' rounded-borders' : '')
      )
    );

    const contentStyle = computed(() => (
      props.fontSize
        ? { fontSize: props.fontSize }
        : null
    ));

    return () => {
      const icon = props.icon !== void 0
        ? [ h(QIcon, { name: props.icon }) ]
        : void 0;

      return h('div', {
        class: classes.value,
        style: sizeStyle.value
      }, [
        h('div', {
          class: 'q-avatar__content row flex-center overflow-hidden',
          style: contentStyle.value
        }, hMergeSlotSafely(slots.default, icon))
      ])
    }
  }
});

const { passive } = listenOpts;
const axisValues = [ 'both', 'horizontal', 'vertical' ];

const QScrollObserver = createComponent({
  name: 'QScrollObserver',

  props: {
    axis: {
      type: String,
      validator: v => axisValues.includes(v),
      default: 'vertical'
    },

    debounce: [ String, Number ],

    scrollTarget: scrollTargetProp
  },

  emits: [ 'scroll' ],

  setup (props, { emit }) {
    const scroll = {
      position: {
        top: 0,
        left: 0
      },

      direction: 'down',
      directionChanged: false,

      delta: {
        top: 0,
        left: 0
      },

      inflectionPoint: {
        top: 0,
        left: 0
      }
    };

    let clearTimer = null, localScrollTarget, parentEl;

    watch(() => props.scrollTarget, () => {
      unconfigureScrollTarget();
      configureScrollTarget();
    });

    function emitEvent () {
      clearTimer !== null && clearTimer();

      const top = Math.max(0, getVerticalScrollPosition(localScrollTarget));
      const left = getHorizontalScrollPosition(localScrollTarget);

      const delta = {
        top: top - scroll.position.top,
        left: left - scroll.position.left
      };

      if (
        (props.axis === 'vertical' && delta.top === 0)
        || (props.axis === 'horizontal' && delta.left === 0)
      ) {
        return
      }

      const curDir = Math.abs(delta.top) >= Math.abs(delta.left)
        ? (delta.top < 0 ? 'up' : 'down')
        : (delta.left < 0 ? 'left' : 'right');

      scroll.position = { top, left };
      scroll.directionChanged = scroll.direction !== curDir;
      scroll.delta = delta;

      if (scroll.directionChanged === true) {
        scroll.direction = curDir;
        scroll.inflectionPoint = scroll.position;
      }

      emit('scroll', { ...scroll });
    }

    function configureScrollTarget () {
      localScrollTarget = getScrollTarget(parentEl, props.scrollTarget);
      localScrollTarget.addEventListener('scroll', trigger, passive);
      trigger(true);
    }

    function unconfigureScrollTarget () {
      if (localScrollTarget !== void 0) {
        localScrollTarget.removeEventListener('scroll', trigger, passive);
        localScrollTarget = void 0;
      }
    }

    function trigger (immediately) {
      if (immediately === true || props.debounce === 0 || props.debounce === '0') {
        emitEvent();
      }
      else if (clearTimer === null) {
        const [ timer, fn ] = props.debounce
          ? [ setTimeout(emitEvent, props.debounce), clearTimeout ]
          : [ requestAnimationFrame(emitEvent), cancelAnimationFrame ];

        clearTimer = () => {
          fn(timer);
          clearTimer = null;
        };
      }
    }

    const { proxy } = getCurrentInstance();

    watch(() => proxy.$q.lang.rtl, emitEvent);

    onMounted(() => {
      parentEl = proxy.$el.parentNode;
      configureScrollTarget();
    });

    onBeforeUnmount(() => {
      clearTimer !== null && clearTimer();
      unconfigureScrollTarget();
    });

    // expose public methods
    Object.assign(proxy, {
      trigger,
      getPosition: () => scroll
    });

    return noop
  }
});

const __nuxt_component_0 = createComponent({
  name: 'QLayout',

  props: {
    container: Boolean,
    view: {
      type: String,
      default: 'hhh lpr fff',
      validator: v => /^(h|l)h(h|r) lpr (f|l)f(f|r)$/.test(v.toLowerCase())
    },

    onScroll: Function,
    onScrollHeight: Function,
    onResize: Function
  },

  setup (props, { slots, emit }) {
    const { proxy: { $q } } = getCurrentInstance();

    const rootRef = ref(null);

    // page related
    const height = ref($q.screen.height);
    const width = ref(props.container === true ? 0 : $q.screen.width);
    const scroll = ref({ position: 0, direction: 'down', inflectionPoint: 0 });

    // container only prop
    const containerHeight = ref(0);
    const scrollbarWidth = ref(isRuntimeSsrPreHydration.value === true ? 0 : getScrollbarWidth());

    const classes = computed(() =>
      'q-layout q-layout--'
      + (props.container === true ? 'containerized' : 'standard')
    );

    const style = computed(() => (
      props.container === false
        ? { minHeight: $q.screen.height + 'px' }
        : null
    ));

    // used by container only
    const targetStyle = computed(() => (
      scrollbarWidth.value !== 0
        ? { [ $q.lang.rtl === true ? 'left' : 'right' ]: `${ scrollbarWidth.value }px` }
        : null
    ));

    const targetChildStyle = computed(() => (
      scrollbarWidth.value !== 0
        ? {
            [ $q.lang.rtl === true ? 'right' : 'left' ]: 0,
            [ $q.lang.rtl === true ? 'left' : 'right' ]: `-${ scrollbarWidth.value }px`,
            width: `calc(100% + ${ scrollbarWidth.value }px)`
          }
        : null
    ));

    function onPageScroll (data) {
      if (props.container === true || document.qScrollPrevented !== true) {
        const info = {
          position: data.position.top,
          direction: data.direction,
          directionChanged: data.directionChanged,
          inflectionPoint: data.inflectionPoint.top,
          delta: data.delta.top
        };

        scroll.value = info;
        props.onScroll !== void 0 && emit('scroll', info);
      }
    }

    function onPageResize (data) {
      const { height: newHeight, width: newWidth } = data;
      let resized = false;

      if (height.value !== newHeight) {
        resized = true;
        height.value = newHeight;
        props.onScrollHeight !== void 0 && emit('scrollHeight', newHeight);
        updateScrollbarWidth();
      }
      if (width.value !== newWidth) {
        resized = true;
        width.value = newWidth;
      }

      if (resized === true && props.onResize !== void 0) {
        emit('resize', data);
      }
    }

    function onContainerResize ({ height }) {
      if (containerHeight.value !== height) {
        containerHeight.value = height;
        updateScrollbarWidth();
      }
    }

    function updateScrollbarWidth () {
      if (props.container === true) {
        const width = height.value > containerHeight.value
          ? getScrollbarWidth()
          : 0;

        if (scrollbarWidth.value !== width) {
          scrollbarWidth.value = width;
        }
      }
    }

    let animateTimer = null;

    const $layout = {
      instances: {},
      view: computed(() => props.view),
      isContainer: computed(() => props.container),

      rootRef,

      height,
      containerHeight,
      scrollbarWidth,
      totalWidth: computed(() => width.value + scrollbarWidth.value),

      rows: computed(() => {
        const rows = props.view.toLowerCase().split(' ');
        return {
          top: rows[ 0 ].split(''),
          middle: rows[ 1 ].split(''),
          bottom: rows[ 2 ].split('')
        }
      }),

      header: reactive({ size: 0, offset: 0, space: false }),
      right: reactive({ size: 300, offset: 0, space: false }),
      footer: reactive({ size: 0, offset: 0, space: false }),
      left: reactive({ size: 300, offset: 0, space: false }),

      scroll,

      animate () {
        if (animateTimer !== null) {
          clearTimeout(animateTimer);
        }
        else {
          document.body.classList.add('q-body--layout-animate');
        }

        animateTimer = setTimeout(() => {
          animateTimer = null;
          document.body.classList.remove('q-body--layout-animate');
        }, 155);
      },

      update (part, prop, val) {
        $layout[ part ][ prop ] = val;
      }
    };

    provide(layoutKey, $layout);

    return () => {
      const content = hMergeSlot(slots.default, [
        h(QScrollObserver, { onScroll: onPageScroll }),
        h(QResizeObserver, { onResize: onPageResize })
      ]);

      const layout = h('div', {
        class: classes.value,
        style: style.value,
        ref: props.container === true ? void 0 : rootRef,
        tabindex: -1
      }, content);

      if (props.container === true) {
        return h('div', {
          class: 'q-layout-container overflow-hidden',
          ref: rootRef
        }, [
          h(QResizeObserver, { onResize: onContainerResize }),
          h('div', {
            class: 'absolute-full',
            style: targetStyle.value
          }, [
            h('div', {
              class: 'scroll',
              style: targetChildStyle.value
            }, [ layout ])
          ])
        ])
      }

      return layout
    }
  }
});

const __nuxt_component_1 = createComponent({
  name: 'QHeader',

  props: {
    modelValue: {
      type: Boolean,
      default: true
    },
    reveal: Boolean,
    revealOffset: {
      type: Number,
      default: 250
    },
    bordered: Boolean,
    elevated: Boolean,

    heightHint: {
      type: [ String, Number ],
      default: 50
    }
  },

  emits: [ 'reveal', 'focusin' ],

  setup (props, { slots, emit }) {
    const { proxy: { $q } } = getCurrentInstance();

    const $layout = inject(layoutKey, emptyRenderFn);
    if ($layout === emptyRenderFn) {
      console.error('QHeader needs to be child of QLayout');
      return emptyRenderFn
    }

    const size = ref(parseInt(props.heightHint, 10));
    const revealed = ref(true);

    const fixed = computed(() =>
      props.reveal === true
      || $layout.view.value.indexOf('H') !== -1
      || ($q.platform.is.ios && $layout.isContainer.value === true)
    );

    const offset = computed(() => {
      if (props.modelValue !== true) {
        return 0
      }
      if (fixed.value === true) {
        return revealed.value === true ? size.value : 0
      }
      const offset = size.value - $layout.scroll.value.position;
      return offset > 0 ? offset : 0
    });

    const hidden = computed(() => props.modelValue !== true
      || (fixed.value === true && revealed.value !== true)
    );

    const revealOnFocus = computed(() =>
      props.modelValue === true && hidden.value === true && props.reveal === true
    );

    const classes = computed(() =>
      'q-header q-layout__section--marginal '
      + (fixed.value === true ? 'fixed' : 'absolute') + '-top'
      + (props.bordered === true ? ' q-header--bordered' : '')
      + (hidden.value === true ? ' q-header--hidden' : '')
      + (props.modelValue !== true ? ' q-layout--prevent-focus' : '')
    );

    const style = computed(() => {
      const
        view = $layout.rows.value.top,
        css = {};

      if (view[ 0 ] === 'l' && $layout.left.space === true) {
        css[ $q.lang.rtl === true ? 'right' : 'left' ] = `${ $layout.left.size }px`;
      }
      if (view[ 2 ] === 'r' && $layout.right.space === true) {
        css[ $q.lang.rtl === true ? 'left' : 'right' ] = `${ $layout.right.size }px`;
      }

      return css
    });

    function updateLayout (prop, val) {
      $layout.update('header', prop, val);
    }

    function updateLocal (prop, val) {
      if (prop.value !== val) {
        prop.value = val;
      }
    }

    function onResize ({ height }) {
      updateLocal(size, height);
      updateLayout('size', height);
    }

    function onFocusin (evt) {
      if (revealOnFocus.value === true) {
        updateLocal(revealed, true);
      }

      emit('focusin', evt);
    }

    watch(() => props.modelValue, val => {
      updateLayout('space', val);
      updateLocal(revealed, true);
      $layout.animate();
    });

    watch(offset, val => {
      updateLayout('offset', val);
    });

    watch(() => props.reveal, val => {
      val === false && updateLocal(revealed, props.modelValue);
    });

    watch(revealed, val => {
      $layout.animate();
      emit('reveal', val);
    });

    watch($layout.scroll, scroll => {
      props.reveal === true && updateLocal(revealed,
        scroll.direction === 'up'
        || scroll.position <= props.revealOffset
        || scroll.position - scroll.inflectionPoint < 100
      );
    });

    const instance = {};

    $layout.instances.header = instance;
    props.modelValue === true && updateLayout('size', size.value);
    updateLayout('space', props.modelValue);
    updateLayout('offset', offset.value);

    onBeforeUnmount(() => {
      if ($layout.instances.header === instance) {
        $layout.instances.header = void 0;
        updateLayout('size', 0);
        updateLayout('offset', 0);
        updateLayout('space', false);
      }
    });

    return () => {
      const child = hUniqueSlot(slots.default, []);

      props.elevated === true && child.push(
        h('div', {
          class: 'q-layout__shadow absolute-full overflow-hidden no-pointer-events'
        })
      );

      child.push(
        h(QResizeObserver, {
          debounce: 0,
          onResize
        })
      );

      return h('header', {
        class: classes.value,
        style: style.value,
        onFocusin
      }, child)
    }
  }
});

const __nuxt_component_2 = createComponent({
  name: 'QToolbar',

  props: {
    inset: Boolean
  },

  setup (props, { slots }) {
    const classes = computed(() =>
      'q-toolbar row no-wrap items-center'
      + (props.inset === true ? ' q-toolbar--inset' : '')
    );

    return () => h('div', { class: classes.value, role: 'toolbar' }, hSlot(slots.default))
  }
});

const __nuxt_component_4 = createComponent({
  name: 'QToolbarTitle',

  props: {
    shrink: Boolean
  },

  setup (props, { slots }) {
    const classes = computed(() =>
      'q-toolbar__title ellipsis'
      + (props.shrink === true ? ' col-shrink' : '')
    );

    return () => h('div', { class: classes.value }, hSlot(slots.default))
  }
});

const duration = 150;

const __nuxt_component_6 = createComponent({
  name: 'QDrawer',

  inheritAttrs: false,

  props: {
    ...useModelToggleProps,
    ...useDarkProps,

    side: {
      type: String,
      default: 'left',
      validator: v => [ 'left', 'right' ].includes(v)
    },

    width: {
      type: Number,
      default: 300
    },

    mini: Boolean,
    miniToOverlay: Boolean,
    miniWidth: {
      type: Number,
      default: 57
    },
    noMiniAnimation: Boolean,

    breakpoint: {
      type: Number,
      default: 1023
    },
    showIfAbove: Boolean,

    behavior: {
      type: String,
      validator: v => [ 'default', 'desktop', 'mobile' ].includes(v),
      default: 'default'
    },

    bordered: Boolean,
    elevated: Boolean,

    overlay: Boolean,
    persistent: Boolean,
    noSwipeOpen: Boolean,
    noSwipeClose: Boolean,
    noSwipeBackdrop: Boolean
  },

  emits: [
    ...useModelToggleEmits,
    'onLayout', 'miniState'
  ],

  setup (props, { slots, emit, attrs }) {
    const vm = getCurrentInstance();
    const { proxy: { $q } } = vm;

    const isDark = useDark(props, $q);
    const { preventBodyScroll } = usePreventScroll();
    const { registerTimeout, removeTimeout } = useTimeout();

    const $layout = inject(layoutKey, emptyRenderFn);
    if ($layout === emptyRenderFn) {
      console.error('QDrawer needs to be child of QLayout');
      return emptyRenderFn
    }

    let lastDesktopState, timerMini = null, layoutTotalWidthWatcher;

    const belowBreakpoint = ref(
      props.behavior === 'mobile'
      || (props.behavior !== 'desktop' && $layout.totalWidth.value <= props.breakpoint)
    );

    const isMini = computed(() =>
      props.mini === true && belowBreakpoint.value !== true
    );

    const size = computed(() => (
      isMini.value === true
        ? props.miniWidth
        : props.width
    ));

    const showing = ref(
      props.showIfAbove === true && belowBreakpoint.value === false
        ? true
        : props.modelValue === true
    );

    const hideOnRouteChange = computed(() =>
      props.persistent !== true
      && (belowBreakpoint.value === true || onScreenOverlay.value === true)
    );

    function handleShow (evt, noEvent) {
      addToHistory();

      evt !== false && $layout.animate();
      applyPosition(0);

      if (belowBreakpoint.value === true) {
        const otherInstance = $layout.instances[ otherSide.value ];
        if (otherInstance !== void 0 && otherInstance.belowBreakpoint === true) {
          otherInstance.hide(false);
        }

        applyBackdrop(1);
        $layout.isContainer.value !== true && preventBodyScroll(true);
      }
      else {
        applyBackdrop(0);
        evt !== false && setScrollable(false);
      }

      registerTimeout(() => {
        evt !== false && setScrollable(true);
        noEvent !== true && emit('show', evt);
      }, duration);
    }

    function handleHide (evt, noEvent) {
      removeFromHistory();

      evt !== false && $layout.animate();

      applyBackdrop(0);
      applyPosition(stateDirection.value * size.value);

      cleanup();

      if (noEvent !== true) {
        registerTimeout(() => { emit('hide', evt); }, duration);
      }
      else {
        removeTimeout();
      }
    }

    const { show, hide } = useModelToggle({
      showing,
      hideOnRouteChange,
      handleShow,
      handleHide
    });

    const { addToHistory, removeFromHistory } = useHistory(showing, hide, hideOnRouteChange);

    const instance = {
      belowBreakpoint,
      hide
    };

    const rightSide = computed(() => props.side === 'right');

    const stateDirection = computed(() =>
      ($q.lang.rtl === true ? -1 : 1) * (rightSide.value === true ? 1 : -1)
    );

    const flagBackdropBg = ref(0);
    const flagPanning = ref(false);
    const flagMiniAnimate = ref(false);
    const flagContentPosition = ref( // starting with "hidden" for SSR
      size.value * stateDirection.value
    );

    const otherSide = computed(() => (rightSide.value === true ? 'left' : 'right'));
    const offset = computed(() => (
      showing.value === true && belowBreakpoint.value === false && props.overlay === false
        ? (props.miniToOverlay === true ? props.miniWidth : size.value)
        : 0
    ));

    const fixed = computed(() =>
      props.overlay === true
      || props.miniToOverlay === true
      || $layout.view.value.indexOf(rightSide.value ? 'R' : 'L') !== -1
      || ($q.platform.is.ios === true && $layout.isContainer.value === true)
    );

    const onLayout = computed(() =>
      props.overlay === false
      && showing.value === true
      && belowBreakpoint.value === false
    );

    const onScreenOverlay = computed(() =>
      props.overlay === true
      && showing.value === true
      && belowBreakpoint.value === false
    );

    const backdropClass = computed(() =>
      'fullscreen q-drawer__backdrop'
      + (showing.value === false && flagPanning.value === false ? ' hidden' : '')
    );

    const backdropStyle = computed(() => ({
      backgroundColor: `rgba(0,0,0,${ flagBackdropBg.value * 0.4 })`
    }));

    const headerSlot = computed(() => (
      rightSide.value === true
        ? $layout.rows.value.top[ 2 ] === 'r'
        : $layout.rows.value.top[ 0 ] === 'l'
    ));

    const footerSlot = computed(() => (
      rightSide.value === true
        ? $layout.rows.value.bottom[ 2 ] === 'r'
        : $layout.rows.value.bottom[ 0 ] === 'l'
    ));

    const aboveStyle = computed(() => {
      const css = {};

      if ($layout.header.space === true && headerSlot.value === false) {
        if (fixed.value === true) {
          css.top = `${ $layout.header.offset }px`;
        }
        else if ($layout.header.space === true) {
          css.top = `${ $layout.header.size }px`;
        }
      }

      if ($layout.footer.space === true && footerSlot.value === false) {
        if (fixed.value === true) {
          css.bottom = `${ $layout.footer.offset }px`;
        }
        else if ($layout.footer.space === true) {
          css.bottom = `${ $layout.footer.size }px`;
        }
      }

      return css
    });

    const style = computed(() => {
      const style = {
        width: `${ size.value }px`,
        transform: `translateX(${ flagContentPosition.value }px)`
      };

      return belowBreakpoint.value === true
        ? style
        : Object.assign(style, aboveStyle.value)
    });

    const contentClass = computed(() =>
      'q-drawer__content fit '
      + ($layout.isContainer.value !== true ? 'scroll' : 'overflow-auto')
    );

    const classes = computed(() =>
      `q-drawer q-drawer--${ props.side }`
      + (flagMiniAnimate.value === true ? ' q-drawer--mini-animate' : '')
      + (props.bordered === true ? ' q-drawer--bordered' : '')
      + (isDark.value === true ? ' q-drawer--dark q-dark' : '')
      + (
        flagPanning.value === true
          ? ' no-transition'
          : (showing.value === true ? '' : ' q-layout--prevent-focus')
      )
      + (
        belowBreakpoint.value === true
          ? ' fixed q-drawer--on-top q-drawer--mobile q-drawer--top-padding'
          : ` q-drawer--${ isMini.value === true ? 'mini' : 'standard' }`
          + (fixed.value === true || onLayout.value !== true ? ' fixed' : '')
          + (props.overlay === true || props.miniToOverlay === true ? ' q-drawer--on-top' : '')
          + (headerSlot.value === true ? ' q-drawer--top-padding' : '')
      )
    );

    const openDirective = computed(() => {
      // if props.noSwipeOpen !== true
      const dir = $q.lang.rtl === true ? props.side : otherSide.value;

      return [ [
        TouchPan,
        onOpenPan,
        void 0,
        {
          [ dir ]: true,
          mouse: true
        }
      ] ]
    });

    const contentCloseDirective = computed(() => {
      // if belowBreakpoint.value === true && props.noSwipeClose !== true
      const dir = $q.lang.rtl === true ? otherSide.value : props.side;

      return [ [
        TouchPan,
        onClosePan,
        void 0,
        {
          [ dir ]: true,
          mouse: true
        }
      ] ]
    });

    const backdropCloseDirective = computed(() => {
      // if showing.value === true && props.noSwipeBackdrop !== true
      const dir = $q.lang.rtl === true ? otherSide.value : props.side;

      return [ [
        TouchPan,
        onClosePan,
        void 0,
        {
          [ dir ]: true,
          mouse: true,
          mouseAllDir: true
        }
      ] ]
    });

    function updateBelowBreakpoint () {
      updateLocal(belowBreakpoint, (
        props.behavior === 'mobile'
        || (props.behavior !== 'desktop' && $layout.totalWidth.value <= props.breakpoint)
      ));
    }

    watch(belowBreakpoint, val => {
      if (val === true) { // from lg to xs
        lastDesktopState = showing.value;
        showing.value === true && hide(false);
      }
      else if (
        props.overlay === false
        && props.behavior !== 'mobile'
        && lastDesktopState !== false
      ) { // from xs to lg
        if (showing.value === true) {
          applyPosition(0);
          applyBackdrop(0);
          cleanup();
        }
        else {
          show(false);
        }
      }
    });

    watch(() => props.side, (newSide, oldSide) => {
      if ($layout.instances[ oldSide ] === instance) {
        $layout.instances[ oldSide ] = void 0;
        $layout[ oldSide ].space = false;
        $layout[ oldSide ].offset = 0;
      }

      $layout.instances[ newSide ] = instance;
      $layout[ newSide ].size = size.value;
      $layout[ newSide ].space = onLayout.value;
      $layout[ newSide ].offset = offset.value;
    });

    watch($layout.totalWidth, () => {
      if ($layout.isContainer.value === true || document.qScrollPrevented !== true) {
        updateBelowBreakpoint();
      }
    });

    watch(
      () => props.behavior + props.breakpoint,
      updateBelowBreakpoint
    );

    watch($layout.isContainer, val => {
      showing.value === true && preventBodyScroll(val !== true);
      val === true && updateBelowBreakpoint();
    });

    watch($layout.scrollbarWidth, () => {
      applyPosition(showing.value === true ? 0 : void 0);
    });

    watch(offset, val => { updateLayout('offset', val); });

    watch(onLayout, val => {
      emit('onLayout', val);
      updateLayout('space', val);
    });

    watch(rightSide, () => { applyPosition(); });

    watch(size, val => {
      applyPosition();
      updateSizeOnLayout(props.miniToOverlay, val);
    });

    watch(() => props.miniToOverlay, val => {
      updateSizeOnLayout(val, size.value);
    });

    watch(() => $q.lang.rtl, () => { applyPosition(); });

    watch(() => props.mini, () => {
      if (props.noMiniAnimation) return
      if (props.modelValue === true) {
        animateMini();
        $layout.animate();
      }
    });

    watch(isMini, val => { emit('miniState', val); });

    function applyPosition (position) {
      if (position === void 0) {
        nextTick(() => {
          position = showing.value === true ? 0 : size.value;
          applyPosition(stateDirection.value * position);
        });
      }
      else {
        if (
          $layout.isContainer.value === true
          && rightSide.value === true
          && (belowBreakpoint.value === true || Math.abs(position) === size.value)
        ) {
          position += stateDirection.value * $layout.scrollbarWidth.value;
        }

        flagContentPosition.value = position;
      }
    }

    function applyBackdrop (x) {
      flagBackdropBg.value = x;
    }

    function setScrollable (v) {
      const action = v === true
        ? 'remove'
        : ($layout.isContainer.value !== true ? 'add' : '');

      action !== '' && document.body.classList[ action ]('q-body--drawer-toggle');
    }

    function animateMini () {
      timerMini !== null && clearTimeout(timerMini);

      if (vm.proxy && vm.proxy.$el) {
        // need to speed it up and apply it immediately,
        // even faster than Vue's nextTick!
        vm.proxy.$el.classList.add('q-drawer--mini-animate');
      }

      flagMiniAnimate.value = true;
      timerMini = setTimeout(() => {
        timerMini = null;
        flagMiniAnimate.value = false;
        if (vm && vm.proxy && vm.proxy.$el) {
          vm.proxy.$el.classList.remove('q-drawer--mini-animate');
        }
      }, 150);
    }

    function onOpenPan (evt) {
      if (showing.value !== false) {
        // some browsers might capture and trigger this
        // even if Drawer has just been opened (but animation is still pending)
        return
      }

      const
        width = size.value,
        position = between(evt.distance.x, 0, width);

      if (evt.isFinal === true) {
        const opened = position >= Math.min(75, width);

        if (opened === true) {
          show();
        }
        else {
          $layout.animate();
          applyBackdrop(0);
          applyPosition(stateDirection.value * width);
        }

        flagPanning.value = false;
        return
      }

      applyPosition(
        ($q.lang.rtl === true ? rightSide.value !== true : rightSide.value)
          ? Math.max(width - position, 0)
          : Math.min(0, position - width)
      );
      applyBackdrop(
        between(position / width, 0, 1)
      );

      if (evt.isFirst === true) {
        flagPanning.value = true;
      }
    }

    function onClosePan (evt) {
      if (showing.value !== true) {
        // some browsers might capture and trigger this
        // even if Drawer has just been closed (but animation is still pending)
        return
      }

      const
        width = size.value,
        dir = evt.direction === props.side,
        position = ($q.lang.rtl === true ? dir !== true : dir)
          ? between(evt.distance.x, 0, width)
          : 0;

      if (evt.isFinal === true) {
        const opened = Math.abs(position) < Math.min(75, width);

        if (opened === true) {
          $layout.animate();
          applyBackdrop(1);
          applyPosition(0);
        }
        else {
          hide();
        }

        flagPanning.value = false;
        return
      }

      applyPosition(stateDirection.value * position);
      applyBackdrop(between(1 - position / width, 0, 1));

      if (evt.isFirst === true) {
        flagPanning.value = true;
      }
    }

    function cleanup () {
      preventBodyScroll(false);
      setScrollable(true);
    }

    function updateLayout (prop, val) {
      $layout.update(props.side, prop, val);
    }

    function updateLocal (prop, val) {
      if (prop.value !== val) {
        prop.value = val;
      }
    }

    function updateSizeOnLayout (miniToOverlay, size) {
      updateLayout('size', miniToOverlay === true ? props.miniWidth : size);
    }

    $layout.instances[ props.side ] = instance;
    updateSizeOnLayout(props.miniToOverlay, size.value);
    updateLayout('space', onLayout.value);
    updateLayout('offset', offset.value);

    if (
      props.showIfAbove === true
      && props.modelValue !== true
      && showing.value === true
      && props[ 'onUpdate:modelValue' ] !== void 0
    ) {
      emit('update:modelValue', true);
    }

    onMounted(() => {
      emit('onLayout', onLayout.value);
      emit('miniState', isMini.value);

      lastDesktopState = props.showIfAbove === true;

      const fn = () => {
        const action = showing.value === true ? handleShow : handleHide;
        action(false, true);
      };

      if ($layout.totalWidth.value !== 0) {
        // make sure that all computed properties
        // have been updated before calling handleShow/handleHide()
        nextTick(fn);
        return
      }

      layoutTotalWidthWatcher = watch($layout.totalWidth, () => {
        layoutTotalWidthWatcher();
        layoutTotalWidthWatcher = void 0;

        if (showing.value === false && props.showIfAbove === true && belowBreakpoint.value === false) {
          show(false);
        }
        else {
          fn();
        }
      });
    });

    onBeforeUnmount(() => {
      layoutTotalWidthWatcher !== void 0 && layoutTotalWidthWatcher();

      if (timerMini !== null) {
        clearTimeout(timerMini);
        timerMini = null;
      }

      showing.value === true && cleanup();

      if ($layout.instances[ props.side ] === instance) {
        $layout.instances[ props.side ] = void 0;
        updateLayout('size', 0);
        updateLayout('offset', 0);
        updateLayout('space', false);
      }
    });

    return () => {
      const child = [];

      if (belowBreakpoint.value === true) {
        props.noSwipeOpen === false && child.push(
          withDirectives(
            h('div', {
              key: 'open',
              class: `q-drawer__opener fixed-${ props.side }`,
              'aria-hidden': 'true'
            }),
            openDirective.value
          )
        );

        child.push(
          hDir(
            'div',
            {
              ref: 'backdrop',
              class: backdropClass.value,
              style: backdropStyle.value,
              'aria-hidden': 'true',
              onClick: hide
            },
            void 0,
            'backdrop',
            props.noSwipeBackdrop !== true && showing.value === true,
            () => backdropCloseDirective.value
          )
        );
      }

      const mini = isMini.value === true && slots.mini !== void 0;
      const content = [
        h('div', {
          ...attrs,
          key: '' + mini, // required otherwise Vue will not diff correctly
          class: [
            contentClass.value,
            attrs.class
          ]
        }, mini === true
          ? slots.mini()
          : hSlot(slots.default)
        )
      ];

      if (props.elevated === true && showing.value === true) {
        content.push(
          h('div', {
            class: 'q-layout__shadow absolute-full overflow-hidden no-pointer-events'
          })
        );
      }

      child.push(
        hDir(
          'aside',
          { ref: 'content', class: classes.value, style: style.value },
          content,
          'contentclose',
          props.noSwipeClose !== true && belowBreakpoint.value === true,
          () => contentCloseDirective.value
        )
      );

      return h('div', { class: 'q-drawer-container' }, child)
    }
  }
});

const __nuxt_component_7 = createComponent({
  name: 'QList',

  props: {
    ...useDarkProps,

    bordered: Boolean,
    dense: Boolean,
    separator: Boolean,
    padding: Boolean,

    tag: {
      type: String,
      default: 'div'
    }
  },

  setup (props, { slots }) {
    const vm = getCurrentInstance();
    const isDark = useDark(props, vm.proxy.$q);

    const classes = computed(() =>
      'q-list'
      + (props.bordered === true ? ' q-list--bordered' : '')
      + (props.dense === true ? ' q-list--dense' : '')
      + (props.separator === true ? ' q-list--separator' : '')
      + (isDark.value === true ? ' q-list--dark' : '')
      + (props.padding === true ? ' q-list--padding' : '')
    );

    return () => h(props.tag, { class: classes.value }, hSlot(slots.default))
  }
});

const QSlideTransition = createComponent({
  name: 'QSlideTransition',

  props: {
    appear: Boolean,
    duration: {
      type: Number,
      default: 300
    }
  },

  emits: [ 'show', 'hide' ],

  setup (props, { slots, emit }) {
    let animating = false, doneFn, element;
    let timer = null, timerFallback = null, animListener, lastEvent;

    function cleanup () {
      doneFn && doneFn();
      doneFn = null;
      animating = false;

      if (timer !== null) {
        clearTimeout(timer);
        timer = null;
      }

      if (timerFallback !== null) {
        clearTimeout(timerFallback);
        timerFallback = null;
      }

      element !== void 0 && element.removeEventListener('transitionend', animListener);
      animListener = null;
    }

    function begin (el, height, done) {
      // here overflowY is 'hidden'
      if (height !== void 0) {
        el.style.height = `${ height }px`;
      }
      el.style.transition = `height ${ props.duration }ms cubic-bezier(.25, .8, .50, 1)`;

      animating = true;
      doneFn = done;
    }

    function end (el, event) {
      el.style.overflowY = null;
      el.style.height = null;
      el.style.transition = null;
      cleanup();
      event !== lastEvent && emit(event);
    }

    function onEnter (el, done) {
      let pos = 0;
      element = el;

      // if animationg overflowY is already 'hidden'
      if (animating === true) {
        cleanup();
        pos = el.offsetHeight === el.scrollHeight ? 0 : void 0;
      }
      else {
        lastEvent = 'hide';
        el.style.overflowY = 'hidden';
      }

      begin(el, pos, done);

      timer = setTimeout(() => {
        timer = null;
        el.style.height = `${ el.scrollHeight }px`;
        animListener = evt => {
          timerFallback = null;

          if (Object(evt) !== evt || evt.target === el) {
            end(el, 'show');
          }
        };
        el.addEventListener('transitionend', animListener);
        timerFallback = setTimeout(animListener, props.duration * 1.1);
      }, 100);
    }

    function onLeave (el, done) {
      let pos;
      element = el;

      if (animating === true) {
        cleanup();
      }
      else {
        lastEvent = 'show';
        // we need to set overflowY 'hidden' before calculating the height
        // or else we get small differences
        el.style.overflowY = 'hidden';
        pos = el.scrollHeight;
      }

      begin(el, pos, done);

      timer = setTimeout(() => {
        timer = null;
        el.style.height = 0;
        animListener = evt => {
          timerFallback = null;

          if (Object(evt) !== evt || evt.target === el) {
            end(el, 'hide');
          }
        };
        el.addEventListener('transitionend', animListener);
        timerFallback = setTimeout(animListener, props.duration * 1.1);
      }, 100);
    }

    onBeforeUnmount(() => {
      animating === true && cleanup();
    });

    return () => h(Transition, {
      css: false,
      appear: props.appear,
      onEnter,
      onLeave
    }, slots.default)
  }
});

const itemGroups = shallowReactive({});
const LINK_PROPS = Object.keys(useRouterLinkProps);

const __nuxt_component_8 = createComponent({
  name: 'QExpansionItem',

  props: {
    ...useRouterLinkProps,
    ...useModelToggleProps,
    ...useDarkProps,

    icon: String,

    label: String,
    labelLines: [ Number, String ],

    caption: String,
    captionLines: [ Number, String ],

    dense: Boolean,

    toggleAriaLabel: String,
    expandIcon: String,
    expandedIcon: String,
    expandIconClass: [ Array, String, Object ],
    duration: {},

    headerInsetLevel: Number,
    contentInsetLevel: Number,

    expandSeparator: Boolean,
    defaultOpened: Boolean,
    hideExpandIcon: Boolean,
    expandIconToggle: Boolean,
    switchToggleSide: Boolean,
    denseToggle: Boolean,
    group: String,
    popup: Boolean,

    headerStyle: [ Array, String, Object ],
    headerClass: [ Array, String, Object ]
  },

  emits: [
    ...useModelToggleEmits,
    'click', 'afterShow', 'afterHide'
  ],

  setup (props, { slots, emit }) {
    const { proxy: { $q } } = getCurrentInstance();
    const isDark = useDark(props, $q);

    const showing = ref(
      props.modelValue !== null
        ? props.modelValue
        : props.defaultOpened
    );

    const blurTargetRef = ref(null);
    const targetUid = useId();

    const { show, hide, toggle } = useModelToggle({ showing });

    let uniqueId, exitGroup;

    const classes = computed(() =>
      'q-expansion-item q-item-type'
      + ` q-expansion-item--${ showing.value === true ? 'expanded' : 'collapsed' }`
      + ` q-expansion-item--${ props.popup === true ? 'popup' : 'standard' }`
    );

    const contentStyle = computed(() => {
      if (props.contentInsetLevel === void 0) {
        return null
      }

      const dir = $q.lang.rtl === true ? 'Right' : 'Left';
      return {
        [ 'padding' + dir ]: (props.contentInsetLevel * 56) + 'px'
      }
    });

    const hasLink = computed(() =>
      props.disable !== true && (
        props.href !== void 0
        || (props.to !== void 0 && props.to !== null && props.to !== '')
      )
    );

    const linkProps = computed(() => {
      const acc = {};
      LINK_PROPS.forEach(key => {
        acc[ key ] = props[ key ];
      });
      return acc
    });

    const isClickable = computed(() =>
      hasLink.value === true || props.expandIconToggle !== true
    );

    const expansionIcon = computed(() => (
      props.expandedIcon !== void 0 && showing.value === true
        ? props.expandedIcon
        : props.expandIcon || $q.iconSet.expansionItem[ props.denseToggle === true ? 'denseIcon' : 'icon' ]
    ));

    const activeToggleIcon = computed(() =>
      props.disable !== true && (hasLink.value === true || props.expandIconToggle === true)
    );

    const headerSlotScope = computed(() => ({
      expanded: showing.value === true,
      detailsId: targetUid.value,
      toggle,
      show,
      hide
    }));

    const toggleAriaAttrs = computed(() => {
      const toggleAriaLabel = props.toggleAriaLabel !== void 0
        ? props.toggleAriaLabel
        : $q.lang.label[ showing.value === true ? 'collapse' : 'expand' ](props.label);

      return {
        role: 'button',
        'aria-expanded': showing.value === true ? 'true' : 'false',
        'aria-controls': targetUid.value,
        'aria-label': toggleAriaLabel
      }
    });

    watch(() => props.group, name => {
      exitGroup !== void 0 && exitGroup();
      name !== void 0 && enterGroup();
    });

    function onHeaderClick (e) {
      hasLink.value !== true && toggle(e);
      emit('click', e);
    }

    function toggleIconKeyboard (e) {
      e.keyCode === 13 && toggleIcon(e, true);
    }

    function toggleIcon (e, keyboard) {
      keyboard !== true && blurTargetRef.value !== null && blurTargetRef.value.focus();
      toggle(e);
      stopAndPrevent(e);
    }

    function onShow () {
      emit('afterShow');
    }

    function onHide () {
      emit('afterHide');
    }

    function enterGroup () {
      if (uniqueId === void 0) {
        uniqueId = uid();
      }

      if (showing.value === true) {
        itemGroups[ props.group ] = uniqueId;
      }

      const show = watch(showing, val => {
        if (val === true) {
          itemGroups[ props.group ] = uniqueId;
        }
        else if (itemGroups[ props.group ] === uniqueId) {
          delete itemGroups[ props.group ];
        }
      });

      const group = watch(
        () => itemGroups[ props.group ],
        (val, oldVal) => {
          if (oldVal === uniqueId && val !== void 0 && val !== uniqueId) {
            hide();
          }
        }
      );

      exitGroup = () => {
        show();
        group();

        if (itemGroups[ props.group ] === uniqueId) {
          delete itemGroups[ props.group ];
        }

        exitGroup = void 0;
      };
    }

    function getToggleIcon () {
      const data = {
        class: [
          'q-focusable relative-position cursor-pointer'
            + `${ props.denseToggle === true && props.switchToggleSide === true ? ' items-end' : '' }`,
          props.expandIconClass
        ],
        side: props.switchToggleSide !== true,
        avatar: props.switchToggleSide
      };

      const child = [
        h(QIcon, {
          class: 'q-expansion-item__toggle-icon'
            + (props.expandedIcon === void 0 && showing.value === true
              ? ' q-expansion-item__toggle-icon--rotated'
              : ''),
          name: expansionIcon.value
        })
      ];

      if (activeToggleIcon.value === true) {
        Object.assign(data, {
          tabindex: 0,
          ...toggleAriaAttrs.value,
          onClick: toggleIcon,
          onKeyup: toggleIconKeyboard
        });

        child.unshift(
          h('div', {
            ref: blurTargetRef,
            class: 'q-expansion-item__toggle-focus q-icon q-focus-helper q-focus-helper--rounded',
            tabindex: -1
          })
        );
      }

      return h(QItemSection, data, () => child)
    }

    function getHeaderChild () {
      let child;

      if (slots.header !== void 0) {
        child = [].concat(slots.header(headerSlotScope.value));
      }
      else {
        child = [
          h(QItemSection, () => [
            h(QItemLabel, { lines: props.labelLines }, () => props.label || ''),

            props.caption
              ? h(QItemLabel, { lines: props.captionLines, caption: true }, () => props.caption)
              : null
          ])
        ];

        props.icon && child[ props.switchToggleSide === true ? 'push' : 'unshift' ](
          h(QItemSection, {
            side: props.switchToggleSide === true,
            avatar: props.switchToggleSide !== true
          }, () => h(QIcon, { name: props.icon }))
        );
      }

      if (props.disable !== true && props.hideExpandIcon !== true) {
        child[ props.switchToggleSide === true ? 'unshift' : 'push' ](
          getToggleIcon()
        );
      }

      return child
    }

    function getHeader () {
      const data = {
        ref: 'item',
        style: props.headerStyle,
        class: props.headerClass,
        dark: isDark.value,
        disable: props.disable,
        dense: props.dense,
        insetLevel: props.headerInsetLevel
      };

      if (isClickable.value === true) {
        data.clickable = true;
        data.onClick = onHeaderClick;

        Object.assign(
          data,
          hasLink.value === true ? linkProps.value : toggleAriaAttrs.value
        );
      }

      return h(QItem, data, getHeaderChild)
    }

    function getTransitionChild () {
      return withDirectives(
        h('div', {
          key: 'e-content',
          class: 'q-expansion-item__content relative-position',
          style: contentStyle.value,
          id: targetUid.value
        }, hSlot(slots.default)),
        [ [
          vShow,
          showing.value
        ] ]
      )
    }

    function getContent () {
      const node = [
        getHeader(),

        h(QSlideTransition, {
          duration: props.duration,
          onShow,
          onHide
        }, getTransitionChild)
      ];

      if (props.expandSeparator === true) {
        node.push(
          h(QSeparator, {
            class: 'q-expansion-item__border q-expansion-item__border--top absolute-top',
            dark: isDark.value
          }),
          h(QSeparator, {
            class: 'q-expansion-item__border q-expansion-item__border--bottom absolute-bottom',
            dark: isDark.value
          })
        );
      }

      return node
    }

    props.group !== void 0 && enterGroup();

    onBeforeUnmount(() => {
      exitGroup !== void 0 && exitGroup();
    });

    return () => h('div', { class: classes.value }, [
      h('div', { class: 'q-expansion-item__container relative-position' }, getContent())
    ])
  }
});

const __nuxt_component_14 = createComponent({
  name: 'QPageContainer',

  setup (_, { slots }) {
    const { proxy: { $q } } = getCurrentInstance();

    const $layout = inject(layoutKey, emptyRenderFn);
    if ($layout === emptyRenderFn) {
      console.error('QPageContainer needs to be child of QLayout');
      return emptyRenderFn
    }

    provide(pageContainerKey, true);

    const style = computed(() => {
      const css = {};

      if ($layout.header.space === true) {
        css.paddingTop = `${ $layout.header.size }px`;
      }
      if ($layout.right.space === true) {
        css[ `padding${ $q.lang.rtl === true ? 'Left' : 'Right' }` ] = `${ $layout.right.size }px`;
      }
      if ($layout.footer.space === true) {
        css.paddingBottom = `${ $layout.footer.size }px`;
      }
      if ($layout.left.space === true) {
        css[ `padding${ $q.lang.rtl === true ? 'Right' : 'Left' }` ] = `${ $layout.left.size }px`;
      }

      return css
    });

    return () => h('div', {
      class: 'q-page-container',
      style: style.value
    }, hSlot(slots.default))
  }
});

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "panel",
  __ssrInlineRender: true,
  setup(__props) {
    const leftDrawerOpen = ref(false);
    function toggleLeftDrawer() {
      leftDrawerOpen.value = !leftDrawerOpen.value;
    }
    function logout() {
      pitLib.auth.clear();
      setTimeout(function() {
        (void 0).replace("/auth");
      }, 200);
    }
    pitLib.auth.get();
    return (_ctx, _push, _parent, _attrs) => {
      const _component_q_layout = __nuxt_component_0;
      const _component_q_header = __nuxt_component_1;
      const _component_q_toolbar = __nuxt_component_2;
      const _component_q_btn = __nuxt_component_2$1;
      const _component_q_toolbar_title = __nuxt_component_4;
      const _component_q_avatar = __nuxt_component_5;
      const _component_q_drawer = __nuxt_component_6;
      const _component_q_list = __nuxt_component_7;
      const _component_q_expansion_item = __nuxt_component_8;
      const _component_center = resolveComponent("center");
      const _component_q_badge = __nuxt_component_2$2;
      const _component_q_card = __nuxt_component_0$1;
      const _component_q_card_section = __nuxt_component_1$1;
      const _component_q_item = QItem;
      const _component_q_item_section = QItemSection;
      const _component_q_page_container = __nuxt_component_14;
      const _directive_ripple = __q_directive_0;
      _push(ssrRenderComponent(_component_q_layout, mergeProps({ view: "hHh lpR fFf" }, _attrs), {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(ssrRenderComponent(_component_q_header, {
              elevated: "",
              class: "bg-primary text-white"
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(ssrRenderComponent(_component_q_toolbar, null, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(ssrRenderComponent(_component_q_btn, {
                          dense: "",
                          flat: "",
                          round: "",
                          icon: "menu",
                          onClick: toggleLeftDrawer
                        }, null, _parent4, _scopeId3));
                        _push4(ssrRenderComponent(_component_q_toolbar_title, {
                          onClick: ($event) => ("navigateTo" in _ctx ? _ctx.navigateTo : unref(navigateTo))("/")
                        }, {
                          default: withCtx((_4, _push5, _parent5, _scopeId4) => {
                            if (_push5) {
                              _push5(ssrRenderComponent(_component_q_avatar, null, {
                                default: withCtx((_5, _push6, _parent6, _scopeId5) => {
                                  if (_push6) {
                                    _push6(`<img src="https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg"${_scopeId5}>`);
                                  } else {
                                    return [
                                      createVNode("img", { src: "https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg" })
                                    ];
                                  }
                                }),
                                _: 1
                              }, _parent5, _scopeId4));
                              _push5(` ${ssrInterpolate(unref(Env).APP.NAME)} Dashboard `);
                            } else {
                              return [
                                createVNode(_component_q_avatar, null, {
                                  default: withCtx(() => [
                                    createVNode("img", { src: "https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg" })
                                  ]),
                                  _: 1
                                }),
                                createTextVNode(" " + toDisplayString(unref(Env).APP.NAME) + " Dashboard ", 1)
                              ];
                            }
                          }),
                          _: 1
                        }, _parent4, _scopeId3));
                      } else {
                        return [
                          createVNode(_component_q_btn, {
                            dense: "",
                            flat: "",
                            round: "",
                            icon: "menu",
                            onClick: toggleLeftDrawer
                          }),
                          createVNode(_component_q_toolbar_title, {
                            onClick: ($event) => ("navigateTo" in _ctx ? _ctx.navigateTo : unref(navigateTo))("/")
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_q_avatar, null, {
                                default: withCtx(() => [
                                  createVNode("img", { src: "https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg" })
                                ]),
                                _: 1
                              }),
                              createTextVNode(" " + toDisplayString(unref(Env).APP.NAME) + " Dashboard ", 1)
                            ]),
                            _: 1
                          }, 8, ["onClick"])
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode(_component_q_toolbar, null, {
                      default: withCtx(() => [
                        createVNode(_component_q_btn, {
                          dense: "",
                          flat: "",
                          round: "",
                          icon: "menu",
                          onClick: toggleLeftDrawer
                        }),
                        createVNode(_component_q_toolbar_title, {
                          onClick: ($event) => ("navigateTo" in _ctx ? _ctx.navigateTo : unref(navigateTo))("/")
                        }, {
                          default: withCtx(() => [
                            createVNode(_component_q_avatar, null, {
                              default: withCtx(() => [
                                createVNode("img", { src: "https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg" })
                              ]),
                              _: 1
                            }),
                            createTextVNode(" " + toDisplayString(unref(Env).APP.NAME) + " Dashboard ", 1)
                          ]),
                          _: 1
                        }, 8, ["onClick"])
                      ]),
                      _: 1
                    })
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_drawer, {
              "show-if-above": "",
              modelValue: leftDrawerOpen.value,
              "onUpdate:modelValue": ($event) => leftDrawerOpen.value = $event,
              side: "left",
              bordered: ""
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<div class="q-pa-md" style="${ssrRenderStyle({ "max-width": "350px" })}"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_component_q_list, {
                    bordered: "",
                    class: "rounded-borders"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      var _a, _b;
                      if (_push4) {
                        _push4(ssrRenderComponent(_component_q_expansion_item, {
                          "expand-separator": "",
                          icon: "account_circle",
                          label: "Account",
                          caption: (_a = unref(pitLib).auth.get()) == null ? void 0 : _a.name
                        }, {
                          default: withCtx((_4, _push5, _parent5, _scopeId4) => {
                            if (_push5) {
                              _push5(ssrRenderComponent(_component_center, null, {
                                default: withCtx((_5, _push6, _parent6, _scopeId5) => {
                                  if (_push6) {
                                    _push6(ssrRenderComponent(_component_q_badge, {
                                      outline: "",
                                      color: "primary",
                                      label: unref(pitLib).auth.get().role.toUpperCase()
                                    }, null, _parent6, _scopeId5));
                                  } else {
                                    return [
                                      createVNode(_component_q_badge, {
                                        outline: "",
                                        color: "primary",
                                        label: unref(pitLib).auth.get().role.toUpperCase()
                                      }, null, 8, ["label"])
                                    ];
                                  }
                                }),
                                _: 1
                              }, _parent5, _scopeId4));
                              _push5(ssrRenderComponent(_component_q_card, null, {
                                default: withCtx((_5, _push6, _parent6, _scopeId5) => {
                                  if (_push6) {
                                    _push6(ssrRenderComponent(_component_q_card_section, null, {
                                      default: withCtx((_6, _push7, _parent7, _scopeId6) => {
                                        if (_push7) {
                                          _push7(ssrRenderComponent(_component_q_btn, { onClick: logout }, {
                                            default: withCtx((_7, _push8, _parent8, _scopeId7) => {
                                              if (_push8) {
                                                _push8(`Logout`);
                                              } else {
                                                return [
                                                  createTextVNode("Logout")
                                                ];
                                              }
                                            }),
                                            _: 1
                                          }, _parent7, _scopeId6));
                                        } else {
                                          return [
                                            createVNode(_component_q_btn, { onClick: logout }, {
                                              default: withCtx(() => [
                                                createTextVNode("Logout")
                                              ]),
                                              _: 1
                                            })
                                          ];
                                        }
                                      }),
                                      _: 1
                                    }, _parent6, _scopeId5));
                                  } else {
                                    return [
                                      createVNode(_component_q_card_section, null, {
                                        default: withCtx(() => [
                                          createVNode(_component_q_btn, { onClick: logout }, {
                                            default: withCtx(() => [
                                              createTextVNode("Logout")
                                            ]),
                                            _: 1
                                          })
                                        ]),
                                        _: 1
                                      })
                                    ];
                                  }
                                }),
                                _: 1
                              }, _parent5, _scopeId4));
                            } else {
                              return [
                                createVNode(_component_center, null, {
                                  default: withCtx(() => [
                                    createVNode(_component_q_badge, {
                                      outline: "",
                                      color: "primary",
                                      label: unref(pitLib).auth.get().role.toUpperCase()
                                    }, null, 8, ["label"])
                                  ]),
                                  _: 1
                                }),
                                createVNode(_component_q_card, null, {
                                  default: withCtx(() => [
                                    createVNode(_component_q_card_section, null, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_btn, { onClick: logout }, {
                                          default: withCtx(() => [
                                            createTextVNode("Logout")
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })
                                  ]),
                                  _: 1
                                })
                              ];
                            }
                          }),
                          _: 1
                        }, _parent4, _scopeId3));
                        _push4(ssrRenderComponent(_component_q_expansion_item, {
                          "expand-separator": "",
                          icon: "person",
                          label: "Users",
                          "header-class": "text-blue"
                        }, {
                          default: withCtx((_4, _push5, _parent5, _scopeId4) => {
                            if (_push5) {
                              _push5(ssrRenderComponent(_component_q_card, null, {
                                default: withCtx((_5, _push6, _parent6, _scopeId5) => {
                                  if (_push6) {
                                    _push6(ssrRenderComponent(_component_q_item, mergeProps({
                                      clickable: "",
                                      to: "/panel/user"
                                    }, ssrGetDirectiveProps(_ctx, _directive_ripple)), {
                                      default: withCtx((_6, _push7, _parent7, _scopeId6) => {
                                        if (_push7) {
                                          _push7(ssrRenderComponent(_component_q_item_section, null, {
                                            default: withCtx((_7, _push8, _parent8, _scopeId7) => {
                                              if (_push8) {
                                                _push8(`<span${_scopeId7}><i class="fa-solid fa-angles-right q-mr-md"${_scopeId7}></i>List</span>`);
                                              } else {
                                                return [
                                                  createVNode("span", null, [
                                                    createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                                    createTextVNode("List")
                                                  ])
                                                ];
                                              }
                                            }),
                                            _: 1
                                          }, _parent7, _scopeId6));
                                        } else {
                                          return [
                                            createVNode(_component_q_item_section, null, {
                                              default: withCtx(() => [
                                                createVNode("span", null, [
                                                  createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                                  createTextVNode("List")
                                                ])
                                              ]),
                                              _: 1
                                            })
                                          ];
                                        }
                                      }),
                                      _: 1
                                    }, _parent6, _scopeId5));
                                    _push6(ssrRenderComponent(_component_q_item, mergeProps({
                                      clickable: "",
                                      to: "/panel/user/create"
                                    }, ssrGetDirectiveProps(_ctx, _directive_ripple)), {
                                      default: withCtx((_6, _push7, _parent7, _scopeId6) => {
                                        if (_push7) {
                                          _push7(ssrRenderComponent(_component_q_item_section, null, {
                                            default: withCtx((_7, _push8, _parent8, _scopeId7) => {
                                              if (_push8) {
                                                _push8(`<span${_scopeId7}><i class="fa-solid fa-plus q-mr-md"${_scopeId7}></i>Create</span>`);
                                              } else {
                                                return [
                                                  createVNode("span", null, [
                                                    createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                                    createTextVNode("Create")
                                                  ])
                                                ];
                                              }
                                            }),
                                            _: 1
                                          }, _parent7, _scopeId6));
                                        } else {
                                          return [
                                            createVNode(_component_q_item_section, null, {
                                              default: withCtx(() => [
                                                createVNode("span", null, [
                                                  createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                                  createTextVNode("Create")
                                                ])
                                              ]),
                                              _: 1
                                            })
                                          ];
                                        }
                                      }),
                                      _: 1
                                    }, _parent6, _scopeId5));
                                  } else {
                                    return [
                                      withDirectives((openBlock(), createBlock(_component_q_item, {
                                        clickable: "",
                                        to: "/panel/user"
                                      }, {
                                        default: withCtx(() => [
                                          createVNode(_component_q_item_section, null, {
                                            default: withCtx(() => [
                                              createVNode("span", null, [
                                                createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                                createTextVNode("List")
                                              ])
                                            ]),
                                            _: 1
                                          })
                                        ]),
                                        _: 1
                                      })), [
                                        [_directive_ripple]
                                      ]),
                                      withDirectives((openBlock(), createBlock(_component_q_item, {
                                        clickable: "",
                                        to: "/panel/user/create"
                                      }, {
                                        default: withCtx(() => [
                                          createVNode(_component_q_item_section, null, {
                                            default: withCtx(() => [
                                              createVNode("span", null, [
                                                createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                                createTextVNode("Create")
                                              ])
                                            ]),
                                            _: 1
                                          })
                                        ]),
                                        _: 1
                                      })), [
                                        [_directive_ripple]
                                      ])
                                    ];
                                  }
                                }),
                                _: 1
                              }, _parent5, _scopeId4));
                            } else {
                              return [
                                createVNode(_component_q_card, null, {
                                  default: withCtx(() => [
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/user"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                              createTextVNode("List")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ]),
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/user/create"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                              createTextVNode("Create")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ])
                                  ]),
                                  _: 1
                                })
                              ];
                            }
                          }),
                          _: 1
                        }, _parent4, _scopeId3));
                        _push4(ssrRenderComponent(_component_q_expansion_item, {
                          "expand-separator": "",
                          icon: "workspace_premium",
                          label: "Plans",
                          "header-class": "text-blue"
                        }, {
                          default: withCtx((_4, _push5, _parent5, _scopeId4) => {
                            if (_push5) {
                              _push5(ssrRenderComponent(_component_q_card, null, {
                                default: withCtx((_5, _push6, _parent6, _scopeId5) => {
                                  if (_push6) {
                                    _push6(ssrRenderComponent(_component_q_item, mergeProps({
                                      clickable: "",
                                      to: "/panel/plan"
                                    }, ssrGetDirectiveProps(_ctx, _directive_ripple)), {
                                      default: withCtx((_6, _push7, _parent7, _scopeId6) => {
                                        if (_push7) {
                                          _push7(ssrRenderComponent(_component_q_item_section, null, {
                                            default: withCtx((_7, _push8, _parent8, _scopeId7) => {
                                              if (_push8) {
                                                _push8(`<span${_scopeId7}><i class="fa-solid fa-angles-right q-mr-md"${_scopeId7}></i>List</span>`);
                                              } else {
                                                return [
                                                  createVNode("span", null, [
                                                    createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                                    createTextVNode("List")
                                                  ])
                                                ];
                                              }
                                            }),
                                            _: 1
                                          }, _parent7, _scopeId6));
                                        } else {
                                          return [
                                            createVNode(_component_q_item_section, null, {
                                              default: withCtx(() => [
                                                createVNode("span", null, [
                                                  createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                                  createTextVNode("List")
                                                ])
                                              ]),
                                              _: 1
                                            })
                                          ];
                                        }
                                      }),
                                      _: 1
                                    }, _parent6, _scopeId5));
                                    _push6(ssrRenderComponent(_component_q_item, mergeProps({
                                      clickable: "",
                                      to: "/panel/plan/purchases"
                                    }, ssrGetDirectiveProps(_ctx, _directive_ripple)), {
                                      default: withCtx((_6, _push7, _parent7, _scopeId6) => {
                                        if (_push7) {
                                          _push7(ssrRenderComponent(_component_q_item_section, null, {
                                            default: withCtx((_7, _push8, _parent8, _scopeId7) => {
                                              if (_push8) {
                                                _push8(`<span${_scopeId7}><i class="fa-solid fa-cart-shopping q-mr-md"${_scopeId7}></i>Purchases</span>`);
                                              } else {
                                                return [
                                                  createVNode("span", null, [
                                                    createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                                    createTextVNode("Purchases")
                                                  ])
                                                ];
                                              }
                                            }),
                                            _: 1
                                          }, _parent7, _scopeId6));
                                        } else {
                                          return [
                                            createVNode(_component_q_item_section, null, {
                                              default: withCtx(() => [
                                                createVNode("span", null, [
                                                  createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                                  createTextVNode("Purchases")
                                                ])
                                              ]),
                                              _: 1
                                            })
                                          ];
                                        }
                                      }),
                                      _: 1
                                    }, _parent6, _scopeId5));
                                  } else {
                                    return [
                                      withDirectives((openBlock(), createBlock(_component_q_item, {
                                        clickable: "",
                                        to: "/panel/plan"
                                      }, {
                                        default: withCtx(() => [
                                          createVNode(_component_q_item_section, null, {
                                            default: withCtx(() => [
                                              createVNode("span", null, [
                                                createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                                createTextVNode("List")
                                              ])
                                            ]),
                                            _: 1
                                          })
                                        ]),
                                        _: 1
                                      })), [
                                        [_directive_ripple]
                                      ]),
                                      withDirectives((openBlock(), createBlock(_component_q_item, {
                                        clickable: "",
                                        to: "/panel/plan/purchases"
                                      }, {
                                        default: withCtx(() => [
                                          createVNode(_component_q_item_section, null, {
                                            default: withCtx(() => [
                                              createVNode("span", null, [
                                                createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                                createTextVNode("Purchases")
                                              ])
                                            ]),
                                            _: 1
                                          })
                                        ]),
                                        _: 1
                                      })), [
                                        [_directive_ripple]
                                      ])
                                    ];
                                  }
                                }),
                                _: 1
                              }, _parent5, _scopeId4));
                            } else {
                              return [
                                createVNode(_component_q_card, null, {
                                  default: withCtx(() => [
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/plan"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                              createTextVNode("List")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ]),
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/plan/purchases"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                              createTextVNode("Purchases")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ])
                                  ]),
                                  _: 1
                                })
                              ];
                            }
                          }),
                          _: 1
                        }, _parent4, _scopeId3));
                      } else {
                        return [
                          createVNode(_component_q_expansion_item, {
                            "expand-separator": "",
                            icon: "account_circle",
                            label: "Account",
                            caption: (_b = unref(pitLib).auth.get()) == null ? void 0 : _b.name
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_center, null, {
                                default: withCtx(() => [
                                  createVNode(_component_q_badge, {
                                    outline: "",
                                    color: "primary",
                                    label: unref(pitLib).auth.get().role.toUpperCase()
                                  }, null, 8, ["label"])
                                ]),
                                _: 1
                              }),
                              createVNode(_component_q_card, null, {
                                default: withCtx(() => [
                                  createVNode(_component_q_card_section, null, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_btn, { onClick: logout }, {
                                        default: withCtx(() => [
                                          createTextVNode("Logout")
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })
                                ]),
                                _: 1
                              })
                            ]),
                            _: 1
                          }, 8, ["caption"]),
                          createVNode(_component_q_expansion_item, {
                            "expand-separator": "",
                            icon: "person",
                            label: "Users",
                            "header-class": "text-blue"
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_q_card, null, {
                                default: withCtx(() => [
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/user"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                            createTextVNode("List")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ]),
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/user/create"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                            createTextVNode("Create")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ])
                                ]),
                                _: 1
                              })
                            ]),
                            _: 1
                          }),
                          createVNode(_component_q_expansion_item, {
                            "expand-separator": "",
                            icon: "workspace_premium",
                            label: "Plans",
                            "header-class": "text-blue"
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_q_card, null, {
                                default: withCtx(() => [
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/plan"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                            createTextVNode("List")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ]),
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/plan/purchases"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                            createTextVNode("Purchases")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ])
                                ]),
                                _: 1
                              })
                            ]),
                            _: 1
                          })
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(`</div>`);
                } else {
                  return [
                    createVNode("div", {
                      class: "q-pa-md",
                      style: { "max-width": "350px" }
                    }, [
                      createVNode(_component_q_list, {
                        bordered: "",
                        class: "rounded-borders"
                      }, {
                        default: withCtx(() => {
                          var _a;
                          return [
                            createVNode(_component_q_expansion_item, {
                              "expand-separator": "",
                              icon: "account_circle",
                              label: "Account",
                              caption: (_a = unref(pitLib).auth.get()) == null ? void 0 : _a.name
                            }, {
                              default: withCtx(() => [
                                createVNode(_component_center, null, {
                                  default: withCtx(() => [
                                    createVNode(_component_q_badge, {
                                      outline: "",
                                      color: "primary",
                                      label: unref(pitLib).auth.get().role.toUpperCase()
                                    }, null, 8, ["label"])
                                  ]),
                                  _: 1
                                }),
                                createVNode(_component_q_card, null, {
                                  default: withCtx(() => [
                                    createVNode(_component_q_card_section, null, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_btn, { onClick: logout }, {
                                          default: withCtx(() => [
                                            createTextVNode("Logout")
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })
                                  ]),
                                  _: 1
                                })
                              ]),
                              _: 1
                            }, 8, ["caption"]),
                            createVNode(_component_q_expansion_item, {
                              "expand-separator": "",
                              icon: "person",
                              label: "Users",
                              "header-class": "text-blue"
                            }, {
                              default: withCtx(() => [
                                createVNode(_component_q_card, null, {
                                  default: withCtx(() => [
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/user"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                              createTextVNode("List")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ]),
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/user/create"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                              createTextVNode("Create")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ])
                                  ]),
                                  _: 1
                                })
                              ]),
                              _: 1
                            }),
                            createVNode(_component_q_expansion_item, {
                              "expand-separator": "",
                              icon: "workspace_premium",
                              label: "Plans",
                              "header-class": "text-blue"
                            }, {
                              default: withCtx(() => [
                                createVNode(_component_q_card, null, {
                                  default: withCtx(() => [
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/plan"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                              createTextVNode("List")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ]),
                                    withDirectives((openBlock(), createBlock(_component_q_item, {
                                      clickable: "",
                                      to: "/panel/plan/purchases"
                                    }, {
                                      default: withCtx(() => [
                                        createVNode(_component_q_item_section, null, {
                                          default: withCtx(() => [
                                            createVNode("span", null, [
                                              createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                              createTextVNode("Purchases")
                                            ])
                                          ]),
                                          _: 1
                                        })
                                      ]),
                                      _: 1
                                    })), [
                                      [_directive_ripple]
                                    ])
                                  ]),
                                  _: 1
                                })
                              ]),
                              _: 1
                            })
                          ];
                        }),
                        _: 1
                      })
                    ])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(ssrRenderComponent(_component_q_page_container, null, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  ssrRenderSlot(_ctx.$slots, "default", {}, null, _push3, _parent3, _scopeId2);
                } else {
                  return [
                    renderSlot(_ctx.$slots, "default")
                  ];
                }
              }),
              _: 3
            }, _parent2, _scopeId));
          } else {
            return [
              createVNode(_component_q_header, {
                elevated: "",
                class: "bg-primary text-white"
              }, {
                default: withCtx(() => [
                  createVNode(_component_q_toolbar, null, {
                    default: withCtx(() => [
                      createVNode(_component_q_btn, {
                        dense: "",
                        flat: "",
                        round: "",
                        icon: "menu",
                        onClick: toggleLeftDrawer
                      }),
                      createVNode(_component_q_toolbar_title, {
                        onClick: ($event) => ("navigateTo" in _ctx ? _ctx.navigateTo : unref(navigateTo))("/")
                      }, {
                        default: withCtx(() => [
                          createVNode(_component_q_avatar, null, {
                            default: withCtx(() => [
                              createVNode("img", { src: "https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg" })
                            ]),
                            _: 1
                          }),
                          createTextVNode(" " + toDisplayString(unref(Env).APP.NAME) + " Dashboard ", 1)
                        ]),
                        _: 1
                      }, 8, ["onClick"])
                    ]),
                    _: 1
                  })
                ]),
                _: 1
              }),
              createVNode(_component_q_drawer, {
                "show-if-above": "",
                modelValue: leftDrawerOpen.value,
                "onUpdate:modelValue": ($event) => leftDrawerOpen.value = $event,
                side: "left",
                bordered: ""
              }, {
                default: withCtx(() => [
                  createVNode("div", {
                    class: "q-pa-md",
                    style: { "max-width": "350px" }
                  }, [
                    createVNode(_component_q_list, {
                      bordered: "",
                      class: "rounded-borders"
                    }, {
                      default: withCtx(() => {
                        var _a;
                        return [
                          createVNode(_component_q_expansion_item, {
                            "expand-separator": "",
                            icon: "account_circle",
                            label: "Account",
                            caption: (_a = unref(pitLib).auth.get()) == null ? void 0 : _a.name
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_center, null, {
                                default: withCtx(() => [
                                  createVNode(_component_q_badge, {
                                    outline: "",
                                    color: "primary",
                                    label: unref(pitLib).auth.get().role.toUpperCase()
                                  }, null, 8, ["label"])
                                ]),
                                _: 1
                              }),
                              createVNode(_component_q_card, null, {
                                default: withCtx(() => [
                                  createVNode(_component_q_card_section, null, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_btn, { onClick: logout }, {
                                        default: withCtx(() => [
                                          createTextVNode("Logout")
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })
                                ]),
                                _: 1
                              })
                            ]),
                            _: 1
                          }, 8, ["caption"]),
                          createVNode(_component_q_expansion_item, {
                            "expand-separator": "",
                            icon: "person",
                            label: "Users",
                            "header-class": "text-blue"
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_q_card, null, {
                                default: withCtx(() => [
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/user"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                            createTextVNode("List")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ]),
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/user/create"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-plus q-mr-md" }),
                                            createTextVNode("Create")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ])
                                ]),
                                _: 1
                              })
                            ]),
                            _: 1
                          }),
                          createVNode(_component_q_expansion_item, {
                            "expand-separator": "",
                            icon: "workspace_premium",
                            label: "Plans",
                            "header-class": "text-blue"
                          }, {
                            default: withCtx(() => [
                              createVNode(_component_q_card, null, {
                                default: withCtx(() => [
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/plan"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-angles-right q-mr-md" }),
                                            createTextVNode("List")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ]),
                                  withDirectives((openBlock(), createBlock(_component_q_item, {
                                    clickable: "",
                                    to: "/panel/plan/purchases"
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_q_item_section, null, {
                                        default: withCtx(() => [
                                          createVNode("span", null, [
                                            createVNode("i", { class: "fa-solid fa-cart-shopping q-mr-md" }),
                                            createTextVNode("Purchases")
                                          ])
                                        ]),
                                        _: 1
                                      })
                                    ]),
                                    _: 1
                                  })), [
                                    [_directive_ripple]
                                  ])
                                ]),
                                _: 1
                              })
                            ]),
                            _: 1
                          })
                        ];
                      }),
                      _: 1
                    })
                  ])
                ]),
                _: 1
              }, 8, ["modelValue", "onUpdate:modelValue"]),
              createVNode(_component_q_page_container, null, {
                default: withCtx(() => [
                  renderSlot(_ctx.$slots, "default")
                ]),
                _: 3
              })
            ];
          }
        }),
        _: 3
      }, _parent));
    };
  }
});
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("layouts/panel.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};

export { _sfc_main as default };
//# sourceMappingURL=panel-DjnfSh_6.mjs.map
