import { markRaw, defineComponent, inject, hasInjectionContext, version, ref, watchEffect, watch, getCurrentInstance, h as h$3, computed, unref, provide, shallowReactive, Suspense, nextTick, Transition, useSSRContext, mergeProps, withCtx, createVNode, createApp, effectScope, reactive, onErrorCaptured, onServerPrefetch, resolveDynamicComponent, toRef, shallowRef, isReadonly, isRef, isShallow, isReactive, toRaw, defineAsyncComponent } from 'vue';
import { u as useRuntimeConfig$1, n as joinRelativeURL, $ as $fetch, w as withQuery, o as hasProtocol, p as parseURL, q as isScriptProtocol, j as joinURL, k as createError$1, r as defu, t as sanitizeStatusCode, v as createHooks, x as defuFn, y as klona, z as toRouteMatcher, A as createRouter$1 } from '../runtime.mjs';
import { getActiveHead } from 'unhead';
import { defineHeadPlugin, composableNames, unpackMeta } from '@unhead/shared';
import { useRoute as useRoute$1, RouterView, createMemoryHistory, createRouter, START_LOCATION } from 'vue-router';
import { ssrRenderComponent, ssrRenderSuspense, ssrRenderVNode } from 'vue/server-renderer';

function createContext$1(opts = {}) {
  let currentInstance;
  let isSingleton = false;
  const checkConflict = (instance) => {
    if (currentInstance && currentInstance !== instance) {
      throw new Error("Context conflict");
    }
  };
  let als;
  if (opts.asyncContext) {
    const _AsyncLocalStorage = opts.AsyncLocalStorage || globalThis.AsyncLocalStorage;
    if (_AsyncLocalStorage) {
      als = new _AsyncLocalStorage();
    } else {
      console.warn("[unctx] `AsyncLocalStorage` is not provided.");
    }
  }
  const _getCurrentInstance = () => {
    if (als && currentInstance === void 0) {
      const instance = als.getStore();
      if (instance !== void 0) {
        return instance;
      }
    }
    return currentInstance;
  };
  return {
    use: () => {
      const _instance = _getCurrentInstance();
      if (_instance === void 0) {
        throw new Error("Context is not available");
      }
      return _instance;
    },
    tryUse: () => {
      return _getCurrentInstance();
    },
    set: (instance, replace) => {
      if (!replace) {
        checkConflict(instance);
      }
      currentInstance = instance;
      isSingleton = true;
    },
    unset: () => {
      currentInstance = void 0;
      isSingleton = false;
    },
    call: (instance, callback) => {
      checkConflict(instance);
      currentInstance = instance;
      try {
        return als ? als.run(instance, callback) : callback();
      } finally {
        if (!isSingleton) {
          currentInstance = void 0;
        }
      }
    },
    async callAsync(instance, callback) {
      currentInstance = instance;
      const onRestore = () => {
        currentInstance = instance;
      };
      const onLeave = () => currentInstance === instance ? onRestore : void 0;
      asyncHandlers$1.add(onLeave);
      try {
        const r = als ? als.run(instance, callback) : callback();
        if (!isSingleton) {
          currentInstance = void 0;
        }
        return await r;
      } finally {
        asyncHandlers$1.delete(onLeave);
      }
    }
  };
}
function createNamespace$1(defaultOpts = {}) {
  const contexts = {};
  return {
    get(key, opts = {}) {
      if (!contexts[key]) {
        contexts[key] = createContext$1({ ...defaultOpts, ...opts });
      }
      contexts[key];
      return contexts[key];
    }
  };
}
const _globalThis$1 = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof global !== "undefined" ? global : {};
const globalKey$2 = "__unctx__";
const defaultNamespace = _globalThis$1[globalKey$2] || (_globalThis$1[globalKey$2] = createNamespace$1());
const getContext = (key, opts = {}) => defaultNamespace.get(key, opts);
const asyncHandlersKey$1 = "__unctx_async_handlers__";
const asyncHandlers$1 = _globalThis$1[asyncHandlersKey$1] || (_globalThis$1[asyncHandlersKey$1] = /* @__PURE__ */ new Set());

const defaultLang = {
  isoName: 'en-US',
  nativeName: 'English (US)',
  label: {
    clear: 'Clear',
    ok: 'OK',
    cancel: 'Cancel',
    close: 'Close',
    set: 'Set',
    select: 'Select',
    reset: 'Reset',
    remove: 'Remove',
    update: 'Update',
    create: 'Create',
    search: 'Search',
    filter: 'Filter',
    refresh: 'Refresh',
    expand: label => (label ? `Expand "${ label }"` : 'Expand'),
    collapse: label => (label ? `Collapse "${ label }"` : 'Collapse')
  },
  date: {
    days: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    daysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    firstDayOfWeek: 0, // 0-6, 0 - Sunday, 1 Monday, ...
    format24h: false,
    pluralDay: 'days'
  },
  table: {
    noData: 'No data available',
    noResults: 'No matching records found',
    loading: 'Loading...',
    selectedRecords: rows => (
      rows === 1
        ? '1 record selected.'
        : (rows === 0 ? 'No' : rows) + ' records selected.'
    ),
    recordsPerPage: 'Records per page:',
    allRows: 'All',
    pagination: (start, end, total) => start + '-' + end + ' of ' + total,
    columns: 'Columns'
  },
  editor: {
    url: 'URL',
    bold: 'Bold',
    italic: 'Italic',
    strikethrough: 'Strikethrough',
    underline: 'Underline',
    unorderedList: 'Unordered List',
    orderedList: 'Ordered List',
    subscript: 'Subscript',
    superscript: 'Superscript',
    hyperlink: 'Hyperlink',
    toggleFullscreen: 'Toggle Fullscreen',
    quote: 'Quote',
    left: 'Left align',
    center: 'Center align',
    right: 'Right align',
    justify: 'Justify align',
    print: 'Print',
    outdent: 'Decrease indentation',
    indent: 'Increase indentation',
    removeFormat: 'Remove formatting',
    formatting: 'Formatting',
    fontSize: 'Font Size',
    align: 'Align',
    hr: 'Insert Horizontal Rule',
    undo: 'Undo',
    redo: 'Redo',
    heading1: 'Heading 1',
    heading2: 'Heading 2',
    heading3: 'Heading 3',
    heading4: 'Heading 4',
    heading5: 'Heading 5',
    heading6: 'Heading 6',
    paragraph: 'Paragraph',
    code: 'Code',
    size1: 'Very small',
    size2: 'A bit small',
    size3: 'Normal',
    size4: 'Medium-large',
    size5: 'Big',
    size6: 'Very big',
    size7: 'Maximum',
    defaultFont: 'Default Font',
    viewSource: 'View Source'
  },
  tree: {
    noNodes: 'No nodes available',
    noResults: 'No matching nodes found'
  }
};

const iconSet = {
  name: 'material-icons',
  type: {
    positive: 'check_circle',
    negative: 'warning',
    info: 'info',
    warning: 'priority_high'
  },
  arrow: {
    up: 'arrow_upward',
    right: 'arrow_forward',
    down: 'arrow_downward',
    left: 'arrow_back',
    dropdown: 'arrow_drop_down'
  },
  chevron: {
    left: 'chevron_left',
    right: 'chevron_right'
  },
  colorPicker: {
    spectrum: 'gradient',
    tune: 'tune',
    palette: 'style'
  },
  pullToRefresh: {
    icon: 'refresh'
  },
  carousel: {
    left: 'chevron_left',
    right: 'chevron_right',
    up: 'keyboard_arrow_up',
    down: 'keyboard_arrow_down',
    navigationIcon: 'lens'
  },
  chip: {
    remove: 'cancel',
    selected: 'check'
  },
  datetime: {
    arrowLeft: 'chevron_left',
    arrowRight: 'chevron_right',
    now: 'access_time',
    today: 'today'
  },
  editor: {
    bold: 'format_bold',
    italic: 'format_italic',
    strikethrough: 'strikethrough_s',
    underline: 'format_underlined',
    unorderedList: 'format_list_bulleted',
    orderedList: 'format_list_numbered',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'link',
    toggleFullscreen: 'fullscreen',
    quote: 'format_quote',
    left: 'format_align_left',
    center: 'format_align_center',
    right: 'format_align_right',
    justify: 'format_align_justify',
    print: 'print',
    outdent: 'format_indent_decrease',
    indent: 'format_indent_increase',
    removeFormat: 'format_clear',
    formatting: 'text_format',
    fontSize: 'format_size',
    align: 'format_align_left',
    hr: 'remove',
    undo: 'undo',
    redo: 'redo',
    heading: 'format_size',
    code: 'code',
    size: 'format_size',
    font: 'font_download',
    viewSource: 'code'
  },
  expansionItem: {
    icon: 'keyboard_arrow_down',
    denseIcon: 'arrow_drop_down'
  },
  fab: {
    icon: 'add',
    activeIcon: 'close'
  },
  field: {
    clear: 'cancel',
    error: 'error'
  },
  pagination: {
    first: 'first_page',
    prev: 'keyboard_arrow_left',
    next: 'keyboard_arrow_right',
    last: 'last_page'
  },
  rating: {
    icon: 'grade'
  },
  stepper: {
    done: 'check',
    active: 'edit',
    error: 'warning'
  },
  tabs: {
    left: 'chevron_left',
    right: 'chevron_right',
    up: 'keyboard_arrow_up',
    down: 'keyboard_arrow_down'
  },
  table: {
    arrowUp: 'arrow_upward',
    warning: 'warning',
    firstPage: 'first_page',
    prevPage: 'chevron_left',
    nextPage: 'chevron_right',
    lastPage: 'last_page'
  },
  tree: {
    icon: 'play_arrow'
  },
  uploader: {
    done: 'done',
    clear: 'clear',
    add: 'add_box',
    upload: 'cloud_upload',
    removeQueue: 'clear_all',
    removeUploaded: 'done_all'
  }
};

function createComponent (raw) { return markRaw(defineComponent(raw)) }
function createDirective (raw) { return markRaw(raw) }

const createReactivePlugin = (state, plugin) => {
      Object.assign(plugin, state);
      return plugin
    }
  ;

const listenOpts = {
  hasPassive: false,
  passiveCapture: true,
  notPassiveCapture: true
};

try {
  const opts = Object.defineProperty({}, 'passive', {
    get () {
      Object.assign(listenOpts, {
        hasPassive: true,
        passive: { passive: true },
        notPassive: { passive: false },
        passiveCapture: { passive: true, capture: true },
        notPassiveCapture: { passive: false, capture: true }
      });
    }
  });
  window.addEventListener('qtest', null, opts);
  window.removeEventListener('qtest', null, opts);
}
catch (_) {}

function noop () {}

function position (e) {
  if (e.touches && e.touches[ 0 ]) {
    e = e.touches[ 0 ];
  }
  else if (e.changedTouches && e.changedTouches[ 0 ]) {
    e = e.changedTouches[ 0 ];
  }
  else if (e.targetTouches && e.targetTouches[ 0 ]) {
    e = e.targetTouches[ 0 ];
  }

  return {
    top: e.clientY,
    left: e.clientX
  }
}

function getEventPath (e) {
  if (e.path) {
    return e.path
  }
  if (e.composedPath) {
    return e.composedPath()
  }

  const path = [];
  let el = e.target;

  while (el) {
    path.push(el);

    if (el.tagName === 'HTML') {
      path.push(document);
      path.push(window);
      return path
    }

    el = el.parentElement;
  }
}

function stop (e) {
  e.stopPropagation();
}

function prevent (e) {
  e.cancelable !== false && e.preventDefault();
}

function stopAndPrevent (e) {
  e.cancelable !== false && e.preventDefault();
  e.stopPropagation();
}

function addEvt (ctx, targetName, events) {
  const name = `__q_${ targetName }_evt`;

  ctx[ name ] = ctx[ name ] !== void 0
    ? ctx[ name ].concat(events)
    : events;

  events.forEach(evt => {
    evt[ 0 ].addEventListener(evt[ 1 ], ctx[ evt[ 2 ] ], listenOpts[ evt[ 3 ] ]);
  });
}

function cleanEvt (ctx, targetName) {
  const name = `__q_${ targetName }_evt`;

  if (ctx[ name ] !== void 0) {
    ctx[ name ].forEach(evt => {
      evt[ 0 ].removeEventListener(evt[ 1 ], ctx[ evt[ 2 ] ], listenOpts[ evt[ 3 ] ]);
    });
    ctx[ name ] = void 0;
  }
}

/* eslint-disable no-useless-escape */


/**
 * __ QUASAR_SSR __            -> runs on SSR on client or server
 * __ QUASAR_SSR_SERVER __     -> runs on SSR on server
 * __ QUASAR_SSR_CLIENT __     -> runs on SSR on client
 * __ QUASAR_SSR_PWA __        -> built with SSR+PWA; may run on SSR on client or on PWA client
 *                              (needs runtime detection)
 */

const isRuntimeSsrPreHydration = { value: true }
  ;

function getMatch (userAgent, platformMatch) {
  const match = /(edg|edge|edga|edgios)\/([\w.]+)/.exec(userAgent)
    || /(opr)[\/]([\w.]+)/.exec(userAgent)
    || /(vivaldi)[\/]([\w.]+)/.exec(userAgent)
    || /(chrome|crios)[\/]([\w.]+)/.exec(userAgent)
    || /(version)(applewebkit)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent)
    || /(webkit)[\/]([\w.]+).*(version)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent)
    || /(firefox|fxios)[\/]([\w.]+)/.exec(userAgent)
    || /(webkit)[\/]([\w.]+)/.exec(userAgent)
    || /(opera)(?:.*version|)[\/]([\w.]+)/.exec(userAgent)
    || [];

  return {
    browser: match[ 5 ] || match[ 3 ] || match[ 1 ] || '',
    version: match[ 4 ] || match[ 2 ] || '0',
    platform: platformMatch[ 0 ] || ''
  }
}

function getPlatformMatch (userAgent) {
  return /(ipad)/.exec(userAgent)
    || /(ipod)/.exec(userAgent)
    || /(windows phone)/.exec(userAgent)
    || /(iphone)/.exec(userAgent)
    || /(kindle)/.exec(userAgent)
    || /(silk)/.exec(userAgent)
    || /(android)/.exec(userAgent)
    || /(win)/.exec(userAgent)
    || /(mac)/.exec(userAgent)
    || /(linux)/.exec(userAgent)
    || /(cros)/.exec(userAgent)
    // TODO: Remove BlackBerry detection. BlackBerry OS, BlackBerry 10, and BlackBerry PlayBook OS
    // is officially dead as of January 4, 2022 (https://www.blackberry.com/us/en/support/devices/end-of-life)
    || /(playbook)/.exec(userAgent)
    || /(bb)/.exec(userAgent)
    || /(blackberry)/.exec(userAgent)
    || []
}

function getPlatform (UA) {
  const
    userAgent = UA.toLowerCase(),
    platformMatch = getPlatformMatch(userAgent),
    matched = getMatch(userAgent, platformMatch),
    browser = {};

  if (matched.browser) {
    browser[ matched.browser ] = true;
    browser.version = matched.version;
    browser.versionNumber = parseInt(matched.version, 10);
  }

  if (matched.platform) {
    browser[ matched.platform ] = true;
  }

  const knownMobiles = browser.android
    || browser.ios
    || browser.bb
    || browser.blackberry
    || browser.ipad
    || browser.iphone
    || browser.ipod
    || browser.kindle
    || browser.playbook
    || browser.silk
    || browser[ 'windows phone' ];

  // These are all considered mobile platforms, meaning they run a mobile browser
  if (
    knownMobiles === true
    || userAgent.indexOf('mobile') !== -1
  ) {
    browser.mobile = true;
  }
  // If it's not mobile we should consider it's desktop platform, meaning it runs a desktop browser
  // It's a workaround for anonymized user agents
  // (browser.cros || browser.mac || browser.linux || browser.win)
  else {
    browser.desktop = true;
  }

  if (browser[ 'windows phone' ]) {
    browser.winphone = true;
    delete browser[ 'windows phone' ];
  }

  if (browser.edga || browser.edgios || browser.edg) {
    browser.edge = true;
    matched.browser = 'edge';
  }
  else if (browser.crios) {
    browser.chrome = true;
    matched.browser = 'chrome';
  }
  else if (browser.fxios) {
    browser.firefox = true;
    matched.browser = 'firefox';
  }

  // Set iOS if on iPod, iPad or iPhone
  if (browser.ipod || browser.ipad || browser.iphone) {
    browser.ios = true;
  }

  if (browser.vivaldi) {
    matched.browser = 'vivaldi';
    browser.vivaldi = true;
  }

  // TODO: The assumption about WebKit based browsers below is not completely accurate.
  // Google released Blink(a fork of WebKit) engine on April 3, 2013, which is really different than WebKit today.
  // Today, one might want to check for WebKit to deal with its bugs, which is used on all browsers on iOS, and Safari browser on all platforms.
  if (
    // Chrome, Opera 15+, Vivaldi and Safari are webkit based browsers
    browser.chrome
    || browser.opr
    || browser.safari
    || browser.vivaldi
    // we expect unknown, non iOS mobile browsers to be webkit based
    || (
      browser.mobile === true
      && browser.ios !== true
      && knownMobiles !== true
    )
  ) {
    browser.webkit = true;
  }

  // Opera 15+ are identified as opr
  if (browser.opr) {
    matched.browser = 'opera';
    browser.opera = true;
  }

  // Some browsers are marked as Safari but are not
  if (browser.safari) {
    if (browser.blackberry || browser.bb) {
      matched.browser = 'blackberry';
      browser.blackberry = true;
    }
    else if (browser.playbook) {
      matched.browser = 'playbook';
      browser.playbook = true;
    }
    else if (browser.android) {
      matched.browser = 'android';
      browser.android = true;
    }
    else if (browser.kindle) {
      matched.browser = 'kindle';
      browser.kindle = true;
    }
    else if (browser.silk) {
      matched.browser = 'silk';
      browser.silk = true;
    }
  }

  // Assign the name and platform variable
  browser.name = matched.browser;
  browser.platform = matched.platform;

  return browser
}

const ssrClient = {
  has: {
    touch: false,
    webStorage: false
  },
  within: { iframe: false }
};

// We export "client" for hydration error-free parts,
// like touch directives who do not (and must NOT) wait
// for the client takeover;
// Do NOT import this directly in your app, unless you really know
// what you are doing.
const client = ssrClient
  ;

const Platform = {
  install (opts) {
    const { $q } = opts;

    {
      $q.platform = this.parseSSR(opts.ssrContext);
    }
  }
};

{
  Platform.parseSSR = (ssrContext) => {
    const userAgent = ssrContext.req.headers[ 'user-agent' ] || ssrContext.req.headers[ 'User-Agent' ] || '';
    return {
      ...client,
      userAgent,
      is: getPlatform(userAgent)
    }
  };
}

const Screen = createReactivePlugin({
  width: 0,
  height: 0,
  name: 'xs',

  sizes: {
    sm: 600,
    md: 1024,
    lg: 1440,
    xl: 1920
  },

  lt: {
    sm: true,
    md: true,
    lg: true,
    xl: true
  },
  gt: {
    xs: false,
    sm: false,
    md: false,
    lg: false
  },

  xs: true,
  sm: false,
  md: false,
  lg: false,
  xl: false
}, {
  setSizes: noop,
  setDebounce: noop,

  install ({ $q, onSSRHydrated }) {
    $q.screen = this;

    return
  }
});

const Plugin$2 = createReactivePlugin({
  isActive: false,
  mode: false
}, {
  __media: void 0,

  set (val) {
    return
  },

  toggle () {
  },

  install ({ $q, ssrContext }) {
    const { dark } = $q.config;

    {
      this.isActive = dark === true;

      $q.dark = {
        isActive: false,
        mode: false,
        set: val => {
          ssrContext._meta.bodyClasses = ssrContext._meta.bodyClasses
            .replace(' body--light', '')
            .replace(' body--dark', '') + ` body--${ val === true ? 'dark' : 'light' }`;

          $q.dark.isActive = val === true;
          $q.dark.mode = val;
        },
        toggle: () => {
          $q.dark.set($q.dark.isActive === false);
        }
      };

      $q.dark.set(dark);
      return
    }
  }
});

const Dark = Plugin$2;

function getMobilePlatform (is) {
  if (is.ios === true) return 'ios'
  if (is.android === true) return 'android'
}

function getBodyClasses ({ is, has, within }, cfg) {
  const cls = [
    is.desktop === true ? 'desktop' : 'mobile',
    `${ has.touch === false ? 'no-' : '' }touch`
  ];

  if (is.mobile === true) {
    const mobile = getMobilePlatform(is);
    mobile !== void 0 && cls.push('platform-' + mobile);
  }

  if (is.nativeMobile === true) {
    const type = is.nativeMobileWrapper;

    cls.push(type);
    cls.push('native-mobile');

    if (
      is.ios === true
      && (cfg[ type ] === void 0 || cfg[ type ].iosStatusBarPadding !== false)
    ) {
      cls.push('q-ios-padding');
    }
  }
  else if (is.electron === true) {
    cls.push('electron');
  }
  else if (is.bex === true) {
    cls.push('bex');
  }

  within.iframe === true && cls.push('within-iframe');

  return cls
}

const Body = {
  install (opts) {
    {
      const { $q, ssrContext } = opts;
      const cls = getBodyClasses($q.platform, $q.config);

      if ($q.config.screen !== void 0 && $q.config.screen.bodyClass === true) {
        cls.push('screen--xs');
      }

      ssrContext._meta.bodyClasses += cls.join(' ');

      const brand = $q.config.brand;
      if (brand !== void 0) {
        const vars = Object.keys(brand)
          .map(key => `--q-${ key }:${ brand[ key ] };`)
          .join('');

        ssrContext._meta.endingHeadTags += `<style>:root{${ vars }}</style>`;
      }

      return
    }
  }
};

const History = {
  __history: [],
  add: noop,
  remove: noop,

  install ({ $q }) {
    return
  }
};

function getLocale () {
  return
}

const Plugin$1 = createReactivePlugin({
  __qLang: {}
}, {
  // props: object
  // __langConfig: object

  getLocale,

  set (langObject = defaultLang, ssrContext) {
    const lang = {
      ...langObject,
      rtl: langObject.rtl === true,
      getLocale
    };

    {
      if (ssrContext === void 0) {
        console.error('SSR ERROR: second param required: Lang.set(lang, ssrContext)');
        return
      }

      lang.set = ssrContext.$q.lang.set;

      if (ssrContext.$q.config.lang === void 0 || ssrContext.$q.config.lang.noHtmlAttrs !== true) {
        const dir = lang.rtl === true ? 'rtl' : 'ltr';
        const attrs = `lang=${ lang.isoName } dir=${ dir }`;

        ssrContext._meta.htmlAttrs = ssrContext.__qPrevLang !== void 0
          ? ssrContext._meta.htmlAttrs.replace(ssrContext.__qPrevLang, attrs)
          : attrs;

        ssrContext.__qPrevLang = attrs;
      }

      ssrContext.$q.lang = lang;
    }
  },

  install ({ $q, lang, ssrContext }) {
    {
      const initialLang = lang || defaultLang;

      $q.lang = {};
      $q.lang.set = langObject => {
        this.set(langObject, ssrContext);
      };

      $q.lang.set(initialLang);

      // one-time SSR server operation
      if (
        this.props === void 0
        || this.props.isoName !== initialLang.isoName
      ) {
        this.props = { ...initialLang };
      }
    }
  }
});

const Plugin = createReactivePlugin({
  iconMapFn: null,
  __qIconSet: {}
}, {
  // props: object

  set (setObject, ssrContext) {
    const def = { ...setObject };

    {
      if (ssrContext === void 0) {
        console.error('SSR ERROR: second param required: IconSet.set(iconSet, ssrContext)');
        return
      }

      def.set = ssrContext.$q.iconSet.set;
      Object.assign(ssrContext.$q.iconSet, def);
    }
  },

  install ({ $q, iconSet: iconSet$1, ssrContext }) {
    {
      const initialSet = iconSet$1 || iconSet;

      $q.iconMapFn = ssrContext.$q.config.iconMapFn || this.iconMapFn || null;
      $q.iconSet = {};
      $q.iconSet.set = setObject => {
        this.set(setObject, ssrContext);
      };

      $q.iconSet.set(initialSet);

      // one-time SSR server operation
      if (
        this.props === void 0
        || this.props.name !== initialSet.name
      ) {
        this.props = { ...initialSet };
      }
    }
  }
});

const IconSet = Plugin;

const quasarKey = '_q_';
const layoutKey = '_q_l_';
const pageContainerKey = '_q_pc_';
const formKey = '_q_fo_';
const tabsKey = '_q_tabs_';

function emptyRenderFn () {}

function isDeepEqual (a, b) {
  if (a === b) {
    return true
  }

  if (a !== null && b !== null && typeof a === 'object' && typeof b === 'object') {
    if (a.constructor !== b.constructor) {
      return false
    }

    let length, i;

    if (a.constructor === Array) {
      length = a.length;

      if (length !== b.length) {
        return false
      }

      for (i = length; i-- !== 0;) {
        if (isDeepEqual(a[ i ], b[ i ]) !== true) {
          return false
        }
      }

      return true
    }

    if (a.constructor === Map) {
      if (a.size !== b.size) {
        return false
      }

      let iter = a.entries();

      i = iter.next();
      while (i.done !== true) {
        if (b.has(i.value[ 0 ]) !== true) {
          return false
        }
        i = iter.next();
      }

      iter = a.entries();
      i = iter.next();
      while (i.done !== true) {
        if (isDeepEqual(i.value[ 1 ], b.get(i.value[ 0 ])) !== true) {
          return false
        }
        i = iter.next();
      }

      return true
    }

    if (a.constructor === Set) {
      if (a.size !== b.size) {
        return false
      }

      const iter = a.entries();

      i = iter.next();
      while (i.done !== true) {
        if (b.has(i.value[ 0 ]) !== true) {
          return false
        }
        i = iter.next();
      }

      return true
    }

    if (a.buffer != null && a.buffer.constructor === ArrayBuffer) {
      length = a.length;

      if (length !== b.length) {
        return false
      }

      for (i = length; i-- !== 0;) {
        if (a[ i ] !== b[ i ]) {
          return false
        }
      }

      return true
    }

    if (a.constructor === RegExp) {
      return a.source === b.source && a.flags === b.flags
    }

    if (a.valueOf !== Object.prototype.valueOf) {
      return a.valueOf() === b.valueOf()
    }

    if (a.toString !== Object.prototype.toString) {
      return a.toString() === b.toString()
    }

    const keys = Object.keys(a).filter(key => a[ key ] !== void 0);
    length = keys.length;

    if (length !== Object.keys(b).filter(key => b[ key ] !== void 0).length) {
      return false
    }

    for (i = length; i-- !== 0;) {
      const key = keys[ i ];
      if (isDeepEqual(a[ key ], b[ key ]) !== true) {
        return false
      }
    }

    return true
  }

  // true if both NaN, false otherwise
  return a !== a && b !== b // eslint-disable-line no-self-compare
}

// not perfect, but what we ARE interested is for Arrays not to slip in
// as spread operator will mess things up in various areas
function isObject (v) {
  return v !== null && typeof v === 'object' && Array.isArray(v) !== true
}

/**
 * If the list below changes, make sure
 * to also edit /ui/testing/specs/generators/generator.plugin.js
 * on the "autoInstalledPlugins" array
 */
const autoInstalledPlugins = [
  Platform,
  Body,
  Dark,
  Screen,
  History,
  Plugin$1,
  IconSet
];

function installPlugins (pluginOpts, pluginList) {
  pluginList.forEach(Plugin => {
    Plugin.install(pluginOpts);
    Plugin.__installed = true;
  });
}

function prepareApp (app, uiOpts, pluginOpts) {
  app.config.globalProperties.$q = pluginOpts.$q;
  app.provide(quasarKey, pluginOpts.$q);

  installPlugins(pluginOpts, autoInstalledPlugins);

  uiOpts.components !== void 0 && Object.values(uiOpts.components).forEach(c => {
    if (isObject(c) === true && c.name !== void 0) {
      app.component(c.name, c);
    }
  });

  uiOpts.directives !== void 0 && Object.values(uiOpts.directives).forEach(d => {
    if (isObject(d) === true && d.name !== void 0) {
      app.directive(d.name, d);
    }
  });

  uiOpts.plugins !== void 0 && installPlugins(
    pluginOpts,
    Object.values(uiOpts.plugins).filter(
      p => typeof p.install === 'function' && autoInstalledPlugins.includes(p) === false
    )
  );

  if (isRuntimeSsrPreHydration.value === true) {
    pluginOpts.$q.onSSRHydrated = () => {
      pluginOpts.onSSRHydrated.forEach(fn => { fn(); });
      pluginOpts.$q.onSSRHydrated = () => {};
    };
  }
}

const installQuasar = function (parentApp, opts = {}, ssrContext) {
    const $q = {
      version: '2.16.4',
      config: opts.config || {}
    };

    Object.assign(ssrContext, {
      $q,
      _meta: {
        htmlAttrs: '',
        headTags: '',
        endingHeadTags: '',
        bodyClasses: '',
        bodyAttrs: 'data-server-rendered',
        bodyTags: ''
      }
    });

    if (ssrContext._modules === void 0) {
      // not OK. means the SSR build is not using @quasar/ssr-helpers,
      // but we shouldn't crash the app
      ssrContext._modules = [];
    }

    if (ssrContext.onRendered === void 0) {
      // not OK. means the SSR build is not using @quasar/ssr-helpers,
      // but we shouldn't crash the app
      ssrContext.onRendered = () => {};
    }

    parentApp.config.globalProperties.ssrContext = ssrContext;

    prepareApp(parentApp, opts, {
      parentApp,
      $q,
      lang: opts.lang,
      iconSet: opts.iconSet,
      ssrContext
    });
  }

const Notify = {
  setDefaults (opts) {
  },

  registerType (typeName, typeOpts) {
  },

  install ({ $q, parentApp }) {
    $q.notify = this.create = noop
      ;

    $q.notify.setDefaults = this.setDefaults;
    $q.notify.registerType = this.registerType;

    if ($q.config.notify !== void 0) {
      this.setDefaults($q.config.notify);
    }
  }
};

const Quasar = {
  name: 'Quasar',
  version: '2.16.4',

  install: installQuasar,

  // TODO: remove in Qv3 (should only be used through the plugin)
  // We provide a deprecated fallback here
  lang: Plugin$1,

  // TODO: remove in Qv3 (should only be used through the plugin)
  // We provide a deprecated fallback here
  iconSet: IconSet
};

/**
 * Returns the $q instance.
 * Equivalent to `this.$q` inside templates.
 */
function useQuasar () {
  return inject(quasarKey)
}

const appConfig = useRuntimeConfig$1().app;
const baseURL = () => appConfig.baseURL;
const publicAssetsURL = (...path) => {
  const publicBase = appConfig.cdnURL || appConfig.baseURL;
  return path.length ? joinRelativeURL(publicBase, ...path) : publicBase;
};
if (!globalThis.$fetch) {
  globalThis.$fetch = $fetch.create({
    baseURL: baseURL()
  });
}
const nuxtAppCtx = /* @__PURE__ */ getContext("nuxt-app", {
  asyncContext: false
});
const NuxtPluginIndicator = "__nuxt_plugin";
function createNuxtApp(options) {
  let hydratingCount = 0;
  const nuxtApp = {
    _scope: effectScope(),
    provide: void 0,
    globalName: "nuxt",
    versions: {
      get nuxt() {
        return "3.11.1";
      },
      get vue() {
        return nuxtApp.vueApp.version;
      }
    },
    payload: reactive({
      data: {},
      state: {},
      once: /* @__PURE__ */ new Set(),
      _errors: {},
      ...{ serverRendered: true }
    }),
    static: {
      data: {}
    },
    runWithContext: (fn) => nuxtApp._scope.run(() => callWithNuxt(nuxtApp, fn)),
    isHydrating: false,
    deferHydration() {
      if (!nuxtApp.isHydrating) {
        return () => {
        };
      }
      hydratingCount++;
      let called = false;
      return () => {
        if (called) {
          return;
        }
        called = true;
        hydratingCount--;
        if (hydratingCount === 0) {
          nuxtApp.isHydrating = false;
          return nuxtApp.callHook("app:suspense:resolve");
        }
      };
    },
    _asyncDataPromises: {},
    _asyncData: {},
    _payloadRevivers: {},
    ...options
  };
  nuxtApp.hooks = createHooks();
  nuxtApp.hook = nuxtApp.hooks.hook;
  {
    const contextCaller = async function(hooks, args) {
      for (const hook of hooks) {
        await nuxtApp.runWithContext(() => hook(...args));
      }
    };
    nuxtApp.hooks.callHook = (name, ...args) => nuxtApp.hooks.callHookWith(contextCaller, name, ...args);
  }
  nuxtApp.callHook = nuxtApp.hooks.callHook;
  nuxtApp.provide = (name, value) => {
    const $name = "$" + name;
    defineGetter(nuxtApp, $name, value);
    defineGetter(nuxtApp.vueApp.config.globalProperties, $name, value);
  };
  defineGetter(nuxtApp.vueApp, "$nuxt", nuxtApp);
  defineGetter(nuxtApp.vueApp.config.globalProperties, "$nuxt", nuxtApp);
  {
    if (nuxtApp.ssrContext) {
      nuxtApp.ssrContext.nuxt = nuxtApp;
      nuxtApp.ssrContext._payloadReducers = {};
      nuxtApp.payload.path = nuxtApp.ssrContext.url;
    }
    nuxtApp.ssrContext = nuxtApp.ssrContext || {};
    if (nuxtApp.ssrContext.payload) {
      Object.assign(nuxtApp.payload, nuxtApp.ssrContext.payload);
    }
    nuxtApp.ssrContext.payload = nuxtApp.payload;
    nuxtApp.ssrContext.config = {
      public: options.ssrContext.runtimeConfig.public,
      app: options.ssrContext.runtimeConfig.app
    };
  }
  const runtimeConfig = options.ssrContext.runtimeConfig;
  nuxtApp.provide("config", runtimeConfig);
  return nuxtApp;
}
async function applyPlugin(nuxtApp, plugin2) {
  if (plugin2.hooks) {
    nuxtApp.hooks.addHooks(plugin2.hooks);
  }
  if (typeof plugin2 === "function") {
    const { provide: provide2 } = await nuxtApp.runWithContext(() => plugin2(nuxtApp)) || {};
    if (provide2 && typeof provide2 === "object") {
      for (const key in provide2) {
        nuxtApp.provide(key, provide2[key]);
      }
    }
  }
}
async function applyPlugins(nuxtApp, plugins2) {
  var _a, _b;
  const resolvedPlugins = [];
  const unresolvedPlugins = [];
  const parallels = [];
  const errors = [];
  let promiseDepth = 0;
  async function executePlugin(plugin2) {
    var _a2;
    const unresolvedPluginsForThisPlugin = ((_a2 = plugin2.dependsOn) == null ? void 0 : _a2.filter((name) => plugins2.some((p2) => p2._name === name) && !resolvedPlugins.includes(name))) ?? [];
    if (unresolvedPluginsForThisPlugin.length > 0) {
      unresolvedPlugins.push([new Set(unresolvedPluginsForThisPlugin), plugin2]);
    } else {
      const promise = applyPlugin(nuxtApp, plugin2).then(async () => {
        if (plugin2._name) {
          resolvedPlugins.push(plugin2._name);
          await Promise.all(unresolvedPlugins.map(async ([dependsOn, unexecutedPlugin]) => {
            if (dependsOn.has(plugin2._name)) {
              dependsOn.delete(plugin2._name);
              if (dependsOn.size === 0) {
                promiseDepth++;
                await executePlugin(unexecutedPlugin);
              }
            }
          }));
        }
      });
      if (plugin2.parallel) {
        parallels.push(promise.catch((e2) => errors.push(e2)));
      } else {
        await promise;
      }
    }
  }
  for (const plugin2 of plugins2) {
    if (((_a = nuxtApp.ssrContext) == null ? void 0 : _a.islandContext) && ((_b = plugin2.env) == null ? void 0 : _b.islands) === false) {
      continue;
    }
    await executePlugin(plugin2);
  }
  await Promise.all(parallels);
  if (promiseDepth) {
    for (let i2 = 0; i2 < promiseDepth; i2++) {
      await Promise.all(parallels);
    }
  }
  if (errors.length) {
    throw errors[0];
  }
}
// @__NO_SIDE_EFFECTS__
function defineNuxtPlugin(plugin2) {
  if (typeof plugin2 === "function") {
    return plugin2;
  }
  const _name = plugin2._name || plugin2.name;
  delete plugin2.name;
  return Object.assign(plugin2.setup || (() => {
  }), plugin2, { [NuxtPluginIndicator]: true, _name });
}
function callWithNuxt(nuxt, setup, args) {
  const fn = () => args ? setup(...args) : setup();
  {
    return nuxt.vueApp.runWithContext(() => nuxtAppCtx.callAsync(nuxt, fn));
  }
}
// @__NO_SIDE_EFFECTS__
function tryUseNuxtApp() {
  var _a;
  let nuxtAppInstance;
  if (hasInjectionContext()) {
    nuxtAppInstance = (_a = getCurrentInstance()) == null ? void 0 : _a.appContext.app.$nuxt;
  }
  nuxtAppInstance = nuxtAppInstance || nuxtAppCtx.tryUse();
  return nuxtAppInstance || null;
}
// @__NO_SIDE_EFFECTS__
function useNuxtApp() {
  const nuxtAppInstance = /* @__PURE__ */ tryUseNuxtApp();
  if (!nuxtAppInstance) {
    {
      throw new Error("[nuxt] instance unavailable");
    }
  }
  return nuxtAppInstance;
}
// @__NO_SIDE_EFFECTS__
function useRuntimeConfig(_event) {
  return (/* @__PURE__ */ useNuxtApp()).$config;
}
function defineGetter(obj, key, val) {
  Object.defineProperty(obj, key, { get: () => val });
}
const LayoutMetaSymbol = Symbol("layout-meta");
const PageRouteSymbol = Symbol("route");
const useRouter = () => {
  var _a;
  return (_a = /* @__PURE__ */ useNuxtApp()) == null ? void 0 : _a.$router;
};
const useRoute = () => {
  if (hasInjectionContext()) {
    return inject(PageRouteSymbol, (/* @__PURE__ */ useNuxtApp())._route);
  }
  return (/* @__PURE__ */ useNuxtApp())._route;
};
// @__NO_SIDE_EFFECTS__
function defineNuxtRouteMiddleware(middleware) {
  return middleware;
}
const isProcessingMiddleware = () => {
  try {
    if ((/* @__PURE__ */ useNuxtApp())._processingMiddleware) {
      return true;
    }
  } catch {
    return true;
  }
  return false;
};
const navigateTo = (to, options) => {
  if (!to) {
    to = "/";
  }
  const toPath = typeof to === "string" ? to : withQuery(to.path || "/", to.query || {}) + (to.hash || "");
  if (options == null ? void 0 : options.open) {
    return Promise.resolve();
  }
  const isExternal = (options == null ? void 0 : options.external) || hasProtocol(toPath, { acceptRelative: true });
  if (isExternal) {
    if (!(options == null ? void 0 : options.external)) {
      throw new Error("Navigating to an external URL is not allowed by default. Use `navigateTo(url, { external: true })`.");
    }
    const protocol = parseURL(toPath).protocol;
    if (protocol && isScriptProtocol(protocol)) {
      throw new Error(`Cannot navigate to a URL with '${protocol}' protocol.`);
    }
  }
  const inMiddleware = isProcessingMiddleware();
  const router = useRouter();
  const nuxtApp = /* @__PURE__ */ useNuxtApp();
  {
    if (nuxtApp.ssrContext) {
      const fullPath = typeof to === "string" || isExternal ? toPath : router.resolve(to).fullPath || "/";
      const location2 = isExternal ? toPath : joinURL((/* @__PURE__ */ useRuntimeConfig()).app.baseURL, fullPath);
      const redirect = async function(response) {
        await nuxtApp.callHook("app:redirected");
        const encodedLoc = location2.replace(/"/g, "%22");
        nuxtApp.ssrContext._renderResponse = {
          statusCode: sanitizeStatusCode((options == null ? void 0 : options.redirectCode) || 302, 302),
          body: `<!DOCTYPE html><html><head><meta http-equiv="refresh" content="0; url=${encodedLoc}"></head></html>`,
          headers: { location: location2 }
        };
        return response;
      };
      if (!isExternal && inMiddleware) {
        router.afterEach((final) => final.fullPath === fullPath ? redirect(false) : void 0);
        return to;
      }
      return redirect(!inMiddleware ? void 0 : (
        /* abort route navigation */
        false
      ));
    }
  }
  if (isExternal) {
    nuxtApp._scope.stop();
    if (options == null ? void 0 : options.replace) {
      (void 0).replace(toPath);
    } else {
      (void 0).href = toPath;
    }
    if (inMiddleware) {
      if (!nuxtApp.isHydrating) {
        return false;
      }
      return new Promise(() => {
      });
    }
    return Promise.resolve();
  }
  return (options == null ? void 0 : options.replace) ? router.replace(to) : router.push(to);
};
const NUXT_ERROR_SIGNATURE = "__nuxt_error";
const useError = () => toRef((/* @__PURE__ */ useNuxtApp()).payload, "error");
const showError = (error) => {
  const nuxtError = createError(error);
  try {
    const nuxtApp = /* @__PURE__ */ useNuxtApp();
    const error2 = useError();
    if (false)
      ;
    error2.value = error2.value || nuxtError;
  } catch {
    throw nuxtError;
  }
  return nuxtError;
};
const isNuxtError = (error) => !!error && typeof error === "object" && NUXT_ERROR_SIGNATURE in error;
const createError = (error) => {
  const nuxtError = createError$1(error);
  Object.defineProperty(nuxtError, NUXT_ERROR_SIGNATURE, {
    value: true,
    configurable: false,
    writable: false
  });
  return nuxtError;
};
version.startsWith("3");
function resolveUnref(r2) {
  return typeof r2 === "function" ? r2() : unref(r2);
}
function resolveUnrefHeadInput(ref2, lastKey = "") {
  if (ref2 instanceof Promise)
    return ref2;
  const root = resolveUnref(ref2);
  if (!ref2 || !root)
    return root;
  if (Array.isArray(root))
    return root.map((r2) => resolveUnrefHeadInput(r2, lastKey));
  if (typeof root === "object") {
    return Object.fromEntries(
      Object.entries(root).map(([k2, v2]) => {
        if (k2 === "titleTemplate" || k2.startsWith("on"))
          return [k2, unref(v2)];
        return [k2, resolveUnrefHeadInput(v2, k2)];
      })
    );
  }
  return root;
}
defineHeadPlugin({
  hooks: {
    "entries:resolve": function(ctx) {
      for (const entry2 of ctx.entries)
        entry2.resolvedInput = resolveUnrefHeadInput(entry2.input);
    }
  }
});
const headSymbol = "usehead";
const _global = typeof globalThis !== "undefined" ? globalThis : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
const globalKey$1 = "__unhead_injection_handler__";
function setHeadInjectionHandler(handler) {
  _global[globalKey$1] = handler;
}
function injectHead() {
  if (globalKey$1 in _global) {
    return _global[globalKey$1]();
  }
  const head = inject(headSymbol);
  if (!head && "production" !== "production")
    console.warn("Unhead is missing Vue context, falling back to shared context. This may have unexpected results.");
  return head || getActiveHead();
}
function useHead(input, options = {}) {
  const head = options.head || injectHead();
  if (head) {
    if (!head.ssr)
      return clientUseHead(head, input, options);
    return head.push(input, options);
  }
}
function clientUseHead(head, input, options = {}) {
  const deactivated = ref(false);
  const resolvedInput = ref({});
  watchEffect(() => {
    resolvedInput.value = deactivated.value ? {} : resolveUnrefHeadInput(input);
  });
  const entry2 = head.push(resolvedInput.value, options);
  watch(resolvedInput, (e2) => {
    entry2.patch(e2);
  });
  getCurrentInstance();
  return entry2;
}
const coreComposableNames = [
  "injectHead"
];
({
  "@unhead/vue": [...coreComposableNames, ...composableNames]
});
function useSeoMeta(input, options) {
  const { title, titleTemplate, ...meta } = input;
  return useHead({
    title,
    titleTemplate,
    // @ts-expect-error runtime type
    _flatMeta: meta
  }, {
    ...options,
    transform(t2) {
      const meta2 = unpackMeta({ ...t2._flatMeta });
      delete t2._flatMeta;
      return {
        // @ts-expect-error runtime type
        ...t2,
        meta: meta2
      };
    }
  });
}
const unhead_KgADcZ0jPj = /* @__PURE__ */ defineNuxtPlugin({
  name: "nuxt:head",
  enforce: "pre",
  setup(nuxtApp) {
    const head = nuxtApp.ssrContext.head;
    setHeadInjectionHandler(
      // need a fresh instance of the nuxt app to avoid parallel requests interfering with each other
      () => (/* @__PURE__ */ useNuxtApp()).vueApp._context.provides.usehead
    );
    nuxtApp.vueApp.use(head);
  }
});
function createContext(opts = {}) {
  let currentInstance;
  let isSingleton = false;
  const checkConflict = (instance) => {
    if (currentInstance && currentInstance !== instance) {
      throw new Error("Context conflict");
    }
  };
  let als;
  if (opts.asyncContext) {
    const _AsyncLocalStorage = opts.AsyncLocalStorage || globalThis.AsyncLocalStorage;
    if (_AsyncLocalStorage) {
      als = new _AsyncLocalStorage();
    } else {
      console.warn("[unctx] `AsyncLocalStorage` is not provided.");
    }
  }
  const _getCurrentInstance = () => {
    if (als && currentInstance === void 0) {
      const instance = als.getStore();
      if (instance !== void 0) {
        return instance;
      }
    }
    return currentInstance;
  };
  return {
    use: () => {
      const _instance = _getCurrentInstance();
      if (_instance === void 0) {
        throw new Error("Context is not available");
      }
      return _instance;
    },
    tryUse: () => {
      return _getCurrentInstance();
    },
    set: (instance, replace) => {
      if (!replace) {
        checkConflict(instance);
      }
      currentInstance = instance;
      isSingleton = true;
    },
    unset: () => {
      currentInstance = void 0;
      isSingleton = false;
    },
    call: (instance, callback) => {
      checkConflict(instance);
      currentInstance = instance;
      try {
        return als ? als.run(instance, callback) : callback();
      } finally {
        if (!isSingleton) {
          currentInstance = void 0;
        }
      }
    },
    async callAsync(instance, callback) {
      currentInstance = instance;
      const onRestore = () => {
        currentInstance = instance;
      };
      const onLeave = () => currentInstance === instance ? onRestore : void 0;
      asyncHandlers.add(onLeave);
      try {
        const r2 = als ? als.run(instance, callback) : callback();
        if (!isSingleton) {
          currentInstance = void 0;
        }
        return await r2;
      } finally {
        asyncHandlers.delete(onLeave);
      }
    }
  };
}
function createNamespace(defaultOpts = {}) {
  const contexts = {};
  return {
    get(key, opts = {}) {
      if (!contexts[key]) {
        contexts[key] = createContext({ ...defaultOpts, ...opts });
      }
      contexts[key];
      return contexts[key];
    }
  };
}
const _globalThis = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof global !== "undefined" ? global : {};
const globalKey = "__unctx__";
_globalThis[globalKey] || (_globalThis[globalKey] = createNamespace());
const asyncHandlersKey = "__unctx_async_handlers__";
const asyncHandlers = _globalThis[asyncHandlersKey] || (_globalThis[asyncHandlersKey] = /* @__PURE__ */ new Set());
function executeAsync(function_) {
  const restores = [];
  for (const leaveHandler of asyncHandlers) {
    const restore2 = leaveHandler();
    if (restore2) {
      restores.push(restore2);
    }
  }
  const restore = () => {
    for (const restore2 of restores) {
      restore2();
    }
  };
  let awaitable = function_();
  if (awaitable && typeof awaitable === "object" && "catch" in awaitable) {
    awaitable = awaitable.catch((error) => {
      restore();
      throw error;
    });
  }
  return [awaitable, restore];
}
const interpolatePath = (route, match) => {
  return match.path.replace(/(:\w+)\([^)]+\)/g, "$1").replace(/(:\w+)[?+*]/g, "$1").replace(/:\w+/g, (r2) => {
    var _a;
    return ((_a = route.params[r2.slice(1)]) == null ? void 0 : _a.toString()) || "";
  });
};
const generateRouteKey$1 = (routeProps, override) => {
  const matchedRoute = routeProps.route.matched.find((m2) => {
    var _a;
    return ((_a = m2.components) == null ? void 0 : _a.default) === routeProps.Component.type;
  });
  const source = override ?? (matchedRoute == null ? void 0 : matchedRoute.meta.key) ?? (matchedRoute && interpolatePath(routeProps.route, matchedRoute));
  return typeof source === "function" ? source(routeProps.route) : source;
};
const wrapInKeepAlive = (props, children) => {
  return { default: () => children };
};
function toArray(value) {
  return Array.isArray(value) ? value : [value];
}
const inlineConfig = {
  "nuxt": {
    "buildId": "9cdac051-01c8-4a5b-b6c6-bd6876029c0c"
  }
};
const __appConfig = /* @__PURE__ */ defuFn(inlineConfig);
function useAppConfig() {
  const nuxtApp = /* @__PURE__ */ useNuxtApp();
  if (!nuxtApp._appConfig) {
    nuxtApp._appConfig = klona(__appConfig);
  }
  return nuxtApp._appConfig;
}
const appLayoutTransition = false;
const appPageTransition = false;
const appKeepalive = false;
const nuxtLinkDefaults = { "componentName": "NuxtLink" };
const asyncDataDefaults = { "deep": true };
const fetchDefaults = {};
async function getRouteRules(url) {
  {
    const _routeRulesMatcher = toRouteMatcher(
      createRouter$1({ routes: (/* @__PURE__ */ useRuntimeConfig()).nitro.routeRules })
    );
    return defu({}, ..._routeRulesMatcher.matchAll(url).reverse());
  }
}
const __nuxt_page_meta$u = { layout: false };
const __nuxt_page_meta$t = { layout: false };
const __nuxt_page_meta$s = { layout: false };
const __nuxt_page_meta$r = { layout: false };
const __nuxt_page_meta$q = { layout: false };
const __nuxt_page_meta$p = { layout: false };
const __nuxt_page_meta$o = { layout: false };
const __nuxt_page_meta$n = { layout: false };
const __nuxt_page_meta$m = { layout: false };
const __nuxt_page_meta$l = { layout: false };
const __nuxt_page_meta$k = { layout: false };
const __nuxt_page_meta$j = { layout: false };
const __nuxt_page_meta$i = { layout: false };
const __nuxt_page_meta$h = { layout: false };
const __nuxt_page_meta$g = { layout: false };
const __nuxt_page_meta$f = { layout: false };
const __nuxt_page_meta$e = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$d = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$c = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$b = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$a = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$9 = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$8 = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$7 = {
  layout: "panel",
  middleware: "ensure-login"
};
const __nuxt_page_meta$6 = { layout: false };
const __nuxt_page_meta$5 = { layout: false };
const __nuxt_page_meta$4 = { layout: false };
const __nuxt_page_meta$3 = { layout: false };
const __nuxt_page_meta$2 = { layout: false, middleware: "ensure-login" };
const __nuxt_page_meta$1 = { layout: false };
const __nuxt_page_meta = { layout: false };
const _routes = [
  {
    name: (__nuxt_page_meta$u == null ? void 0 : __nuxt_page_meta$u.name) ?? "about",
    path: (__nuxt_page_meta$u == null ? void 0 : __nuxt_page_meta$u.path) ?? "/about",
    meta: __nuxt_page_meta$u || {},
    alias: (__nuxt_page_meta$u == null ? void 0 : __nuxt_page_meta$u.alias) || [],
    redirect: __nuxt_page_meta$u == null ? void 0 : __nuxt_page_meta$u.redirect,
    component: () => import('./about-BTL6-KA0.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$t == null ? void 0 : __nuxt_page_meta$t.name) ?? "auth",
    path: (__nuxt_page_meta$t == null ? void 0 : __nuxt_page_meta$t.path) ?? "/auth",
    meta: __nuxt_page_meta$t || {},
    alias: (__nuxt_page_meta$t == null ? void 0 : __nuxt_page_meta$t.alias) || [],
    redirect: __nuxt_page_meta$t == null ? void 0 : __nuxt_page_meta$t.redirect,
    component: () => import('./auth-DKkvkDji.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$s == null ? void 0 : __nuxt_page_meta$s.name) ?? "blog-details-2",
    path: (__nuxt_page_meta$s == null ? void 0 : __nuxt_page_meta$s.path) ?? "/blog-details-2",
    meta: __nuxt_page_meta$s || {},
    alias: (__nuxt_page_meta$s == null ? void 0 : __nuxt_page_meta$s.alias) || [],
    redirect: __nuxt_page_meta$s == null ? void 0 : __nuxt_page_meta$s.redirect,
    component: () => import('./blog-details-2-CVBnutpB.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$r == null ? void 0 : __nuxt_page_meta$r.name) ?? "blog-details-id",
    path: (__nuxt_page_meta$r == null ? void 0 : __nuxt_page_meta$r.path) ?? "/blog-details/:id()",
    meta: __nuxt_page_meta$r || {},
    alias: (__nuxt_page_meta$r == null ? void 0 : __nuxt_page_meta$r.alias) || [],
    redirect: __nuxt_page_meta$r == null ? void 0 : __nuxt_page_meta$r.redirect,
    component: () => import('./_id_-CGXLOgQp.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$q == null ? void 0 : __nuxt_page_meta$q.name) ?? "blog-sidebar",
    path: (__nuxt_page_meta$q == null ? void 0 : __nuxt_page_meta$q.path) ?? "/blog-sidebar",
    meta: __nuxt_page_meta$q || {},
    alias: (__nuxt_page_meta$q == null ? void 0 : __nuxt_page_meta$q.alias) || [],
    redirect: __nuxt_page_meta$q == null ? void 0 : __nuxt_page_meta$q.redirect,
    component: () => import('./blog-sidebar-D8e0GlAu.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$p == null ? void 0 : __nuxt_page_meta$p.name) ?? "blog",
    path: (__nuxt_page_meta$p == null ? void 0 : __nuxt_page_meta$p.path) ?? "/blog",
    meta: __nuxt_page_meta$p || {},
    alias: (__nuxt_page_meta$p == null ? void 0 : __nuxt_page_meta$p.alias) || [],
    redirect: __nuxt_page_meta$p == null ? void 0 : __nuxt_page_meta$p.redirect,
    component: () => import('./blog-P6e-SL05.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$o == null ? void 0 : __nuxt_page_meta$o.name) ?? "bmi",
    path: (__nuxt_page_meta$o == null ? void 0 : __nuxt_page_meta$o.path) ?? "/bmi",
    meta: __nuxt_page_meta$o || {},
    alias: (__nuxt_page_meta$o == null ? void 0 : __nuxt_page_meta$o.alias) || [],
    redirect: __nuxt_page_meta$o == null ? void 0 : __nuxt_page_meta$o.redirect,
    component: () => import('./bmi-DsmQMngU.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$n == null ? void 0 : __nuxt_page_meta$n.name) ?? "contact",
    path: (__nuxt_page_meta$n == null ? void 0 : __nuxt_page_meta$n.path) ?? "/contact",
    meta: __nuxt_page_meta$n || {},
    alias: (__nuxt_page_meta$n == null ? void 0 : __nuxt_page_meta$n.alias) || [],
    redirect: __nuxt_page_meta$n == null ? void 0 : __nuxt_page_meta$n.redirect,
    component: () => import('./contact-C6ogk9it.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$m == null ? void 0 : __nuxt_page_meta$m.name) ?? "home-2",
    path: (__nuxt_page_meta$m == null ? void 0 : __nuxt_page_meta$m.path) ?? "/home-2",
    meta: __nuxt_page_meta$m || {},
    alias: (__nuxt_page_meta$m == null ? void 0 : __nuxt_page_meta$m.alias) || [],
    redirect: __nuxt_page_meta$m == null ? void 0 : __nuxt_page_meta$m.redirect,
    component: () => import('./home-2-DmqaIGga.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$l == null ? void 0 : __nuxt_page_meta$l.name) ?? "home-3",
    path: (__nuxt_page_meta$l == null ? void 0 : __nuxt_page_meta$l.path) ?? "/home-3",
    meta: __nuxt_page_meta$l || {},
    alias: (__nuxt_page_meta$l == null ? void 0 : __nuxt_page_meta$l.alias) || [],
    redirect: __nuxt_page_meta$l == null ? void 0 : __nuxt_page_meta$l.redirect,
    component: () => import('./home-3-BJoUYH1u.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$k == null ? void 0 : __nuxt_page_meta$k.name) ?? "home-4",
    path: (__nuxt_page_meta$k == null ? void 0 : __nuxt_page_meta$k.path) ?? "/home-4",
    meta: __nuxt_page_meta$k || {},
    alias: (__nuxt_page_meta$k == null ? void 0 : __nuxt_page_meta$k.alias) || [],
    redirect: __nuxt_page_meta$k == null ? void 0 : __nuxt_page_meta$k.redirect,
    component: () => import('./home-4-CmhWnxEz.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$j == null ? void 0 : __nuxt_page_meta$j.name) ?? "home-5",
    path: (__nuxt_page_meta$j == null ? void 0 : __nuxt_page_meta$j.path) ?? "/home-5",
    meta: __nuxt_page_meta$j || {},
    alias: (__nuxt_page_meta$j == null ? void 0 : __nuxt_page_meta$j.alias) || [],
    redirect: __nuxt_page_meta$j == null ? void 0 : __nuxt_page_meta$j.redirect,
    component: () => import('./home-5-DQ5dl-GU.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$i == null ? void 0 : __nuxt_page_meta$i.name) ?? "home-6",
    path: (__nuxt_page_meta$i == null ? void 0 : __nuxt_page_meta$i.path) ?? "/home-6",
    meta: __nuxt_page_meta$i || {},
    alias: (__nuxt_page_meta$i == null ? void 0 : __nuxt_page_meta$i.alias) || [],
    redirect: __nuxt_page_meta$i == null ? void 0 : __nuxt_page_meta$i.redirect,
    component: () => import('./home-6-BS6f2-FM.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$h == null ? void 0 : __nuxt_page_meta$h.name) ?? "home-7",
    path: (__nuxt_page_meta$h == null ? void 0 : __nuxt_page_meta$h.path) ?? "/home-7",
    meta: __nuxt_page_meta$h || {},
    alias: (__nuxt_page_meta$h == null ? void 0 : __nuxt_page_meta$h.alias) || [],
    redirect: __nuxt_page_meta$h == null ? void 0 : __nuxt_page_meta$h.redirect,
    component: () => import('./home-7-BdGpHKRk.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$g == null ? void 0 : __nuxt_page_meta$g.name) ?? "home-8",
    path: (__nuxt_page_meta$g == null ? void 0 : __nuxt_page_meta$g.path) ?? "/home-8",
    meta: __nuxt_page_meta$g || {},
    alias: (__nuxt_page_meta$g == null ? void 0 : __nuxt_page_meta$g.alias) || [],
    redirect: __nuxt_page_meta$g == null ? void 0 : __nuxt_page_meta$g.redirect,
    component: () => import('./home-8-Drorr0Vm.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$f == null ? void 0 : __nuxt_page_meta$f.name) ?? "index",
    path: (__nuxt_page_meta$f == null ? void 0 : __nuxt_page_meta$f.path) ?? "/",
    meta: __nuxt_page_meta$f || {},
    alias: (__nuxt_page_meta$f == null ? void 0 : __nuxt_page_meta$f.alias) || [],
    redirect: __nuxt_page_meta$f == null ? void 0 : __nuxt_page_meta$f.redirect,
    component: () => import('./index-BguGpw3x.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$e == null ? void 0 : __nuxt_page_meta$e.name) ?? "panel",
    path: (__nuxt_page_meta$e == null ? void 0 : __nuxt_page_meta$e.path) ?? "/panel",
    meta: __nuxt_page_meta$e || {},
    alias: (__nuxt_page_meta$e == null ? void 0 : __nuxt_page_meta$e.alias) || [],
    redirect: __nuxt_page_meta$e == null ? void 0 : __nuxt_page_meta$e.redirect,
    component: () => import('./index-CmIp0Oqa.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$d == null ? void 0 : __nuxt_page_meta$d.name) ?? "panel-plan",
    path: (__nuxt_page_meta$d == null ? void 0 : __nuxt_page_meta$d.path) ?? "/panel/plan",
    meta: __nuxt_page_meta$d || {},
    alias: (__nuxt_page_meta$d == null ? void 0 : __nuxt_page_meta$d.alias) || [],
    redirect: __nuxt_page_meta$d == null ? void 0 : __nuxt_page_meta$d.redirect,
    component: () => import('./index-CSilwWLs.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$c == null ? void 0 : __nuxt_page_meta$c.name) ?? "panel-plan-purchases-_id",
    path: (__nuxt_page_meta$c == null ? void 0 : __nuxt_page_meta$c.path) ?? "/panel/plan/purchases/:_id()",
    meta: __nuxt_page_meta$c || {},
    alias: (__nuxt_page_meta$c == null ? void 0 : __nuxt_page_meta$c.alias) || [],
    redirect: __nuxt_page_meta$c == null ? void 0 : __nuxt_page_meta$c.redirect,
    component: () => import('./__id_-BBqPRNjs.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$b == null ? void 0 : __nuxt_page_meta$b.name) ?? "panel-plan-purchases",
    path: (__nuxt_page_meta$b == null ? void 0 : __nuxt_page_meta$b.path) ?? "/panel/plan/purchases",
    meta: __nuxt_page_meta$b || {},
    alias: (__nuxt_page_meta$b == null ? void 0 : __nuxt_page_meta$b.alias) || [],
    redirect: __nuxt_page_meta$b == null ? void 0 : __nuxt_page_meta$b.redirect,
    component: () => import('./index-B7vm3aPI.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$a == null ? void 0 : __nuxt_page_meta$a.name) ?? "panel-user-_id",
    path: (__nuxt_page_meta$a == null ? void 0 : __nuxt_page_meta$a.path) ?? "/panel/user/:_id()",
    meta: __nuxt_page_meta$a || {},
    alias: (__nuxt_page_meta$a == null ? void 0 : __nuxt_page_meta$a.alias) || [],
    redirect: __nuxt_page_meta$a == null ? void 0 : __nuxt_page_meta$a.redirect,
    component: () => import('./index-BFyQJWZP.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$9 == null ? void 0 : __nuxt_page_meta$9.name) ?? "panel-user-_id-membership-membership_id",
    path: (__nuxt_page_meta$9 == null ? void 0 : __nuxt_page_meta$9.path) ?? "/panel/user/:_id()/membership/:membership_id()",
    meta: __nuxt_page_meta$9 || {},
    alias: (__nuxt_page_meta$9 == null ? void 0 : __nuxt_page_meta$9.alias) || [],
    redirect: __nuxt_page_meta$9 == null ? void 0 : __nuxt_page_meta$9.redirect,
    component: () => import('./index-CwYtAWDP.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$8 == null ? void 0 : __nuxt_page_meta$8.name) ?? "panel-user-create",
    path: (__nuxt_page_meta$8 == null ? void 0 : __nuxt_page_meta$8.path) ?? "/panel/user/create",
    meta: __nuxt_page_meta$8 || {},
    alias: (__nuxt_page_meta$8 == null ? void 0 : __nuxt_page_meta$8.alias) || [],
    redirect: __nuxt_page_meta$8 == null ? void 0 : __nuxt_page_meta$8.redirect,
    component: () => import('./create-DQu3g9Jg.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$7 == null ? void 0 : __nuxt_page_meta$7.name) ?? "panel-user",
    path: (__nuxt_page_meta$7 == null ? void 0 : __nuxt_page_meta$7.path) ?? "/panel/user",
    meta: __nuxt_page_meta$7 || {},
    alias: (__nuxt_page_meta$7 == null ? void 0 : __nuxt_page_meta$7.alias) || [],
    redirect: __nuxt_page_meta$7 == null ? void 0 : __nuxt_page_meta$7.redirect,
    component: () => import('./index-BjKAdL8D.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$6 == null ? void 0 : __nuxt_page_meta$6.name) ?? "portfolio-details-2",
    path: (__nuxt_page_meta$6 == null ? void 0 : __nuxt_page_meta$6.path) ?? "/portfolio-details-2",
    meta: __nuxt_page_meta$6 || {},
    alias: (__nuxt_page_meta$6 == null ? void 0 : __nuxt_page_meta$6.alias) || [],
    redirect: __nuxt_page_meta$6 == null ? void 0 : __nuxt_page_meta$6.redirect,
    component: () => import('./portfolio-details-2-DaATVIJp.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$5 == null ? void 0 : __nuxt_page_meta$5.name) ?? "portfolio-details-3",
    path: (__nuxt_page_meta$5 == null ? void 0 : __nuxt_page_meta$5.path) ?? "/portfolio-details-3",
    meta: __nuxt_page_meta$5 || {},
    alias: (__nuxt_page_meta$5 == null ? void 0 : __nuxt_page_meta$5.alias) || [],
    redirect: __nuxt_page_meta$5 == null ? void 0 : __nuxt_page_meta$5.redirect,
    component: () => import('./portfolio-details-3-B1aMGDRH.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$4 == null ? void 0 : __nuxt_page_meta$4.name) ?? "portfolio-details",
    path: (__nuxt_page_meta$4 == null ? void 0 : __nuxt_page_meta$4.path) ?? "/portfolio-details",
    meta: __nuxt_page_meta$4 || {},
    alias: (__nuxt_page_meta$4 == null ? void 0 : __nuxt_page_meta$4.alias) || [],
    redirect: __nuxt_page_meta$4 == null ? void 0 : __nuxt_page_meta$4.redirect,
    component: () => import('./portfolio-details-CreCmwMf.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$3 == null ? void 0 : __nuxt_page_meta$3.name) ?? "portfolio",
    path: (__nuxt_page_meta$3 == null ? void 0 : __nuxt_page_meta$3.path) ?? "/portfolio",
    meta: __nuxt_page_meta$3 || {},
    alias: (__nuxt_page_meta$3 == null ? void 0 : __nuxt_page_meta$3.alias) || [],
    redirect: __nuxt_page_meta$3 == null ? void 0 : __nuxt_page_meta$3.redirect,
    component: () => import('./portfolio-D0CkC9JZ.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$2 == null ? void 0 : __nuxt_page_meta$2.name) ?? "profile",
    path: (__nuxt_page_meta$2 == null ? void 0 : __nuxt_page_meta$2.path) ?? "/profile",
    meta: __nuxt_page_meta$2 || {},
    alias: (__nuxt_page_meta$2 == null ? void 0 : __nuxt_page_meta$2.alias) || [],
    redirect: __nuxt_page_meta$2 == null ? void 0 : __nuxt_page_meta$2.redirect,
    component: () => import('./index-COI0pdlM.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta$1 == null ? void 0 : __nuxt_page_meta$1.name) ?? "service-details",
    path: (__nuxt_page_meta$1 == null ? void 0 : __nuxt_page_meta$1.path) ?? "/service-details",
    meta: __nuxt_page_meta$1 || {},
    alias: (__nuxt_page_meta$1 == null ? void 0 : __nuxt_page_meta$1.alias) || [],
    redirect: __nuxt_page_meta$1 == null ? void 0 : __nuxt_page_meta$1.redirect,
    component: () => import('./service-details-DheBi5-G.mjs').then((m2) => m2.default || m2)
  },
  {
    name: (__nuxt_page_meta == null ? void 0 : __nuxt_page_meta.name) ?? "service",
    path: (__nuxt_page_meta == null ? void 0 : __nuxt_page_meta.path) ?? "/service",
    meta: __nuxt_page_meta || {},
    alias: (__nuxt_page_meta == null ? void 0 : __nuxt_page_meta.alias) || [],
    redirect: __nuxt_page_meta == null ? void 0 : __nuxt_page_meta.redirect,
    component: () => import('./service-dxBfEgLQ.mjs').then((m2) => m2.default || m2)
  }
];
const _wrapIf = (component, props, slots) => {
  props = props === true ? {} : props;
  return { default: () => {
    var _a;
    return props ? h$3(component, props, slots) : (_a = slots.default) == null ? void 0 : _a.call(slots);
  } };
};
function generateRouteKey(route) {
  const source = (route == null ? void 0 : route.meta.key) ?? route.path.replace(/(:\w+)\([^)]+\)/g, "$1").replace(/(:\w+)[?+*]/g, "$1").replace(/:\w+/g, (r2) => {
    var _a;
    return ((_a = route.params[r2.slice(1)]) == null ? void 0 : _a.toString()) || "";
  });
  return typeof source === "function" ? source(route) : source;
}
function isChangingPage(to, from) {
  if (to === from || from === START_LOCATION) {
    return false;
  }
  if (generateRouteKey(to) !== generateRouteKey(from)) {
    return true;
  }
  const areComponentsSame = to.matched.every(
    (comp, index) => {
      var _a, _b;
      return comp.components && comp.components.default === ((_b = (_a = from.matched[index]) == null ? void 0 : _a.components) == null ? void 0 : _b.default);
    }
  );
  if (areComponentsSame) {
    return false;
  }
  return true;
}
const routerOptions0 = {
  scrollBehavior(to, from, savedPosition) {
    var _a;
    const nuxtApp = /* @__PURE__ */ useNuxtApp();
    const behavior = ((_a = useRouter().options) == null ? void 0 : _a.scrollBehaviorType) ?? "auto";
    let position = savedPosition || void 0;
    const routeAllowsScrollToTop = typeof to.meta.scrollToTop === "function" ? to.meta.scrollToTop(to, from) : to.meta.scrollToTop;
    if (!position && from && to && routeAllowsScrollToTop !== false && isChangingPage(to, from)) {
      position = { left: 0, top: 0 };
    }
    if (to.path === from.path) {
      if (from.hash && !to.hash) {
        return { left: 0, top: 0 };
      }
      if (to.hash) {
        return { el: to.hash, top: _getHashElementScrollMarginTop(to.hash), behavior };
      }
      return false;
    }
    const hasTransition = (route) => !!(route.meta.pageTransition ?? appPageTransition);
    const hookToWait = hasTransition(from) && hasTransition(to) ? "page:transition:finish" : "page:finish";
    return new Promise((resolve) => {
      nuxtApp.hooks.hookOnce(hookToWait, async () => {
        await new Promise((resolve2) => setTimeout(resolve2, 0));
        if (to.hash) {
          position = { el: to.hash, top: _getHashElementScrollMarginTop(to.hash), behavior };
        }
        resolve(position);
      });
    });
  }
};
function _getHashElementScrollMarginTop(selector) {
  try {
    const elem = (void 0).querySelector(selector);
    if (elem) {
      return parseFloat(getComputedStyle(elem).scrollMarginTop);
    }
  } catch {
  }
  return 0;
}
const configRouterOptions = {
  hashMode: false,
  scrollBehaviorType: "auto"
};
const routerOptions = {
  ...configRouterOptions,
  ...routerOptions0
};
const validate = /* @__PURE__ */ defineNuxtRouteMiddleware(async (to) => {
  var _a;
  let __temp, __restore;
  if (!((_a = to.meta) == null ? void 0 : _a.validate)) {
    return;
  }
  useRouter();
  const result = ([__temp, __restore] = executeAsync(() => Promise.resolve(to.meta.validate(to))), __temp = await __temp, __restore(), __temp);
  if (result === true) {
    return;
  }
  {
    return result;
  }
});
const manifest_45route_45rule = /* @__PURE__ */ defineNuxtRouteMiddleware(async (to) => {
  {
    return;
  }
});
const globalMiddleware = [
  validate,
  manifest_45route_45rule
];
const namedMiddleware = {
  "ensure-login": () => import('./ensureLogin-g5MCWfAj.mjs')
};
const plugin = /* @__PURE__ */ defineNuxtPlugin({
  name: "nuxt:router",
  enforce: "pre",
  async setup(nuxtApp) {
    var _a, _b, _c;
    let __temp, __restore;
    let routerBase = (/* @__PURE__ */ useRuntimeConfig()).app.baseURL;
    if (routerOptions.hashMode && !routerBase.includes("#")) {
      routerBase += "#";
    }
    const history = ((_a = routerOptions.history) == null ? void 0 : _a.call(routerOptions, routerBase)) ?? createMemoryHistory(routerBase);
    const routes = ((_b = routerOptions.routes) == null ? void 0 : _b.call(routerOptions, _routes)) ?? _routes;
    let startPosition;
    const initialURL = nuxtApp.ssrContext.url;
    const router = createRouter({
      ...routerOptions,
      scrollBehavior: (to, from, savedPosition) => {
        if (from === START_LOCATION) {
          startPosition = savedPosition;
          return;
        }
        if (routerOptions.scrollBehavior) {
          router.options.scrollBehavior = routerOptions.scrollBehavior;
          if ("scrollRestoration" in (void 0).history) {
            const unsub = router.beforeEach(() => {
              unsub();
              (void 0).history.scrollRestoration = "manual";
            });
          }
          return routerOptions.scrollBehavior(to, START_LOCATION, startPosition || savedPosition);
        }
      },
      history,
      routes
    });
    nuxtApp.vueApp.use(router);
    const previousRoute = shallowRef(router.currentRoute.value);
    router.afterEach((_to, from) => {
      previousRoute.value = from;
    });
    Object.defineProperty(nuxtApp.vueApp.config.globalProperties, "previousRoute", {
      get: () => previousRoute.value
    });
    const _route = shallowRef(router.resolve(initialURL));
    const syncCurrentRoute = () => {
      _route.value = router.currentRoute.value;
    };
    nuxtApp.hook("page:finish", syncCurrentRoute);
    router.afterEach((to, from) => {
      var _a2, _b2, _c2, _d;
      if (((_b2 = (_a2 = to.matched[0]) == null ? void 0 : _a2.components) == null ? void 0 : _b2.default) === ((_d = (_c2 = from.matched[0]) == null ? void 0 : _c2.components) == null ? void 0 : _d.default)) {
        syncCurrentRoute();
      }
    });
    const route = {};
    for (const key in _route.value) {
      Object.defineProperty(route, key, {
        get: () => _route.value[key]
      });
    }
    nuxtApp._route = shallowReactive(route);
    nuxtApp._middleware = nuxtApp._middleware || {
      global: [],
      named: {}
    };
    useError();
    try {
      if (true) {
        ;
        [__temp, __restore] = executeAsync(() => router.push(initialURL)), await __temp, __restore();
        ;
      }
      ;
      [__temp, __restore] = executeAsync(() => router.isReady()), await __temp, __restore();
      ;
    } catch (error2) {
      [__temp, __restore] = executeAsync(() => nuxtApp.runWithContext(() => showError(error2))), await __temp, __restore();
    }
    if ((_c = nuxtApp.ssrContext) == null ? void 0 : _c.islandContext) {
      return { provide: { router } };
    }
    const initialLayout = nuxtApp.payload.state._layout;
    router.beforeEach(async (to, from) => {
      var _a2, _b2;
      await nuxtApp.callHook("page:loading:start");
      to.meta = reactive(to.meta);
      if (nuxtApp.isHydrating && initialLayout && !isReadonly(to.meta.layout)) {
        to.meta.layout = initialLayout;
      }
      nuxtApp._processingMiddleware = true;
      if (!((_a2 = nuxtApp.ssrContext) == null ? void 0 : _a2.islandContext)) {
        const middlewareEntries = /* @__PURE__ */ new Set([...globalMiddleware, ...nuxtApp._middleware.global]);
        for (const component of to.matched) {
          const componentMiddleware = component.meta.middleware;
          if (!componentMiddleware) {
            continue;
          }
          for (const entry2 of toArray(componentMiddleware)) {
            middlewareEntries.add(entry2);
          }
        }
        {
          const routeRules = await nuxtApp.runWithContext(() => getRouteRules(to.path));
          if (routeRules.appMiddleware) {
            for (const key in routeRules.appMiddleware) {
              if (routeRules.appMiddleware[key]) {
                middlewareEntries.add(key);
              } else {
                middlewareEntries.delete(key);
              }
            }
          }
        }
        for (const entry2 of middlewareEntries) {
          const middleware = typeof entry2 === "string" ? nuxtApp._middleware.named[entry2] || await ((_b2 = namedMiddleware[entry2]) == null ? void 0 : _b2.call(namedMiddleware).then((r2) => r2.default || r2)) : entry2;
          if (!middleware) {
            throw new Error(`Unknown route middleware: '${entry2}'.`);
          }
          const result = await nuxtApp.runWithContext(() => middleware(to, from));
          {
            if (result === false || result instanceof Error) {
              const error2 = result || createError$1({
                statusCode: 404,
                statusMessage: `Page Not Found: ${initialURL}`
              });
              await nuxtApp.runWithContext(() => showError(error2));
              return false;
            }
          }
          if (result === true) {
            continue;
          }
          if (result || result === false) {
            return result;
          }
        }
      }
    });
    router.onError(async () => {
      delete nuxtApp._processingMiddleware;
      await nuxtApp.callHook("page:loading:end");
    });
    router.afterEach(async (to, _from, failure) => {
      delete nuxtApp._processingMiddleware;
      if (failure) {
        await nuxtApp.callHook("page:loading:end");
      }
      if ((failure == null ? void 0 : failure.type) === 4) {
        return;
      }
      if (to.matched.length === 0) {
        await nuxtApp.runWithContext(() => showError(createError$1({
          statusCode: 404,
          fatal: false,
          statusMessage: `Page not found: ${to.fullPath}`,
          data: {
            path: to.fullPath
          }
        })));
      } else if (to.redirectedFrom && to.fullPath !== initialURL) {
        await nuxtApp.runWithContext(() => navigateTo(to.fullPath || "/"));
      }
    });
    nuxtApp.hooks.hookOnce("app:created", async () => {
      try {
        const to = router.resolve(initialURL);
        if ("name" in to) {
          to.name = void 0;
        }
        await router.replace({
          ...to,
          force: true
        });
        router.options.scrollBehavior = routerOptions.scrollBehavior;
      } catch (error2) {
        await nuxtApp.runWithContext(() => showError(error2));
      }
    });
    return { provide: { router } };
  }
});
function definePayloadReducer(name, reduce) {
  {
    (/* @__PURE__ */ useNuxtApp()).ssrContext._payloadReducers[name] = reduce;
  }
}
const reducers = {
  NuxtError: (data) => isNuxtError(data) && data.toJSON(),
  EmptyShallowRef: (data) => isRef(data) && isShallow(data) && !data.value && (typeof data.value === "bigint" ? "0n" : JSON.stringify(data.value) || "_"),
  EmptyRef: (data) => isRef(data) && !data.value && (typeof data.value === "bigint" ? "0n" : JSON.stringify(data.value) || "_"),
  ShallowRef: (data) => isRef(data) && isShallow(data) && data.value,
  ShallowReactive: (data) => isReactive(data) && isShallow(data) && toRaw(data),
  Ref: (data) => isRef(data) && data.value,
  Reactive: (data) => isReactive(data) && toRaw(data)
};
const revive_payload_server_eJ33V7gbc6 = /* @__PURE__ */ defineNuxtPlugin({
  name: "nuxt:revive-payload:server",
  setup() {
    for (const reducer in reducers) {
      definePayloadReducer(reducer, reducers[reducer]);
    }
  }
});
const components_plugin_KR1HBZs4kY = /* @__PURE__ */ defineNuxtPlugin({
  name: "nuxt:global-components"
});
const componentsWithDefaults = {};
const appConfigKey = "nuxtQuasar";
const quasarNuxtConfig = {
  lang: defaultLang,
  iconSet,
  components: { "defaults": {} },
  plugins: { Notify }
};
function omit(object, keys) {
  return Object.keys(object).reduce((output, key) => {
    if (!keys.includes(key)) {
      output[key] = object[key];
    }
    return output;
  }, {});
}
const plugin_IFbScM8fhe = /* @__PURE__ */ defineNuxtPlugin((nuxt) => {
  const quasarAppConfig = useAppConfig()[appConfigKey];
  const { lang: lang2, iconSet: iconSet2, plugins: plugins2, components } = quasarNuxtConfig;
  let ssrContext;
  let quasarProxy;
  let config = defuFn(quasarAppConfig, omit(quasarNuxtConfig.config || {}, ["brand"]));
  {
    const BRAND_RE = /--q-(?:.+?):(?:.+?);/g;
    const meta = reactive({
      bodyClasses: "",
      htmlAttrs: "",
      endingHeadTags: ""
    });
    const htmlAttrsRecord = computed(
      () => Object.fromEntries(
        meta.htmlAttrs.split(" ").map((attr) => attr.split("="))
      )
    );
    const bodyStyles = computed(() => {
      return [...meta.endingHeadTags.matchAll(BRAND_RE)].map((match) => match[0]).join("");
    });
    useHead(
      computed(() => ({
        bodyAttrs: {
          class: meta.bodyClasses,
          style: bodyStyles.value
        },
        htmlAttrs: htmlAttrsRecord.value
      }))
    );
    ssrContext = {
      req: nuxt.ssrContext.event.node.req,
      res: nuxt.ssrContext.event.node.res
    };
    quasarProxy = {
      install({ ssrContext: ssrContext2 }) {
        meta.bodyClasses = ssrContext2._meta.bodyClasses;
        meta.htmlAttrs = ssrContext2._meta.htmlAttrs;
        meta.endingHeadTags = ssrContext2._meta.endingHeadTags;
        ssrContext2._meta = new Proxy({}, {
          get(target, key) {
            return meta[key] ?? target[key];
          },
          set(target, key, value) {
            if (typeof meta[key] === "string") {
              meta[key] = value;
            } else {
              target[key] = value;
            }
            return true;
          }
        });
      }
    };
  }
  nuxt.vueApp.use(Quasar, {
    lang: lang2,
    iconSet: iconSet2,
    plugins: {
      quasarProxy,
      ...plugins2
    },
    config
    // @ts-expect-error Private Argument
  }, ssrContext);
  const quasar = useQuasar();
  const asDefault = (value) => value && typeof value === "object" ? () => value : value;
  for (const [name, propDefaults] of Object.entries(components.defaults || {})) {
    const component = componentsWithDefaults[name];
    for (const [propName, defaultValue] of Object.entries(propDefaults)) {
      const propConfig = component.props[propName];
      if (Array.isArray(propConfig) || typeof propConfig === "function") {
        component.props[propName] = {
          type: propConfig,
          default: asDefault(defaultValue)
        };
      } else if (typeof propConfig === "object") {
        propConfig.default = asDefault(defaultValue);
      } else {
        throw new TypeError(`Unexpected prop definition type used at ${name}.props.${propName}, please open an issue.`);
      }
    }
  }
  return {
    provide: {
      q: quasar
    }
  };
});
const intervalError = "[nuxt] `setInterval` should not be used on the server. Consider wrapping it with an `onNuxtReady`, `onBeforeMount` or `onMounted` lifecycle hook, or ensure you only call it in the browser by checking `false`.";
const setInterval = () => {
  console.error(intervalError);
};
/*! Bundled license information:

gsap/SplitText.js:
  (*!
   * SplitText 3.12.5
   * https://gsap.com
   * 
   * @license Copyright 2024, GreenSock. All rights reserved.
   *)
*/
var e$2;
var t$2;
var r;
var o$1;
var s$2;
var i$2;
var n$2;
var a$1;
var l$2;
var c$2;
var d$1;
var h$2;
var f$1;
var g$2;
var p$1;
var u$2 = () => false;
var m$2 = () => e$2 || u$2();
var T$1 = (e2) => {
  let t2 = o$1.querySelector(".ScrollSmoother-wrapper");
  return t2 || (t2 = o$1.createElement("div"), t2.classList.add("ScrollSmoother-wrapper"), e2.parentNode.insertBefore(t2, e2), t2.appendChild(e2)), t2;
};
var x$2 = class _x {
  constructor(u2) {
    _x.register(e$2) || console.warn("Please gsap.registerPlugin(ScrollSmoother)"), u2 = this.vars = u2 || {}, c$2 && c$2.kill(), c$2 = this, g$2(this);
    let m2, v2, y2, w2, b2, C2, _2, E2, P2, R2, k2, A2, N2, M2, z2, F2, { smoothTouch: L2, onUpdate: B2, onStop: H2, smooth: O2, onFocusIn: I2, normalizeScroll: U2, wholePixels: q2 } = u2, V2 = this, W2 = u2.effectsPrefix || "", D2 = l$2.getScrollFunc(r), j2 = 1 === l$2.isTouch ? true === L2 ? 0.8 : parseFloat(L2) || 0 : 0 === O2 || false === O2 ? 0 : parseFloat(O2) || 0.8, Y2 = j2 && +u2.speed || 1, K2 = 0, $2 = 0, G2 = 1, J2 = h$2(0), Q2 = () => J2.update(-K2), X2 = {
      y: 0
    }, Z2 = () => m2.style.overflow = "visible", ee2 = (e2) => {
      e2.update();
      let t2 = e2.getTween();
      t2 && (t2.pause(), t2._time = t2._dur, t2._tTime = t2._tDur), z2 = false, e2.animation.progress(e2.progress, true);
    }, te2 = (e2, t2) => {
      (e2 !== K2 && !R2 || t2) && (q2 && (e2 = Math.round(e2)), j2 && (m2.style.transform = "matrix3d(1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, " + e2 + ", 0, 1)", m2._gsap.y = e2 + "px"), $2 = e2 - K2, K2 = e2, l$2.isUpdating || _x.isRefreshing || l$2.update());
    }, re2 = function(e2) {
      return arguments.length ? (e2 < 0 && (e2 = 0), X2.y = -e2, z2 = true, R2 ? K2 = -e2 : te2(-e2), l$2.isRefreshing ? w2.update() : D2(e2 / Y2), this) : -K2;
    }, oe2 = "undefined" != typeof ResizeObserver && false !== u2.autoResize && new ResizeObserver(
      () => {
        if (!l$2.isRefreshing) {
          p$1.restart(true);
        }
      }
    ), se2 = (e2) => {
      v2.scrollTop = 0, e2.target.contains && e2.target.contains(v2) || I2 && false === I2(this, e2) || (l$2.isInViewport(e2.target) || e2.target === F2 || this.scrollTo(e2.target, false, "center center"), F2 = e2.target);
    }, ie2 = (e2, t2) => {
      if (e2 < t2.start)
        return e2;
      let r2 = isNaN(t2.ratio) ? 1 : t2.ratio, o2 = t2.end - t2.start, s2 = e2 - t2.start, i2 = t2.offset || 0, n2 = t2.pins || [], a2 = n2.offset || 0, l2 = t2._startClamp && t2.start <= 0 || t2.pins && t2.pins.offset ? 0 : t2._endClamp && t2.end === S() ? 1 : 0.5;
      return n2.forEach(
        (t3) => {
          o2 -= t3.distance, t3.nativeStart <= e2 && (s2 -= t3.distance);
        }
      ), a2 && (s2 *= (o2 - a2 / r2) / o2), e2 + (s2 - i2 * l2) / r2 - s2;
    }, ne2 = (t2, r2, o2) => {
      o2 || (t2.pins.length = t2.pins.offset = 0);
      let s2, i2, n2, a2, l2, c2, d2, h2, f2 = t2.pins, g2 = t2.markers;
      for (d2 = 0; d2 < r2.length; d2++)
        if (h2 = r2[d2], t2.trigger && h2.trigger && t2 !== h2 && (h2.trigger === t2.trigger || h2.pinnedContainer === t2.trigger || t2.trigger.contains(h2.trigger)) && (l2 = h2._startNative || h2._startClamp || h2.start, c2 = h2._endNative || h2._endClamp || h2.end, n2 = ie2(l2, t2), a2 = h2.pin && c2 > 0 ? n2 + (c2 - l2) : ie2(c2, t2), h2.setPositions(n2, a2, true, (h2._startClamp ? Math.max(0, n2) : n2) - l2), h2.markerStart && g2.push(e$2.quickSetter([h2.markerStart, h2.markerEnd], "y", "px")), h2.pin && h2.end > 0 && !o2)) {
          if (s2 = h2.end - h2.start, i2 = t2._startClamp && h2.start < 0, i2) {
            if (t2.start > 0)
              return t2.setPositions(0, t2.end + (t2._startNative - t2.start), true), void ne2(t2, r2);
            s2 += h2.start, f2.offset = -h2.start;
          }
          f2.push({
            start: h2.start,
            nativeStart: l2,
            end: h2.end,
            distance: s2,
            trig: h2
          }), t2.setPositions(t2.start, t2.end + (i2 ? -h2.start : s2), true);
        }
    }, ae2 = (e2, t2) => {
      b2.forEach((r2) => ne2(r2, e2, t2));
    }, le2 = () => {
      Z2(), requestAnimationFrame(Z2), b2 && (l$2.getAll().forEach(
        (e2) => {
          e2._startNative = e2.start, e2._endNative = e2.end;
        }
      ), b2.forEach(
        (e2) => {
          let t2 = e2._startClamp || e2.start, r2 = e2.autoSpeed ? Math.min(e2.end) : t2 + Math.abs((e2.end - t2) / e2.ratio), o2 = r2 - e2.end;
          if (t2 -= o2 / 2, r2 -= o2 / 2, t2 > r2) {
            let e3 = t2;
            t2 = r2, r2 = e3;
          }
          e2._startClamp && t2 < 0 ? (r2 = e2.ratio < 0 ? S() : e2.end / e2.ratio, o2 = r2 - e2.end, t2 = 0) : (e2.ratio < 0 || e2._endClamp && r2 >= S()) && (r2 = S(), t2 = e2.ratio < 0 || e2.ratio > 1 ? 0 : r2 - (r2 - e2.start) / e2.ratio, o2 = (r2 - t2) * e2.ratio - (e2.end - e2.start)), e2.offset = o2 || 1e-4, e2.pins.length = e2.pins.offset = 0, e2.setPositions(t2, r2, true);
        }
      ), ae2(l$2.sort())), J2.reset();
    }, ce2 = () => l$2.addEventListener("refresh", le2), de2 = () => b2 && b2.forEach((e2) => e2.vars.onRefresh(e2)), he2 = () => (b2 && b2.forEach((e2) => e2.vars.onRefreshInit(e2)), de2), fe2 = (e2, t2, r2, o2) => () => {
      let s2 = "function" == typeof t2 ? t2(r2, o2) : t2;
      s2 || 0 === s2 || (s2 = o2.getAttribute("data-" + W2 + e2) || ("speed" === e2 ? 1 : 0)), o2.setAttribute("data-" + W2 + e2, s2);
      let i2 = "clamp(" === (s2 + "").substr(0, 6);
      return {
        clamp: i2,
        value: i2 ? s2.substr(6, s2.length - 7) : s2
      };
    }, ge2 = (t2, o2, i2, n2, c2) => {
      c2 = ("function" == typeof c2 ? c2(n2, t2) : c2) || 0;
      let h2, f2, g2, p2, u3, m3, y3 = fe2("speed", o2, n2, t2), w3 = fe2("lag", i2, n2, t2), T2 = e$2.getProperty(t2, "y"), x2 = t2._gsap, C22 = [], _22 = () => {
        o2 = y3(), i2 = parseFloat(w3().value), h2 = parseFloat(o2.value) || 1, g2 = "auto" === o2.value, u3 = g2 || f2 && f2._startClamp && f2.start <= 0 || C22.offset ? 0 : f2 && f2._endClamp && f2.end === S() ? 1 : 0.5, p2 && p2.kill(), p2 = i2 && e$2.to(t2, {
          ease: d$1,
          overwrite: false,
          y: "+=0",
          duration: i2
        }), f2 && (f2.ratio = h2, f2.autoSpeed = g2);
      }, E22 = () => {
        x2.y = T2 + "px", x2.renderTransform(1), _22();
      }, P22 = [], R22 = 0, k22 = (e2) => {
        if (g2) {
          E22();
          let o3 = ((e3, t3) => {
            let o4, i3, n3 = e3.parentNode || s$2, a2 = e3.getBoundingClientRect(), l2 = n3.getBoundingClientRect(), c3 = l2.top - a2.top, d2 = l2.bottom - a2.bottom, h3 = (Math.abs(c3) > Math.abs(d2) ? c3 : d2) / (1 - t3), f3 = -h3 * t3;
            return h3 > 0 && (o4 = l2.height / (r.innerHeight + l2.height), i3 = 0.5 === o4 ? 2 * l2.height : 2 * Math.min(l2.height, Math.abs(-h3 * o4 / (2 * o4 - 1))) * (t3 || 1), f3 += t3 ? -i3 * t3 : -i3 / 2, h3 += i3), {
              change: h3,
              offset: f3
            };
          })(t2, a$1(0, 1, -e2.start / (e2.end - e2.start)));
          R22 = o3.change, m3 = o3.offset;
        } else
          m3 = C22.offset || 0, R22 = (e2.end - e2.start - m3) * (1 - h2);
        C22.forEach((e3) => R22 -= e3.distance * (1 - h2)), e2.offset = R22 || 1e-3, e2.vars.onUpdate(e2), p2 && p2.progress(1);
      };
      return _22(), (1 !== h2 || g2 || p2) && (f2 = l$2.create({
        trigger: g2 ? t2.parentNode : t2,
        start: () => o2.clamp ? "clamp(top bottom+=" + c2 + ")" : "top bottom+=" + c2,
        end: () => o2.value < 0 ? "max" : o2.clamp ? "clamp(bottom top-=" + c2 + ")" : "bottom top-=" + c2,
        scroller: v2,
        scrub: true,
        refreshPriority: -999,
        onRefreshInit: E22,
        onRefresh: k22,
        onKill: (e2) => {
          let t3 = b2.indexOf(e2);
          t3 >= 0 && b2.splice(t3, 1), E22();
        },
        onUpdate: (t3) => {
          let r2, o3, s2, i3 = T2 + R22 * (t3.progress - u3), n3 = C22.length, a2 = 0;
          if (t3.offset) {
            if (n3) {
              for (o3 = -K2, s2 = t3.end; n3--; ) {
                if (r2 = C22[n3], r2.trig.isActive || o3 >= r2.start && o3 <= r2.end)
                  return void (p2 && (r2.trig.progress += r2.trig.direction < 0 ? 1e-3 : -1e-3, r2.trig.update(0, 0, 1), p2.resetTo("y", parseFloat(x2.y), -$2, true), G2 && p2.progress(1)));
                o3 > r2.end && (a2 += r2.distance), s2 -= r2.distance;
              }
              i3 = T2 + a2 + R22 * ((e$2.utils.clamp(t3.start, t3.end, o3) - t3.start - a2) / (s2 - t3.start) - u3);
            }
            P22.length && !g2 && P22.forEach((e2) => e2(i3 - a2)), l2 = i3 + m3, i3 = Math.round(1e5 * l2) / 1e5 || 0, p2 ? (p2.resetTo("y", i3, -$2, true), G2 && p2.progress(1)) : (x2.y = i3 + "px", x2.renderTransform(1));
          }
          var l2;
        }
      }), k22(f2), e$2.core.getCache(f2.trigger).stRevert = he2, f2.startY = T2, f2.pins = C22, f2.markers = P22, f2.ratio = h2, f2.autoSpeed = g2, t2.style.willChange = "transform"), f2;
    };
    function pe2() {
      return y2 = m2.clientHeight, m2.style.overflow = "visible", i$2.style.height = r.innerHeight + (y2 - r.innerHeight) / Y2 + "px", y2 - r.innerHeight;
    }
    ce2(), l$2.addEventListener("killAll", ce2), e$2.delayedCall(0.5, () => G2 = 0), this.scrollTop = re2, this.scrollTo = (t2, r2, o2) => {
      let s2 = e$2.utils.clamp(0, S(), isNaN(t2) ? this.offset(t2, o2, !!r2 && !R2) : +t2);
      r2 ? R2 ? e$2.to(this, {
        duration: j2,
        scrollTop: s2,
        overwrite: "auto",
        ease: d$1
      }) : D2(s2) : re2(s2);
    }, this.offset = (t2, r2, o2) => {
      let s2, i2 = (t2 = n$2(t2)[0]).style.cssText, a2 = l$2.create({
        trigger: t2,
        start: r2 || "top top"
      });
      return b2 && (G2 ? l$2.refresh() : ae2([a2], true)), s2 = a2.start / (o2 ? Y2 : 1), a2.kill(false), t2.style.cssText = i2, e$2.core.getCache(t2).uncache = 1, s2;
    }, this.content = function(t2) {
      if (arguments.length) {
        let r2 = n$2(t2 || "#smooth-content")[0] || console.warn("ScrollSmoother needs a valid content element.") || i$2.children[0];
        return r2 !== m2 && (m2 = r2, P2 = m2.getAttribute("style") || "", oe2 && oe2.observe(m2), e$2.set(m2, {
          overflow: "visible",
          width: "100%",
          boxSizing: "border-box",
          y: "+=0"
        }), j2 || e$2.set(m2, {
          clearProps: "transform"
        })), this;
      }
      return m2;
    }, this.wrapper = function(t2) {
      return arguments.length ? (v2 = n$2(t2 || "#smooth-wrapper")[0] || T$1(m2), E2 = v2.getAttribute("style") || "", pe2(), e$2.set(v2, j2 ? {
        overflow: "hidden",
        position: "fixed",
        height: "100%",
        width: "100%",
        top: 0,
        left: 0,
        right: 0,
        bottom: 0
      } : {
        overflow: "visible",
        position: "relative",
        width: "100%",
        height: "auto",
        top: "auto",
        bottom: "auto",
        left: "auto",
        right: "auto"
      }), this) : v2;
    }, this.effects = (e2, t2) => {
      if (b2 || (b2 = []), !e2)
        return b2.slice(0);
      (e2 = n$2(e2)).forEach(
        (e3) => {
          let t3 = b2.length;
          for (; t3--; )
            b2[t3].trigger === e3 && b2[t3].kill();
        }
      ), t2 = t2 || {};
      let r2, o2, { speed: s2, lag: i2, effectsPadding: a2 } = t2, c2 = [];
      for (r2 = 0; r2 < e2.length; r2++)
        o2 = ge2(e2[r2], s2, i2, r2, a2), o2 && c2.push(o2);
      return b2.push(...c2), false !== t2.refresh && l$2.refresh(), c2;
    }, this.sections = (e2, t2) => {
      if (C2 || (C2 = []), !e2)
        return C2.slice(0);
      let r2 = n$2(e2).map((e3) => l$2.create({
        trigger: e3,
        start: "top 120%",
        end: "bottom -20%",
        onToggle: (t3) => {
          e3.style.opacity = t3.isActive ? "1" : "0", e3.style.pointerEvents = t3.isActive ? "all" : "none";
        }
      }));
      return t2 && t2.add ? C2.push(...r2) : C2 = r2.slice(0), r2;
    }, this.content(u2.content), this.wrapper(u2.wrapper), this.render = (e2) => te2(e2 || 0 === e2 ? e2 : K2), this.getVelocity = () => J2.getVelocity(-K2), l$2.scrollerProxy(v2, {
      scrollTop: re2,
      scrollHeight: () => pe2() && i$2.scrollHeight,
      fixedMarkers: false !== u2.fixedMarkers && !!j2,
      content: m2,
      getBoundingClientRect: () => ({
        top: 0,
        left: 0,
        width: r.innerWidth,
        height: r.innerHeight
      })
    }), l$2.defaults({
      scroller: v2
    });
    let ue2 = l$2.getAll().filter((e2) => e2.scroller === r || e2.scroller === v2);
    ue2.forEach((e2) => e2.revert(true, true)), w2 = l$2.create({
      animation: e$2.fromTo(X2, {
        y: () => (M2 = 0, 0)
      }, {
        y: () => (M2 = 1, -pe2()),
        immediateRender: false,
        ease: "none",
        data: "ScrollSmoother",
        duration: 100,
        onUpdate: function() {
          if (M2) {
            let e2 = z2;
            e2 && (ee2(w2), X2.y = K2), te2(X2.y, e2), Q2(), B2 && !R2 && B2(V2);
          }
        }
      }),
      onRefreshInit: (e2) => {
        if (_x.isRefreshing)
          return;
        if (_x.isRefreshing = true, b2) {
          let e3 = l$2.getAll().filter((e4) => !!e4.pin);
          b2.forEach(
            (t3) => {
              t3.vars.pinnedContainer || e3.forEach(
                (e4) => {
                  if (e4.pin.contains(t3.trigger)) {
                    let r2 = t3.vars;
                    r2.pinnedContainer = e4.pin, t3.vars = null, t3.init(r2, t3.animation);
                  }
                }
              );
            }
          );
        }
        let t2 = e2.getTween();
        N2 = t2 && t2._end > t2._dp._time, A2 = K2, X2.y = 0, j2 && (1 === l$2.isTouch && (v2.style.position = "absolute"), v2.scrollTop = 0, 1 === l$2.isTouch && (v2.style.position = "fixed"));
      },
      onRefresh: (t2) => {
        t2.animation.invalidate(), t2.setPositions(t2.start, pe2() / Y2), N2 || ee2(t2), X2.y = -D2() * Y2, te2(X2.y), G2 || (N2 && (z2 = false), t2.animation.progress(e$2.utils.clamp(0, 1, A2 / Y2 / -t2.end))), N2 && (t2.progress -= 1e-3, t2.update()), _x.isRefreshing = false;
      },
      id: "ScrollSmoother",
      scroller: r,
      invalidateOnRefresh: true,
      start: 0,
      refreshPriority: -9999,
      end: () => pe2() / Y2,
      onScrubComplete: () => {
        J2.reset(), H2 && H2(this);
      },
      scrub: j2 || true
    }), this.smooth = function(e2) {
      return arguments.length && (j2 = e2 || 0, Y2 = j2 && +u2.speed || 1, w2.scrubDuration(e2)), w2.getTween() ? w2.getTween().duration() : 0;
    }, w2.getTween() && (w2.getTween().vars.ease = u2.ease || d$1), this.scrollTrigger = w2, u2.effects && this.effects(true === u2.effects ? "[data-" + W2 + "speed], [data-" + W2 + "lag]" : u2.effects, {
      effectsPadding: u2.effectsPadding,
      refresh: false
    }), u2.sections && this.sections(true === u2.sections ? "[data-section]" : u2.sections), ue2.forEach(
      (e2) => {
        e2.vars.scroller = v2, e2.revert(false, true), e2.init(e2.vars, e2.animation);
      }
    ), this.paused = function(e2, t2) {
      return arguments.length ? (!!R2 !== e2 && (e2 ? (w2.getTween() && w2.getTween().pause(), D2(-K2 / Y2), J2.reset(), k2 = l$2.normalizeScroll(), k2 && k2.disable(), R2 = l$2.observe({
        preventDefault: true,
        type: "wheel,touch,scroll",
        debounce: false,
        allowClicks: true,
        onChangeY: () => re2(-K2)
      }), R2.nested = f$1(s$2, "wheel,touch,scroll", true, false !== t2)) : (R2.nested.kill(), R2.kill(), R2 = 0, k2 && k2.enable(), w2.progress = (-K2 / Y2 - w2.start) / (w2.end - w2.start), ee2(w2))), this) : !!R2;
    }, this.kill = this.revert = () => {
      this.paused(false), ee2(w2), w2.kill();
      let e2 = (b2 || []).concat(C2 || []), t2 = e2.length;
      for (; t2--; )
        e2[t2].kill();
      l$2.scrollerProxy(v2), l$2.removeEventListener("killAll", ce2), l$2.removeEventListener("refresh", le2), v2.style.cssText = E2, m2.style.cssText = P2;
      let o2 = l$2.defaults({});
      o2 && o2.scroller === v2 && l$2.defaults({
        scroller: r
      }), this.normalizer && l$2.normalizeScroll(false), clearInterval(_2), c$2 = null, oe2 && oe2.disconnect(), i$2.style.removeProperty("height"), r.removeEventListener("focusin", se2);
    }, this.refresh = (e2, t2) => w2.refresh(e2, t2), U2 && (this.normalizer = l$2.normalizeScroll(true === U2 ? {
      debounce: true,
      content: !j2 && m2
    } : U2)), l$2.config(u2), "overscrollBehavior" in r.getComputedStyle(i$2) && e$2.set([i$2, s$2], {
      overscrollBehavior: "none"
    }), "scrollBehavior" in r.getComputedStyle(i$2) && e$2.set([i$2, s$2], {
      scrollBehavior: "auto"
    }), r.addEventListener("focusin", se2), _2 = setInterval(), "loading" === o$1.readyState || requestAnimationFrame(() => l$2.refresh());
  }
  get progress() {
    return this.scrollTrigger ? this.scrollTrigger.animation._time / 100 : 0;
  }
  static register(v2) {
    return e$2 = v2 || m$2(), e$2 && (n$2 = e$2.utils.toArray, a$1 = e$2.utils.clamp, d$1 = e$2.parseEase("expo"), g$2 = e$2.core.context || function() {
    }, l$2 = e$2.core.globals().ScrollTrigger, e$2.core.globals("ScrollSmoother", _x), i$2), t$2;
  }
};
x$2.version = "3.12.5", x$2.create = (e2) => c$2 && e2 && c$2.content() === n$2(e2.content)[0] ? c$2 : new x$2(e2), x$2.get = () => c$2, m$2() && e$2.registerPlugin(x$2);
var ScrollSmoother_default = x$2;
/*! Bundled license information:

  (*!
   * ScrollSmoother 3.12.5
   * https://gsap.com
   * 
   * @license Copyright 2024, GreenSock. All rights reserved.
   * *** DO NOT DEPLOY THIS FILE ***
   * This is a trial version that only works locally and on domains like codepen.io and codesandbox.io.
   * Loading it on an unauthorized domain violates the license and will cause a redirect.
   * Get the unrestricted file by joining Club GSAP at https://gsap.com/pricing
   * @author: Jack Doyle, jack@greensock.com
   *)
*/
const gsap_scroll_smoother_QW85FHtwvF = /* @__PURE__ */ defineNuxtPlugin(() => {
  return {
    provide: {
      ScrollSmoother: ScrollSmoother_default
    }
  };
});
var e$1;
var t$1;
var i$1;
var s$1;
var o;
var a;
var n$1;
var l$1;
var c$1;
var d;
var p;
var h$1;
var g$1;
var u$1 = () => e$1 || false;
var m$1 = [];
var v = [];
var y$1 = [];
var x$1 = Date.now;
var b$1 = (e2, t2) => t2;
var w$1 = (e2, t2) => ~y$1.indexOf(e2) && y$1[y$1.indexOf(e2) + 1][t2];
var _$1 = (e2) => !!~d.indexOf(e2);
var T = (e2, t2, r2, i2, s2) => e2.addEventListener(t2, r2, { passive: false !== i2, capture: !!s2 });
var k = (e2, t2, r2, i2) => e2.removeEventListener(t2, r2, !!i2);
var S$2 = () => p && p.isPressed || v.cache++;
var C$1 = (e2, t2) => {
  let r2 = (s2) => {
    if (s2 || 0 === s2) {
      i$1.history.scrollRestoration = "manual";
      let t3 = p && p.isPressed;
      s2 = r2.v = Math.round(s2) || (p && p.iOS ? 1 : 0), e2(s2), r2.cacheID = v.cache, t3 && b$1("ss", s2);
    } else
      (t2 || v.cache !== r2.cacheID || b$1("ref")) && (r2.cacheID = v.cache, r2.v = e2());
    return r2.v + r2.offset;
  };
  return r2.offset = 0, e2 && r2;
};
var E$1 = { s: "scrollLeft", p: "left", p2: "Left", os: "right", os2: "Right", d: "width", d2: "Width", a: "x", sc: C$1(function(e2) {
  return arguments.length ? i$1.scrollTo(e2, P.sc()) : i$1.pageXOffset || s$1.scrollLeft || o.scrollLeft || a.scrollLeft || 0;
}) };
var P = { s: "scrollTop", p: "top", p2: "Top", os: "bottom", os2: "Bottom", d: "height", d2: "Height", a: "y", op: E$1, sc: C$1(function(e2) {
  return arguments.length ? i$1.scrollTo(E$1.sc(), e2) : i$1.pageYOffset || s$1.scrollTop || o.scrollTop || a.scrollTop || 0;
}) };
var M = (t2, r2) => (r2 && r2._ctx && r2._ctx.selector || e$1.utils.toArray)(t2)[0] || ("string" == typeof t2 && false !== e$1.config().nullTargetWarn ? console.warn("Element not found:", t2) : null);
var O = (t2, { s: r2, sc: i2 }) => {
  _$1(t2) && (t2 = s$1.scrollingElement || o);
  let a2 = v.indexOf(t2), n2 = i2 === P.sc ? 1 : 2;
  !~a2 && (a2 = v.push(t2) - 1), v[a2 + n2] || T(t2, "scroll", S$2);
  let l2 = v[a2 + n2], c2 = l2 || (v[a2 + n2] = C$1(w$1(t2, r2), true) || (_$1(t2) ? i2 : C$1(function(e2) {
    return arguments.length ? t2[r2] = e2 : t2[r2];
  })));
  return c2.target = t2, l2 || (c2.smooth = "smooth" === e$1.getProperty(t2, "scrollBehavior")), c2;
};
var A$1 = (e2, t2, r2) => {
  let i2 = e2, s2 = e2, o2 = x$1(), a2 = o2, n2 = t2 || 50, l2 = Math.max(500, 3 * n2), c2 = (e3, t3) => {
    let l3 = x$1();
    t3 || l3 - o2 > n2 ? (s2 = i2, i2 = e3, a2 = o2, o2 = l3) : r2 ? i2 += e3 : i2 = s2 + (e3 - s2) / (l3 - a2) * (o2 - a2);
  };
  return { update: c2, reset: () => {
    s2 = i2 = r2 ? 0 : i2, a2 = o2 = 0;
  }, getVelocity: (e3) => {
    let t3 = a2, n3 = s2, d2 = x$1();
    return (e3 || 0 === e3) && e3 !== i2 && c2(e3), o2 === a2 || d2 - a2 > l2 ? 0 : (i2 + (r2 ? n3 : -n3)) / ((r2 ? d2 : o2) - t3) * 1e3;
  } };
};
var R = (e2, t2) => (t2 && !e2._gsapAllow && e2.preventDefault(), e2.changedTouches ? e2.changedTouches[0] : e2);
var D$1 = (e2) => {
  let t2 = Math.max(...e2), r2 = Math.min(...e2);
  return Math.abs(t2) >= Math.abs(r2) ? t2 : r2;
};
var Y = () => {
  c$1 = e$1.core.globals().ScrollTrigger, c$1 && c$1.core && (() => {
    let e2 = c$1.core, t2 = e2.bridge || {}, r2 = e2._scrollers, i2 = e2._proxies;
    r2.push(...v), i2.push(...y$1), v = r2, y$1 = i2, b$1 = (e3, r3) => t2[e3](r3);
  })();
};
var B$1 = (c2) => (e$1 = c2 || u$1(), t$1);
E$1.op = P, v.cache = 0;
var I = class {
  constructor(e2) {
    this.init(e2);
  }
  init(r2) {
    B$1(e$1) || console.warn("Please gsap.registerPlugin(Observer)"), c$1 || Y();
    let { tolerance: d2, dragMinimum: u2, type: f2, target: v2, lineHeight: y2, debounce: b2, preventDefault: w2, onStop: C2, onStopDelay: I2, ignore: X2, wheelSpeed: z2, event: L2, onDragStart: N2, onDragEnd: F2, onDrag: W2, onPress: H2, onRelease: q2, onRight: U2, onLeft: V2, onUp: G2, onDown: j2, onChangeX: K2, onChangeY: Z2, onChange: $2, onToggleX: J2, onToggleY: Q2, onHover: ee2, onHoverEnd: te2, onMove: re2, ignoreCheck: ie2, isNormalizer: se2, onGestureStart: oe2, onGestureEnd: ae2, onWheel: ne2, onEnable: le2, onDisable: ce2, onClick: de2, scrollSpeed: pe2, capture: he2, allowClicks: ge2, lockAxis: ue2, onLockAxis: fe2 } = r2;
    this.target = v2 = M(v2) || o, this.vars = r2, X2 && (X2 = e$1.utils.toArray(X2)), d2 = d2 || 1e-9, u2 = u2 || 0, z2 = z2 || 1, pe2 = pe2 || 1, f2 = f2 || "wheel,touch,pointer", b2 = false !== b2, y2 || (y2 = parseFloat(i$1.getComputedStyle(a).lineHeight) || 22);
    let me2, ve2, ye2, xe2, be2, we2, _e2, Te2 = this, ke2 = 0, Se2 = 0, Ce2 = r2.passive || !w2, Ee2 = O(v2, E$1), Pe2 = O(v2, P), Me2 = Ee2(), Oe2 = Pe2(), Ae2 = ~f2.indexOf("touch") && !~f2.indexOf("pointer") && "pointerdown" === h$1[0], Re2 = _$1(v2), De2 = v2.ownerDocument || s$1, Ye2 = [0, 0, 0], Be2 = [0, 0, 0], Ie2 = 0, Xe2 = () => Ie2 = x$1(), ze2 = (e2, t2) => (Te2.event = e2) && X2 && ~X2.indexOf(e2.target) || t2 && Ae2 && "touch" !== e2.pointerType || ie2 && ie2(e2, t2), Le2 = () => {
      let e2 = Te2.deltaX = D$1(Ye2), t2 = Te2.deltaY = D$1(Be2), r3 = Math.abs(e2) >= d2, i2 = Math.abs(t2) >= d2;
      $2 && (r3 || i2) && $2(Te2, e2, t2, Ye2, Be2), r3 && (U2 && Te2.deltaX > 0 && U2(Te2), V2 && Te2.deltaX < 0 && V2(Te2), K2 && K2(Te2), J2 && Te2.deltaX < 0 != ke2 < 0 && J2(Te2), ke2 = Te2.deltaX, Ye2[0] = Ye2[1] = Ye2[2] = 0), i2 && (j2 && Te2.deltaY > 0 && j2(Te2), G2 && Te2.deltaY < 0 && G2(Te2), Z2 && Z2(Te2), Q2 && Te2.deltaY < 0 != Se2 < 0 && Q2(Te2), Se2 = Te2.deltaY, Be2[0] = Be2[1] = Be2[2] = 0), (xe2 || ye2) && (re2 && re2(Te2), ye2 && (W2(Te2), ye2 = false), xe2 = false), we2 && !(we2 = false) && fe2 && fe2(Te2), be2 && (ne2(Te2), be2 = false), me2 = 0;
    }, Ne2 = (e2, t2, r3) => {
      Ye2[r3] += e2, Be2[r3] += t2, Te2._vx.update(e2), Te2._vy.update(t2), b2 ? me2 || (me2 = requestAnimationFrame(Le2)) : Le2();
    }, Fe2 = (e2, t2) => {
      ue2 && !_e2 && (Te2.axis = _e2 = Math.abs(e2) > Math.abs(t2) ? "x" : "y", we2 = true), "y" !== _e2 && (Ye2[2] += e2, Te2._vx.update(e2, true)), "x" !== _e2 && (Be2[2] += t2, Te2._vy.update(t2, true)), b2 ? me2 || (me2 = requestAnimationFrame(Le2)) : Le2();
    }, We2 = (e2) => {
      if (ze2(e2, 1))
        return;
      let t2 = (e2 = R(e2, w2)).clientX, r3 = e2.clientY, i2 = t2 - Te2.x, s2 = r3 - Te2.y, o2 = Te2.isDragging;
      Te2.x = t2, Te2.y = r3, (o2 || Math.abs(Te2.startX - t2) >= u2 || Math.abs(Te2.startY - r3) >= u2) && (W2 && (ye2 = true), o2 || (Te2.isDragging = true), Fe2(i2, s2), o2 || N2 && N2(Te2));
    }, He2 = Te2.onPress = (e2) => {
      ze2(e2, 1) || e2 && e2.button || (Te2.axis = _e2 = null, ve2.pause(), Te2.isPressed = true, e2 = R(e2), ke2 = Se2 = 0, Te2.startX = Te2.x = e2.clientX, Te2.startY = Te2.y = e2.clientY, Te2._vx.reset(), Te2._vy.reset(), T(se2 ? v2 : De2, h$1[1], We2, Ce2, true), Te2.deltaX = Te2.deltaY = 0, H2 && H2(Te2));
    }, qe2 = Te2.onRelease = (t2) => {
      if (ze2(t2, 1))
        return;
      k(se2 ? v2 : De2, h$1[1], We2, true);
      let r3 = !isNaN(Te2.y - Te2.startY), s2 = Te2.isDragging, o2 = s2 && (Math.abs(Te2.x - Te2.startX) > 3 || Math.abs(Te2.y - Te2.startY) > 3), a2 = R(t2);
      !o2 && r3 && (Te2._vx.reset(), Te2._vy.reset(), w2 && ge2 && e$1.delayedCall(0.08, () => {
        if (x$1() - Ie2 > 300 && !t2.defaultPrevented) {
          if (t2.target.click)
            t2.target.click();
          else if (De2.createEvent) {
            let e2 = De2.createEvent("MouseEvents");
            e2.initMouseEvent("click", true, true, i$1, 1, a2.screenX, a2.screenY, a2.clientX, a2.clientY, false, false, false, false, 0, null), t2.target.dispatchEvent(e2);
          }
        }
      })), Te2.isDragging = Te2.isGesturing = Te2.isPressed = false, C2 && s2 && !se2 && ve2.restart(true), F2 && s2 && F2(Te2), q2 && q2(Te2, o2);
    }, Ue2 = (e2) => e2.touches && e2.touches.length > 1 && (Te2.isGesturing = true) && oe2(e2, Te2.isDragging), Ve2 = () => (Te2.isGesturing = false) || ae2(Te2), Ge2 = (e2) => {
      if (ze2(e2))
        return;
      let t2 = Ee2(), r3 = Pe2();
      Ne2((t2 - Me2) * pe2, (r3 - Oe2) * pe2, 1), Me2 = t2, Oe2 = r3, C2 && ve2.restart(true);
    }, je2 = (e2) => {
      if (ze2(e2))
        return;
      e2 = R(e2, w2), ne2 && (be2 = true);
      let t2 = (1 === e2.deltaMode ? y2 : 2 === e2.deltaMode ? i$1.innerHeight : 1) * z2;
      Ne2(e2.deltaX * t2, e2.deltaY * t2, 0), C2 && !se2 && ve2.restart(true);
    }, Ke2 = (e2) => {
      if (ze2(e2))
        return;
      let t2 = e2.clientX, r3 = e2.clientY, i2 = t2 - Te2.x, s2 = r3 - Te2.y;
      Te2.x = t2, Te2.y = r3, xe2 = true, C2 && ve2.restart(true), (i2 || s2) && Fe2(i2, s2);
    }, Ze2 = (e2) => {
      Te2.event = e2, ee2(Te2);
    }, $e2 = (e2) => {
      Te2.event = e2, te2(Te2);
    }, Je2 = (e2) => ze2(e2) || R(e2, w2) && de2(Te2);
    ve2 = Te2._dc = e$1.delayedCall(I2 || 0.25, () => {
      Te2._vx.reset(), Te2._vy.reset(), ve2.pause(), C2 && C2(Te2);
    }).pause(), Te2.deltaX = Te2.deltaY = 0, Te2._vx = A$1(0, 50, true), Te2._vy = A$1(0, 50, true), Te2.scrollX = Ee2, Te2.scrollY = Pe2, Te2.isDragging = Te2.isGesturing = Te2.isPressed = false, g$1(this), Te2.enable = (e2) => (Te2.isEnabled || (T(Re2 ? De2 : v2, "scroll", S$2), f2.indexOf("scroll") >= 0 && T(Re2 ? De2 : v2, "scroll", Ge2, Ce2, he2), f2.indexOf("wheel") >= 0 && T(v2, "wheel", je2, Ce2, he2), (f2.indexOf("touch") >= 0 && n$1 || f2.indexOf("pointer") >= 0) && (T(v2, h$1[0], He2, Ce2, he2), T(De2, h$1[2], qe2), T(De2, h$1[3], qe2), ge2 && T(v2, "click", Xe2, true, true), de2 && T(v2, "click", Je2), oe2 && T(De2, "gesturestart", Ue2), ae2 && T(De2, "gestureend", Ve2), ee2 && T(v2, l$1 + "enter", Ze2), te2 && T(v2, l$1 + "leave", $e2), re2 && T(v2, l$1 + "move", Ke2)), Te2.isEnabled = true, e2 && e2.type && He2(e2), le2 && le2(Te2)), Te2), Te2.disable = () => {
      Te2.isEnabled && (m$1.filter((e2) => e2 !== Te2 && _$1(e2.target)).length || k(Re2 ? De2 : v2, "scroll", S$2), Te2.isPressed && (Te2._vx.reset(), Te2._vy.reset(), k(se2 ? v2 : De2, h$1[1], We2, true)), k(Re2 ? De2 : v2, "scroll", Ge2, he2), k(v2, "wheel", je2, he2), k(v2, h$1[0], He2, he2), k(De2, h$1[2], qe2), k(De2, h$1[3], qe2), k(v2, "click", Xe2, true), k(v2, "click", Je2), k(De2, "gesturestart", Ue2), k(De2, "gestureend", Ve2), k(v2, l$1 + "enter", Ze2), k(v2, l$1 + "leave", $e2), k(v2, l$1 + "move", Ke2), Te2.isEnabled = Te2.isPressed = Te2.isDragging = false, ce2 && ce2(Te2));
    }, Te2.kill = Te2.revert = () => {
      Te2.disable();
      let e2 = m$1.indexOf(Te2);
      e2 >= 0 && m$1.splice(e2, 1), p === Te2 && (p = 0);
    }, m$1.push(Te2), se2 && _$1(v2) && (p = Te2), Te2.enable(L2);
  }
  get velocityX() {
    return this._vx.getVelocity();
  }
  get velocityY() {
    return this._vy.getVelocity();
  }
};
I.version = "3.12.5", I.create = (e2) => new I(e2), I.register = B$1, I.getAll = () => m$1.slice(), I.getById = (e2) => m$1.filter((t2) => t2.vars.id === e2)[0], u$1() && e$1.registerPlugin(I);
var X;
var z;
var L;
var N;
var F$1;
var W;
var H;
var q;
var U;
var V;
var G;
var j;
var K;
var Z;
var $;
var J;
var Q;
var ee;
var te;
var re;
var ie;
var se;
var oe;
var ae;
var ne;
var le;
var ce;
var de;
var pe;
var he;
var ge;
var ue;
var fe;
var me;
var ve;
var ye;
var xe;
var be;
var we = 1;
var _e = Date.now;
var Te = _e();
var ke = 0;
var Se = 0;
var Ce = (e2, t2, r2) => {
  let i2 = Ne(e2) && ("clamp(" === e2.substr(0, 6) || e2.indexOf("max") > -1);
  return r2["_" + t2 + "Clamp"] = i2, i2 ? e2.substr(6, e2.length - 7) : e2;
};
var Ee = (e2, t2) => !t2 || Ne(e2) && "clamp(" === e2.substr(0, 6) ? e2 : "clamp(" + e2 + ")";
var Pe = () => Se && requestAnimationFrame(Pe);
var Me = () => Z = 1;
var Oe = () => Z = 0;
var Ae = (e2) => e2;
var Re = (e2) => Math.round(1e5 * e2) / 1e5 || 0;
var De = () => false;
var Ye = () => X || De();
var Be = (e2) => !!~H.indexOf(e2);
var Ie = (e2) => ("Height" === e2 ? ge : L["inner" + e2]) || F$1["client" + e2] || W["client" + e2];
var Xe = (e2) => w$1(e2, "getBoundingClientRect") || (Be(e2) ? () => (zt.width = L.innerWidth, zt.height = ge, zt) : () => $e(e2));
var ze = (e2, { s: t2, d2: r2, d: i2, a: s2 }) => Math.max(0, (t2 = "scroll" + r2) && (s2 = w$1(e2, t2)) ? s2() - Xe(e2)()[i2] : Be(e2) ? (F$1[t2] || W[t2]) - Ie(r2) : e2[t2] - e2["offset" + r2]);
var Le = (e2, t2) => {
  for (let r2 = 0; r2 < te.length; r2 += 3)
    (!t2 || ~t2.indexOf(te[r2 + 1])) && e2(te[r2], te[r2 + 1], te[r2 + 2]);
};
var Ne = (e2) => "string" == typeof e2;
var Fe = (e2) => "function" == typeof e2;
var We = (e2) => "number" == typeof e2;
var He = (e2) => "object" == typeof e2;
var qe = (e2, t2, r2) => e2 && e2.progress(t2 ? 0 : 1) && r2 && e2.pause();
var Ue = (e2, t2) => {
  if (e2.enabled) {
    let r2 = e2._ctx ? e2._ctx.add(() => t2(e2)) : t2(e2);
    r2 && r2.totalTime && (e2.callbackAnimation = r2);
  }
};
var Ve = Math.abs;
var Ge = "padding";
var je = "px";
var Ke = (e2) => L.getComputedStyle(e2);
var Ze = (e2, t2) => {
  for (let r2 in t2)
    r2 in e2 || (e2[r2] = t2[r2]);
  return e2;
};
var $e = (e2, t2) => {
  let r2 = t2 && "matrix(1, 0, 0, 1, 0, 0)" !== Ke(e2)[$] && X.to(e2, { x: 0, y: 0, xPercent: 0, yPercent: 0, rotation: 0, rotationX: 0, rotationY: 0, scale: 1, skewX: 0, skewY: 0 }).progress(1), i2 = e2.getBoundingClientRect();
  return r2 && r2.progress(0).kill(), i2;
};
var Je = (e2, { d2: t2 }) => e2["offset" + t2] || e2["client" + t2] || 0;
var Qe = (e2) => {
  let t2, r2 = [], i2 = e2.labels, s2 = e2.duration();
  for (t2 in i2)
    r2.push(i2[t2] / s2);
  return r2;
};
var et = (e2) => {
  let t2 = X.utils.snap(e2), r2 = Array.isArray(e2) && e2.slice(0).sort((e3, t3) => e3 - t3);
  return r2 ? (e3, i2, s2 = 1e-3) => {
    let o2;
    if (!i2)
      return t2(e3);
    if (i2 > 0) {
      for (e3 -= s2, o2 = 0; o2 < r2.length; o2++)
        if (r2[o2] >= e3)
          return r2[o2];
      return r2[o2 - 1];
    }
    for (o2 = r2.length, e3 += s2; o2--; )
      if (r2[o2] <= e3)
        return r2[o2];
    return r2[0];
  } : (r3, i2, s2 = 1e-3) => {
    let o2 = t2(r3);
    return !i2 || Math.abs(o2 - r3) < s2 || o2 - r3 < 0 == i2 < 0 ? o2 : t2(i2 < 0 ? r3 - e2 : r3 + e2);
  };
};
var tt = (e2, t2, r2, i2) => r2.split(",").forEach((r3) => e2(t2, r3, i2));
var rt = (e2, t2, r2, i2, s2) => e2.addEventListener(t2, r2, { passive: !i2, capture: !!s2 });
var it = (e2, t2, r2, i2) => e2.removeEventListener(t2, r2, !!i2);
var st = (e2, t2, r2) => {
  (r2 = r2 && r2.wheelHandler) && (e2(t2, "wheel", r2), e2(t2, "touchmove", r2));
};
var ot = { startColor: "green", endColor: "red", indent: 0, fontSize: "16px", fontWeight: "normal" };
var at = { toggleActions: "play", anticipatePin: 0 };
var nt = { top: 0, left: 0, center: 0.5, bottom: 1, right: 1 };
var lt = (e2, t2) => {
  if (Ne(e2)) {
    let r2 = e2.indexOf("="), i2 = ~r2 ? +(e2.charAt(r2 - 1) + 1) * parseFloat(e2.substr(r2 + 1)) : 0;
    ~r2 && (e2.indexOf("%") > r2 && (i2 *= t2 / 100), e2 = e2.substr(0, r2 - 1)), e2 = i2 + (e2 in nt ? nt[e2] * t2 : ~e2.indexOf("%") ? parseFloat(e2) * t2 / 100 : parseFloat(e2) || 0);
  }
  return e2;
};
var ct = (e2, t2, r2, i2, { startColor: s2, endColor: o2, fontSize: a2, indent: n2, fontWeight: l2 }, c2, d2, p2) => {
  let h2 = N.createElement("div"), g2 = Be(r2) || "fixed" === w$1(r2, "pinType"), u2 = -1 !== e2.indexOf("scroller"), f2 = g2 ? W : r2, m2 = -1 !== e2.indexOf("start"), v2 = m2 ? s2 : o2, y2 = "border-color:" + v2 + ";font-size:" + a2 + ";color:" + v2 + ";font-weight:" + l2 + ";pointer-events:none;white-space:nowrap;font-family:sans-serif,Arial;z-index:1000;padding:4px 8px;border-width:0;border-style:solid;";
  return y2 += "position:" + ((u2 || p2) && g2 ? "fixed;" : "absolute;"), (u2 || p2 || !g2) && (y2 += (i2 === P ? "right" : "bottom") + ":" + (c2 + parseFloat(n2)) + "px;"), d2 && (y2 += "box-sizing:border-box;text-align:left;width:" + d2.offsetWidth + "px;"), h2._isStart = m2, h2.setAttribute("class", "gsap-marker-" + e2 + (t2 ? " marker-" + t2 : "")), h2.style.cssText = y2, h2.innerText = t2 || 0 === t2 ? e2 + "-" + t2 : e2, f2.children[0] ? f2.insertBefore(h2, f2.children[0]) : f2.appendChild(h2), h2._offset = h2["offset" + i2.op.d2], dt(h2, 0, i2, m2), h2;
};
var dt = (e2, t2, r2, i2) => {
  let s2 = { display: "block" }, o2 = r2[i2 ? "os2" : "p2"], a2 = r2[i2 ? "p2" : "os2"];
  e2._isFlipped = i2, s2[r2.a + "Percent"] = i2 ? -100 : 0, s2[r2.a] = i2 ? "1px" : 0, s2["border" + o2 + "Width"] = 1, s2["border" + a2 + "Width"] = 0, s2[r2.p] = t2 + "px", X.set(e2, s2);
};
var pt = [];
var ht = {};
var ut = () => {
  (!oe || !oe.isPressed || oe.startX > W.clientWidth) && (v.cache++, oe ? ve || (ve = requestAnimationFrame(At)) : At(), ke || bt("scrollStart"), ke = _e());
};
var ft = () => {
  le = L.innerWidth, ne = L.innerHeight;
};
var mt = () => {
  v.cache++, !K && !se && !N.fullscreenElement && !N.webkitFullscreenElement && (!ae || le !== L.innerWidth || Math.abs(L.innerHeight - ne) > 0.25 * L.innerHeight) && q.restart(true);
};
var vt = {};
var yt = [];
var xt = () => it(Ut, "scrollEnd", xt) || Pt(true);
var bt = (e2) => vt[e2] && vt[e2].map((e3) => e3()) || yt;
var wt = [];
var _t = (e2) => {
  for (let t2 = 0; t2 < wt.length; t2 += 5)
    (!e2 || wt[t2 + 4] && wt[t2 + 4].query === e2) && (wt[t2].style.cssText = wt[t2 + 1], wt[t2].getBBox && wt[t2].setAttribute("transform", wt[t2 + 2] || ""), wt[t2 + 3].uncache = 1);
};
var Tt = (e2, t2) => {
  let r2;
  for (J = 0; J < pt.length; J++)
    r2 = pt[J], !r2 || t2 && r2._ctx !== t2 || (e2 ? r2.kill(1) : r2.revert(true, true));
  ue = true, t2 && _t(t2), t2 || bt("revert");
};
var kt = (e2, t2) => {
  v.cache++, (t2 || !ye) && v.forEach((e3) => Fe(e3) && e3.cacheID++ && (e3.rec = 0)), Ne(e2) && (L.history.scrollRestoration = pe = e2);
};
var St = 0;
var Ct = () => {
  W.appendChild(he), ge = !oe && he.offsetHeight || L.innerHeight, W.removeChild(he);
};
var Et = (e2) => U(".gsap-marker-start, .gsap-marker-end, .gsap-marker-scroller-start, .gsap-marker-scroller-end").forEach((t2) => t2.style.display = e2 ? "none" : "block");
var Pt = (e2, t2) => {
  if (ke && !e2 && !ue)
    return void rt(Ut, "scrollEnd", xt);
  Ct(), ye = Ut.isRefreshing = true, v.forEach((e3) => Fe(e3) && ++e3.cacheID && (e3.rec = e3()));
  let r2 = bt("refreshInit");
  re && Ut.sort(), t2 || Tt(), v.forEach((e3) => {
    Fe(e3) && (e3.smooth && (e3.target.style.scrollBehavior = "auto"), e3(0));
  }), pt.slice(0).forEach((e3) => e3.refresh()), ue = false, pt.forEach((e3) => {
    if (e3._subPinOffset && e3.pin) {
      let t3 = e3.vars.horizontal ? "offsetWidth" : "offsetHeight", r3 = e3.pin[t3];
      e3.revert(true, 1), e3.adjustPinSpacing(e3.pin[t3] - r3), e3.refresh();
    }
  }), fe = 1, Et(true), pt.forEach((e3) => {
    let t3 = ze(e3.scroller, e3._dir), r3 = "max" === e3.vars.end || e3._endClamp && e3.end > t3, i2 = e3._startClamp && e3.start >= t3;
    (r3 || i2) && e3.setPositions(i2 ? t3 - 1 : e3.start, r3 ? Math.max(i2 ? t3 : e3.start + 1, t3) : e3.end, true);
  }), Et(false), fe = 0, r2.forEach((e3) => e3 && e3.render && e3.render(-1)), v.forEach((e3) => {
    Fe(e3) && (e3.smooth && requestAnimationFrame(() => e3.target.style.scrollBehavior = "smooth"), e3.rec && e3(e3.rec));
  }), kt(pe, 1), q.pause(), St++, ye = 2, At(2), pt.forEach((e3) => Fe(e3.vars.onRefresh) && e3.vars.onRefresh(e3)), ye = Ut.isRefreshing = false, bt("refresh");
};
var Mt = 0;
var Ot = 1;
var At = (e2) => {
  if (2 === e2 || !ye && !ue) {
    Ut.isUpdating = true, be && be.update(0);
    let e3 = pt.length, t2 = _e(), r2 = t2 - Te >= 50, i2 = e3 && pt[0].scroll();
    if (Ot = Mt > i2 ? -1 : 1, ye || (Mt = i2), r2 && (ke && !Z && t2 - ke > 200 && (ke = 0, bt("scrollEnd")), G = Te, Te = t2), Ot < 0) {
      for (J = e3; J-- > 0; )
        pt[J] && pt[J].update(0, r2);
      Ot = 1;
    } else
      for (J = 0; J < e3; J++)
        pt[J] && pt[J].update(0, r2);
    Ut.isUpdating = false;
  }
  ve = 0;
};
var Rt = ["left", "top", "bottom", "right", "marginBottom", "marginRight", "marginTop", "marginLeft", "display", "flexShrink", "float", "zIndex", "gridColumnStart", "gridColumnEnd", "gridRowStart", "gridRowEnd", "gridArea", "justifySelf", "alignSelf", "placeSelf", "order"];
var Dt = Rt.concat(["width", "height", "boxSizing", "maxWidth", "maxHeight", "position", "margin", Ge, "paddingTop", "paddingRight", "paddingBottom", "paddingLeft"]);
var Yt = (e2, t2, r2, i2) => {
  if (!e2._gsap.swappedIn) {
    let s2, o2 = Rt.length, a2 = t2.style, n2 = e2.style;
    for (; o2--; )
      s2 = Rt[o2], a2[s2] = r2[s2];
    a2.position = "absolute" === r2.position ? "absolute" : "relative", "inline" === r2.display && (a2.display = "inline-block"), n2.bottom = n2.right = "auto", a2.flexBasis = r2.flexBasis || "auto", a2.overflow = "visible", a2.boxSizing = "border-box", a2.width = Je(e2, E$1) + je, a2.height = Je(e2, P) + je, a2.padding = n2.margin = n2.top = n2.left = "0", It(i2), n2.width = n2.maxWidth = r2.width, n2.height = n2.maxHeight = r2.height, n2.padding = r2.padding, e2.parentNode !== t2 && (e2.parentNode.insertBefore(t2, e2), t2.appendChild(e2)), e2._gsap.swappedIn = true;
  }
};
var Bt = /([A-Z])/g;
var It = (e2) => {
  if (e2) {
    let t2, r2, i2 = e2.t.style, s2 = e2.length, o2 = 0;
    for ((e2.t._gsap || X.core.getCache(e2.t)).uncache = 1; o2 < s2; o2 += 2)
      r2 = e2[o2 + 1], t2 = e2[o2], r2 ? i2[t2] = r2 : i2[t2] && i2.removeProperty(t2.replace(Bt, "-$1").toLowerCase());
  }
};
var Xt = (e2) => {
  let t2 = Dt.length, r2 = e2.style, i2 = [], s2 = 0;
  for (; s2 < t2; s2++)
    i2.push(Dt[s2], r2[Dt[s2]]);
  return i2.t = e2, i2;
};
var zt = { left: 0, top: 0 };
var Lt = (e2, t2, r2, i2, s2, o2, a2, n2, l2, c2, d2, p2, h2, g2) => {
  Fe(e2) && (e2 = e2(n2)), Ne(e2) && "max" === e2.substr(0, 3) && (e2 = p2 + ("=" === e2.charAt(4) ? lt("0" + e2.substr(3), r2) : 0));
  let u2, f2, m2, v2 = h2 ? h2.time() : 0;
  if (h2 && h2.seek(0), isNaN(e2) || (e2 = +e2), We(e2))
    h2 && (e2 = X.utils.mapRange(h2.scrollTrigger.start, h2.scrollTrigger.end, 0, p2, e2)), a2 && dt(a2, r2, i2, true);
  else {
    Fe(t2) && (t2 = t2(n2));
    let o3, d3, p3, h3, g3 = (e2 || "0").split(" ");
    m2 = M(t2, n2) || W, o3 = $e(m2) || {}, o3 && (o3.left || o3.top) || "none" !== Ke(m2).display || (h3 = m2.style.display, m2.style.display = "block", o3 = $e(m2), h3 ? m2.style.display = h3 : m2.style.removeProperty("display")), d3 = lt(g3[0], o3[i2.d]), p3 = lt(g3[1] || "0", r2), e2 = o3[i2.p] - l2[i2.p] - c2 + d3 + s2 - p3, a2 && dt(a2, p3, i2, r2 - p3 < 20 || a2._isStart && p3 > 20), r2 -= r2 - p3;
  }
  if (g2 && (n2[g2] = e2 || -1e-3, e2 < 0 && (e2 = 0)), o2) {
    let t3 = e2 + r2, s3 = o2._isStart;
    u2 = "scroll" + i2.d2, dt(o2, t3, i2, s3 && t3 > 20 || !s3 && (d2 ? Math.max(W[u2], F$1[u2]) : o2.parentNode[u2]) <= t3 + 1), d2 && (l2 = $e(a2), d2 && (o2.style[i2.op.p] = l2[i2.op.p] - i2.op.m - o2._offset + je));
  }
  return h2 && m2 && (u2 = $e(m2), h2.seek(p2), f2 = $e(m2), h2._caScrollDist = u2[i2.p] - f2[i2.p], e2 = e2 / h2._caScrollDist * p2), h2 && h2.seek(v2), h2 ? e2 : Math.round(e2);
};
var Nt = /(webkit|moz|length|cssText|inset)/i;
var Ft = (e2, t2, r2, i2) => {
  if (e2.parentNode !== t2) {
    let s2, o2, a2 = e2.style;
    if (t2 === W) {
      for (s2 in e2._stOrig = a2.cssText, o2 = Ke(e2), o2)
        +s2 || Nt.test(s2) || !o2[s2] || "string" != typeof a2[s2] || "0" === s2 || (a2[s2] = o2[s2]);
      a2.top = r2, a2.left = i2;
    } else
      a2.cssText = e2._stOrig;
    X.core.getCache(e2).uncache = 1, t2.appendChild(e2);
  }
};
var Wt = (e2, t2, r2) => {
  let i2 = t2, s2 = i2;
  return (t3) => {
    let o2 = Math.round(e2());
    return o2 !== i2 && o2 !== s2 && Math.abs(o2 - i2) > 3 && Math.abs(o2 - s2) > 3 && (t3 = o2, r2 && r2()), s2 = i2, i2 = t3, t3;
  };
};
var Ht = (e2, t2, r2) => {
  let i2 = {};
  i2[t2.p] = "+=" + r2, X.set(e2, i2);
};
var qt = (e2, t2) => {
  let r2 = O(e2, t2), i2 = "_scroll" + t2.p2, s2 = (t3, o2, a2, n2, l2) => {
    let c2 = s2.tween, d2 = o2.onComplete, p2 = {};
    a2 = a2 || r2();
    let h2 = Wt(r2, a2, () => {
      c2.kill(), s2.tween = 0;
    });
    return l2 = n2 && l2 || 0, n2 = n2 || t3 - a2, c2 && c2.kill(), o2[i2] = t3, o2.inherit = false, o2.modifiers = p2, p2[i2] = () => h2(a2 + n2 * c2.ratio + l2 * c2.ratio * c2.ratio), o2.onUpdate = () => {
      v.cache++, s2.tween && At();
    }, o2.onComplete = () => {
      s2.tween = 0, d2 && d2.call(c2);
    }, c2 = s2.tween = X.to(e2, o2), c2;
  };
  return e2[i2] = r2, r2.wheelHandler = () => s2.tween && s2.tween.kill() && (s2.tween = 0), rt(e2, "wheel", r2.wheelHandler), Ut.isTouch && rt(e2, "touchmove", r2.wheelHandler), s2;
};
var Ut = class _Ut {
  constructor(e2, t2) {
    z || _Ut.register(X) || console.warn("Please gsap.registerPlugin(ScrollTrigger)"), de(this), this.init(e2, t2);
  }
  init(e2, t2) {
    if (this.progress = this.start = 0, this.vars && this.kill(true, true), !Se)
      return void (this.update = this.refresh = this.kill = Ae);
    e2 = Ze(Ne(e2) || We(e2) || e2.nodeType ? { trigger: e2 } : e2, at);
    let r2, i2, s2, o2, a2, n2, l2, c2, d2, p2, h2, g2, u2, f2, m2, x2, b2, _2, T2, k2, S2, C2, A2, R2, D2, Y2, B2, I2, z2, H2, q2, j2, $2, Q2, ee2, te2, se2, oe2, ae2, { onUpdate: ne2, toggleClass: le2, id: ce2, onToggle: de2, onRefresh: pe2, scrub: he2, trigger: ge2, pin: ue2, pinSpacing: ve2, invalidateOnRefresh: Te2, anticipatePin: Pe2, onScrubComplete: Me2, onSnapComplete: Oe2, once: De2, snap: Ye2, pinReparent: Le2, pinSpacer: tt2, containerAnimation: st2, fastScrollEnd: nt2, preventOverlaps: dt2 } = e2, gt2 = e2.horizontal || e2.containerAnimation && false !== e2.horizontal ? E$1 : P, ft2 = !he2 && 0 !== he2, vt2 = M(e2.scroller || L), yt2 = X.core.getCache(vt2), bt2 = Be(vt2), wt2 = "fixed" === ("pinType" in e2 ? e2.pinType : w$1(vt2, "pinType") || bt2 && "fixed"), _t2 = [e2.onEnter, e2.onLeave, e2.onEnterBack, e2.onLeaveBack], Tt2 = ft2 && e2.toggleActions.split(" "), kt2 = "markers" in e2 ? e2.markers : at.markers, Ct2 = bt2 ? 0 : parseFloat(Ke(vt2)["border" + gt2.p2 + "Width"]) || 0, Et2 = this, Mt2 = e2.onRefreshInit && (() => e2.onRefreshInit(Et2)), At2 = ((e3, t3, { d: r3, d2: i3, a: s3 }) => (s3 = w$1(e3, "getBoundingClientRect")) ? () => s3()[r3] : () => (t3 ? Ie(i3) : e3["client" + i3]) || 0)(vt2, bt2, gt2), Rt2 = ((e3, t3) => !t3 || ~y$1.indexOf(e3) ? Xe(e3) : () => zt)(vt2, bt2), Dt2 = 0, Bt2 = 0, Nt2 = 0, Wt2 = O(vt2, gt2);
    var Vt2;
    if (Et2._startClamp = Et2._endClamp = false, Et2._dir = gt2, Pe2 *= 45, Et2.scroller = vt2, Et2.scroll = st2 ? st2.time.bind(st2) : Wt2, o2 = Wt2(), Et2.vars = e2, t2 = t2 || e2.animation, "refreshPriority" in e2 && (re = 1, -9999 === e2.refreshPriority && (be = Et2)), yt2.tweenScroll = yt2.tweenScroll || { top: qt(vt2, P), left: qt(vt2, E$1) }, Et2.tweenTo = r2 = yt2.tweenScroll[gt2.p], Et2.scrubDuration = (e3) => {
      $2 = We(e3) && e3, $2 ? j2 ? j2.duration(e3) : j2 = X.to(t2, { ease: "expo", totalProgress: "+=0", inherit: false, duration: $2, paused: true, onComplete: () => Me2 && Me2(Et2) }) : (j2 && j2.progress(1).kill(), j2 = 0);
    }, t2 && (t2.vars.lazy = false, t2._initted && !Et2.isReverted || false !== t2.vars.immediateRender && false !== e2.immediateRender && t2.duration() && t2.render(0, true, true), Et2.animation = t2.pause(), t2.scrollTrigger = Et2, Et2.scrubDuration(he2), H2 = 0, ce2 || (ce2 = t2.vars.id)), Ye2 && (He(Ye2) && !Ye2.push || (Ye2 = { snapTo: Ye2 }), "scrollBehavior" in W.style && X.set(bt2 ? [W, F$1] : vt2, { scrollBehavior: "auto" }), v.forEach((e3) => Fe(e3) && e3.target === (bt2 ? N.scrollingElement || F$1 : vt2) && (e3.smooth = false)), s2 = Fe(Ye2.snapTo) ? Ye2.snapTo : "labels" === Ye2.snapTo ? /* @__PURE__ */ ((e3) => (t3) => X.utils.snap(Qe(e3), t3))(t2) : "labelsDirectional" === Ye2.snapTo ? (Vt2 = t2, (e3, t3) => et(Qe(Vt2))(e3, t3.direction)) : false !== Ye2.directional ? (e3, t3) => et(Ye2.snapTo)(e3, _e() - Bt2 < 500 ? 0 : t3.direction) : X.utils.snap(Ye2.snapTo), Q2 = Ye2.duration || { min: 0.1, max: 2 }, Q2 = He(Q2) ? V(Q2.min, Q2.max) : V(Q2, Q2), ee2 = X.delayedCall(Ye2.delay || $2 / 2 || 0.1, () => {
      let e3 = Wt2(), i3 = _e() - Bt2 < 500, o3 = r2.tween;
      if (!(i3 || Math.abs(Et2.getVelocity()) < 10) || o3 || Z || Dt2 === e3)
        Et2.isActive && Dt2 !== e3 && ee2.restart(true);
      else {
        let a3, c3, d3 = (e3 - n2) / f2, p3 = t2 && !ft2 ? t2.totalProgress() : d3, h3 = i3 ? 0 : (p3 - q2) / (_e() - G) * 1e3 || 0, g3 = X.utils.clamp(-d3, 1 - d3, Ve(h3 / 2) * h3 / 0.185), u3 = d3 + (false === Ye2.inertia ? 0 : g3), { onStart: m3, onInterrupt: v2, onComplete: y2 } = Ye2;
        if (a3 = s2(u3, Et2), We(a3) || (a3 = u3), c3 = Math.round(n2 + a3 * f2), e3 <= l2 && e3 >= n2 && c3 !== e3) {
          if (o3 && !o3._initted && o3.data <= Ve(c3 - e3))
            return;
          false === Ye2.inertia && (g3 = a3 - d3), r2(c3, { duration: Q2(Ve(0.185 * Math.max(Ve(u3 - p3), Ve(a3 - p3)) / h3 / 0.05 || 0)), ease: Ye2.ease || "power3", data: Ve(c3 - e3), onInterrupt: () => ee2.restart(true) && v2 && v2(Et2), onComplete() {
            Et2.update(), Dt2 = Wt2(), t2 && (j2 ? j2.resetTo("totalProgress", a3, t2._tTime / t2._tDur) : t2.progress(a3)), H2 = q2 = t2 && !ft2 ? t2.totalProgress() : Et2.progress, Oe2 && Oe2(Et2), y2 && y2(Et2);
          } }, e3, g3 * f2, c3 - e3 - g3 * f2), m3 && m3(Et2, r2.tween);
        }
      }
    }).pause()), ce2 && (ht[ce2] = Et2), ge2 = Et2.trigger = M(ge2 || true !== ue2 && ue2), ae2 = ge2 && ge2._gsap && ge2._gsap.stRevert, ae2 && (ae2 = ae2(Et2)), ue2 = true === ue2 ? ge2 : M(ue2), Ne(le2) && (le2 = { targets: ge2, className: le2 }), ue2 && (false === ve2 || "margin" === ve2 || (ve2 = !(!ve2 && ue2.parentNode && ue2.parentNode.style && "flex" === Ke(ue2.parentNode).display) && Ge), Et2.pin = ue2, i2 = X.core.getCache(ue2), i2.spacer ? m2 = i2.pinState : (tt2 && (tt2 = M(tt2), tt2 && !tt2.nodeType && (tt2 = tt2.current || tt2.nativeElement), i2.spacerIsNative = !!tt2, tt2 && (i2.spacerState = Xt(tt2))), i2.spacer = _2 = tt2 || N.createElement("div"), _2.classList.add("pin-spacer"), ce2 && _2.classList.add("pin-spacer-" + ce2), i2.pinState = m2 = Xt(ue2)), false !== e2.force3D && X.set(ue2, { force3D: true }), Et2.spacer = _2 = i2.spacer, z2 = Ke(ue2), R2 = z2[ve2 + gt2.os2], k2 = X.getProperty(ue2), S2 = X.quickSetter(ue2, gt2.a, je), Yt(ue2, _2, z2), b2 = Xt(ue2)), kt2) {
      g2 = He(kt2) ? Ze(kt2, ot) : ot, p2 = ct("scroller-start", ce2, vt2, gt2, g2, 0), h2 = ct("scroller-end", ce2, vt2, gt2, g2, 0, p2), T2 = p2["offset" + gt2.op.d2];
      let e3 = M(w$1(vt2, "content") || vt2);
      c2 = this.markerStart = ct("start", ce2, e3, gt2, g2, T2, 0, st2), d2 = this.markerEnd = ct("end", ce2, e3, gt2, g2, T2, 0, st2), st2 && (oe2 = X.quickSetter([c2, d2], gt2.a, je)), wt2 || y$1.length && true === w$1(vt2, "fixedMarkers") || (((e4) => {
        let t3 = Ke(e4).position;
        e4.style.position = "absolute" === t3 || "fixed" === t3 ? t3 : "relative";
      })(bt2 ? W : vt2), X.set([p2, h2], { force3D: true }), Y2 = X.quickSetter(p2, gt2.a, je), I2 = X.quickSetter(h2, gt2.a, je));
    }
    if (st2) {
      let e3 = st2.vars.onUpdate, t3 = st2.vars.onUpdateParams;
      st2.eventCallback("onUpdate", () => {
        Et2.update(0, 0, 1), e3 && e3.apply(st2, t3 || []);
      });
    }
    if (Et2.previous = () => pt[pt.indexOf(Et2) - 1], Et2.next = () => pt[pt.indexOf(Et2) + 1], Et2.revert = (e3, r3) => {
      if (!r3)
        return Et2.kill(true);
      let i3 = false !== e3 || !Et2.enabled, s3 = K;
      i3 !== Et2.isReverted && (i3 && (te2 = Math.max(Wt2(), Et2.scroll.rec || 0), Nt2 = Et2.progress, se2 = t2 && t2.progress()), c2 && [c2, d2, p2, h2].forEach((e4) => e4.style.display = i3 ? "none" : "block"), i3 && (K = Et2, Et2.update(i3)), !ue2 || Le2 && Et2.isActive || (i3 ? ((e4, t3, r4) => {
        It(r4);
        let i4 = e4._gsap;
        if (i4.spacerIsNative)
          It(i4.spacerState);
        else if (e4._gsap.swappedIn) {
          let r5 = t3.parentNode;
          r5 && (r5.insertBefore(e4, t3), r5.removeChild(t3));
        }
        e4._gsap.swappedIn = false;
      })(ue2, _2, m2) : Yt(ue2, _2, Ke(ue2), D2)), i3 || Et2.update(i3), K = s3, Et2.isReverted = i3);
    }, Et2.refresh = (i3, s3, g3, v2) => {
      if ((K || !Et2.enabled) && !s3)
        return;
      if (ue2 && i3 && ke)
        return void rt(_Ut, "scrollEnd", xt);
      !ye && Mt2 && Mt2(Et2), K = Et2, r2.tween && !g3 && (r2.tween.kill(), r2.tween = 0), j2 && j2.pause(), Te2 && t2 && t2.revert({ kill: false }).invalidate(), Et2.isReverted || Et2.revert(true, true), Et2._subPinOffset = false;
      let y2, w2, T3, S3, R3, Y3, I3, z3, L2, H3, q3, U2, V2, G2 = At2(), Z2 = Rt2(), $3 = st2 ? st2.duration() : ze(vt2, gt2), J2 = f2 <= 0.01, Q3 = 0, re2 = v2 || 0, oe3 = He(g3) ? g3.end : e2.end, ae3 = e2.endTrigger || ge2, ne3 = He(g3) ? g3.start : e2.start || (0 !== e2.start && ge2 ? ue2 ? "0 0" : "0 100%" : 0), le3 = Et2.pinnedContainer = e2.pinnedContainer && M(e2.pinnedContainer, Et2), ce3 = ge2 && Math.max(0, pt.indexOf(Et2)) || 0, de3 = ce3;
      for (kt2 && He(g3) && (U2 = X.getProperty(p2, gt2.p), V2 = X.getProperty(h2, gt2.p)); de3--; )
        Y3 = pt[de3], Y3.end || Y3.refresh(0, 1) || (K = Et2), I3 = Y3.pin, !I3 || I3 !== ge2 && I3 !== ue2 && I3 !== le3 || Y3.isReverted || (H3 || (H3 = []), H3.unshift(Y3), Y3.revert(true, true)), Y3 !== pt[de3] && (ce3--, de3--);
      for (Fe(ne3) && (ne3 = ne3(Et2)), ne3 = Ce(ne3, "start", Et2), n2 = Lt(ne3, ge2, G2, gt2, Wt2(), c2, p2, Et2, Z2, Ct2, wt2, $3, st2, Et2._startClamp && "_startClamp") || (ue2 ? -1e-3 : 0), Fe(oe3) && (oe3 = oe3(Et2)), Ne(oe3) && !oe3.indexOf("+=") && (~oe3.indexOf(" ") ? oe3 = (Ne(ne3) ? ne3.split(" ")[0] : "") + oe3 : (Q3 = lt(oe3.substr(2), G2), oe3 = Ne(ne3) ? ne3 : (st2 ? X.utils.mapRange(0, st2.duration(), st2.scrollTrigger.start, st2.scrollTrigger.end, n2) : n2) + Q3, ae3 = ge2)), oe3 = Ce(oe3, "end", Et2), l2 = Math.max(n2, Lt(oe3 || (ae3 ? "100% 0" : $3), ae3, G2, gt2, Wt2() + Q3, d2, h2, Et2, Z2, Ct2, wt2, $3, st2, Et2._endClamp && "_endClamp")) || -1e-3, Q3 = 0, de3 = ce3; de3--; )
        Y3 = pt[de3], I3 = Y3.pin, I3 && Y3.start - Y3._pinPush <= n2 && !st2 && Y3.end > 0 && (y2 = Y3.end - (Et2._startClamp ? Math.max(0, Y3.start) : Y3.start), (I3 === ge2 && Y3.start - Y3._pinPush < n2 || I3 === le3) && isNaN(ne3) && (Q3 += y2 * (1 - Y3.progress)), I3 === ue2 && (re2 += y2));
      if (n2 += Q3, l2 += Q3, Et2._startClamp && (Et2._startClamp += Q3), Et2._endClamp && !ye && (Et2._endClamp = l2 || -1e-3, l2 = Math.min(l2, ze(vt2, gt2))), f2 = l2 - n2 || (n2 -= 0.01) && 1e-3, J2 && (Nt2 = X.utils.clamp(0, 1, X.utils.normalize(n2, l2, te2))), Et2._pinPush = re2, c2 && Q3 && (y2 = {}, y2[gt2.a] = "+=" + Q3, le3 && (y2[gt2.p] = "-=" + Wt2()), X.set([c2, d2], y2)), !ue2 || fe && Et2.end >= ze(vt2, gt2)) {
        if (ge2 && Wt2() && !st2)
          for (w2 = ge2.parentNode; w2 && w2 !== W; )
            w2._pinOffset && (n2 -= w2._pinOffset, l2 -= w2._pinOffset), w2 = w2.parentNode;
      } else
        y2 = Ke(ue2), S3 = gt2 === P, T3 = Wt2(), C2 = parseFloat(k2(gt2.a)) + re2, !$3 && l2 > 1 && (q3 = (bt2 ? N.scrollingElement || F$1 : vt2).style, q3 = { style: q3, value: q3["overflow" + gt2.a.toUpperCase()] }, bt2 && "scroll" !== Ke(W)["overflow" + gt2.a.toUpperCase()] && (q3.style["overflow" + gt2.a.toUpperCase()] = "scroll")), Yt(ue2, _2, y2), b2 = Xt(ue2), w2 = $e(ue2, true), z3 = wt2 && O(vt2, S3 ? E$1 : P)(), ve2 ? (D2 = [ve2 + gt2.os2, f2 + re2 + je], D2.t = _2, de3 = ve2 === Ge ? Je(ue2, gt2) + f2 + re2 : 0, de3 && (D2.push(gt2.d, de3 + je), "auto" !== _2.style.flexBasis && (_2.style.flexBasis = de3 + je)), It(D2), le3 && pt.forEach((e3) => {
          e3.pin === le3 && false !== e3.vars.pinSpacing && (e3._subPinOffset = true);
        }), wt2 && Wt2(te2)) : (de3 = Je(ue2, gt2), de3 && "auto" !== _2.style.flexBasis && (_2.style.flexBasis = de3 + je)), wt2 && (R3 = { top: w2.top + (S3 ? T3 - n2 : z3) + je, left: w2.left + (S3 ? z3 : T3 - n2) + je, boxSizing: "border-box", position: "fixed" }, R3.width = R3.maxWidth = Math.ceil(w2.width) + je, R3.height = R3.maxHeight = Math.ceil(w2.height) + je, R3.margin = R3.marginTop = R3.marginRight = R3.marginBottom = R3.marginLeft = "0", R3.padding = y2.padding, R3.paddingTop = y2.paddingTop, R3.paddingRight = y2.paddingRight, R3.paddingBottom = y2.paddingBottom, R3.paddingLeft = y2.paddingLeft, x2 = ((e3, t3, r3) => {
          let i4, s4 = [], o3 = e3.length, a3 = r3 ? 8 : 0;
          for (; a3 < o3; a3 += 2)
            i4 = e3[a3], s4.push(i4, i4 in t3 ? t3[i4] : e3[a3 + 1]);
          return s4.t = e3.t, s4;
        })(m2, R3, Le2), ye && Wt2(0)), t2 ? (L2 = t2._initted, ie(1), t2.render(t2.duration(), true, true), A2 = k2(gt2.a) - C2 + f2 + re2, B2 = Math.abs(f2 - A2) > 1, wt2 && B2 && x2.splice(x2.length - 2, 2), t2.render(0, true, true), L2 || t2.invalidate(true), t2.parent || t2.totalTime(t2.totalTime()), ie(0)) : A2 = f2, q3 && (q3.value ? q3.style["overflow" + gt2.a.toUpperCase()] = q3.value : q3.style.removeProperty("overflow-" + gt2.a));
      H3 && H3.forEach((e3) => e3.revert(false, true)), Et2.start = n2, Et2.end = l2, o2 = a2 = ye ? te2 : Wt2(), st2 || ye || (o2 < te2 && Wt2(te2), Et2.scroll.rec = 0), Et2.revert(false, true), Bt2 = _e(), ee2 && (Dt2 = -1, ee2.restart(true)), K = 0, t2 && ft2 && (t2._initted || se2) && t2.progress() !== se2 && t2.progress(se2 || 0, true).render(t2.time(), true, true), (J2 || Nt2 !== Et2.progress || st2 || Te2) && (t2 && !ft2 && t2.totalProgress(st2 && n2 < -1e-3 && !Nt2 ? X.utils.normalize(n2, l2, 0) : Nt2, true), Et2.progress = J2 || (o2 - n2) / f2 === Nt2 ? 0 : Nt2), ue2 && ve2 && (_2._pinOffset = Math.round(Et2.progress * A2)), j2 && j2.invalidate(), isNaN(U2) || (U2 -= X.getProperty(p2, gt2.p), V2 -= X.getProperty(h2, gt2.p), Ht(p2, gt2, U2), Ht(c2, gt2, U2 - (v2 || 0)), Ht(h2, gt2, V2), Ht(d2, gt2, V2 - (v2 || 0))), J2 && !ye && Et2.update(), !pe2 || ye || u2 || (u2 = true, pe2(Et2), u2 = false);
    }, Et2.getVelocity = () => (Wt2() - a2) / (_e() - G) * 1e3 || 0, Et2.endAnimation = () => {
      qe(Et2.callbackAnimation), t2 && (j2 ? j2.progress(1) : t2.paused() ? ft2 || qe(t2, Et2.direction < 0, 1) : qe(t2, t2.reversed()));
    }, Et2.labelToScroll = (e3) => t2 && t2.labels && (n2 || Et2.refresh() || n2) + t2.labels[e3] / t2.duration() * f2 || 0, Et2.getTrailing = (e3) => {
      let t3 = pt.indexOf(Et2), r3 = Et2.direction > 0 ? pt.slice(0, t3).reverse() : pt.slice(t3 + 1);
      return (Ne(e3) ? r3.filter((t4) => t4.vars.preventOverlaps === e3) : r3).filter((e4) => Et2.direction > 0 ? e4.end <= n2 : e4.start >= l2);
    }, Et2.update = (e3, i3, s3) => {
      if (st2 && !s3 && !e3)
        return;
      let c3, d3, h3, g3, u3, m3, v2, y2, w2 = true === ye ? te2 : Et2.scroll(), T3 = e3 ? 0 : (w2 - n2) / f2, k3 = T3 < 0 ? 0 : T3 > 1 ? 1 : T3 || 0, E2 = Et2.progress;
      if (i3 && (a2 = o2, o2 = st2 ? Wt2() : w2, Ye2 && (q2 = H2, H2 = t2 && !ft2 ? t2.totalProgress() : k3)), Pe2 && ue2 && !K && !we && ke && (!k3 && n2 < w2 + (w2 - a2) / (_e() - G) * Pe2 ? k3 = 1e-4 : 1 === k3 && l2 > w2 + (w2 - a2) / (_e() - G) * Pe2 && (k3 = 0.9999)), k3 !== E2 && Et2.enabled) {
        if (c3 = Et2.isActive = !!k3 && k3 < 1, d3 = !!E2 && E2 < 1, m3 = c3 !== d3, u3 = m3 || !!k3 != !!E2, Et2.direction = k3 > E2 ? 1 : -1, Et2.progress = k3, u3 && !K && (h3 = k3 && !E2 ? 0 : 1 === k3 ? 1 : 1 === E2 ? 2 : 3, ft2 && (g3 = !m3 && "none" !== Tt2[h3 + 1] && Tt2[h3 + 1] || Tt2[h3], y2 = t2 && ("complete" === g3 || "reset" === g3 || g3 in t2))), dt2 && (m3 || y2) && (y2 || he2 || !t2) && (Fe(dt2) ? dt2(Et2) : Et2.getTrailing(dt2).forEach((e4) => e4.endAnimation())), ft2 || (!j2 || K || we ? t2 && t2.totalProgress(k3, !(!K || !Bt2 && !e3)) : (j2._dp._time - j2._start !== j2._time && j2.render(j2._dp._time - j2._start), j2.resetTo ? j2.resetTo("totalProgress", k3, t2._tTime / t2._tDur) : (j2.vars.totalProgress = k3, j2.invalidate().restart()))), ue2)
          if (e3 && ve2 && (_2.style[ve2 + gt2.os2] = R2), wt2) {
            if (u3) {
              if (v2 = !e3 && k3 > E2 && l2 + 1 > w2 && w2 + 1 >= ze(vt2, gt2), Le2)
                if (e3 || !c3 && !v2)
                  Ft(ue2, _2);
                else {
                  let e4 = $e(ue2, true), t3 = w2 - n2;
                  Ft(ue2, W, e4.top + (gt2 === P ? t3 : 0) + je, e4.left + (gt2 === P ? 0 : t3) + je);
                }
              It(c3 || v2 ? x2 : b2), B2 && k3 < 1 && c3 || S2(C2 + (1 !== k3 || v2 ? 0 : A2));
            }
          } else
            S2(Re(C2 + A2 * k3));
        Ye2 && !r2.tween && !K && !we && ee2.restart(true), le2 && (m3 || De2 && k3 && (k3 < 1 || !me)) && U(le2.targets).forEach((e4) => e4.classList[c3 || De2 ? "add" : "remove"](le2.className)), ne2 && !ft2 && !e3 && ne2(Et2), u3 && !K ? (ft2 && (y2 && ("complete" === g3 ? t2.pause().totalProgress(1) : "reset" === g3 ? t2.restart(true).pause() : "restart" === g3 ? t2.restart(true) : t2[g3]()), ne2 && ne2(Et2)), !m3 && me || (de2 && m3 && Ue(Et2, de2), _t2[h3] && Ue(Et2, _t2[h3]), De2 && (1 === k3 ? Et2.kill(false, 1) : _t2[h3] = 0), m3 || (h3 = 1 === k3 ? 1 : 3, _t2[h3] && Ue(Et2, _t2[h3]))), nt2 && !c3 && Math.abs(Et2.getVelocity()) > (We(nt2) ? nt2 : 2500) && (qe(Et2.callbackAnimation), j2 ? j2.progress(1) : qe(t2, "reverse" === g3 ? 1 : !k3, 1))) : ft2 && ne2 && !K && ne2(Et2);
      }
      if (I2) {
        let e4 = st2 ? w2 / st2.duration() * (st2._caScrollDist || 0) : w2;
        Y2(e4 + (p2._isFlipped ? 1 : 0)), I2(e4);
      }
      oe2 && oe2(-w2 / st2.duration() * (st2._caScrollDist || 0));
    }, Et2.enable = (e3, t3) => {
      Et2.enabled || (Et2.enabled = true, rt(vt2, "resize", mt), bt2 || rt(vt2, "scroll", ut), Mt2 && rt(_Ut, "refreshInit", Mt2), false !== e3 && (Et2.progress = Nt2 = 0, o2 = a2 = Dt2 = Wt2()), false !== t3 && Et2.refresh());
    }, Et2.getTween = (e3) => e3 && r2 ? r2.tween : j2, Et2.setPositions = (e3, t3, r3, i3) => {
      if (st2) {
        let r4 = st2.scrollTrigger, i4 = st2.duration(), s3 = r4.end - r4.start;
        e3 = r4.start + s3 * e3 / i4, t3 = r4.start + s3 * t3 / i4;
      }
      Et2.refresh(false, false, { start: Ee(e3, r3 && !!Et2._startClamp), end: Ee(t3, r3 && !!Et2._endClamp) }, i3), Et2.update();
    }, Et2.adjustPinSpacing = (e3) => {
      if (D2 && e3) {
        let t3 = D2.indexOf(gt2.d) + 1;
        D2[t3] = parseFloat(D2[t3]) + e3 + je, D2[1] = parseFloat(D2[1]) + e3 + je, It(D2);
      }
    }, Et2.disable = (e3, t3) => {
      if (Et2.enabled && (false !== e3 && Et2.revert(true, true), Et2.enabled = Et2.isActive = false, t3 || j2 && j2.pause(), te2 = 0, i2 && (i2.uncache = 1), Mt2 && it(_Ut, "refreshInit", Mt2), ee2 && (ee2.pause(), r2.tween && r2.tween.kill() && (r2.tween = 0)), !bt2)) {
        let e4 = pt.length;
        for (; e4--; )
          if (pt[e4].scroller === vt2 && pt[e4] !== Et2)
            return;
        it(vt2, "resize", mt), bt2 || it(vt2, "scroll", ut);
      }
    }, Et2.kill = (r3, s3) => {
      Et2.disable(r3, s3), j2 && !s3 && j2.kill(), ce2 && delete ht[ce2];
      let o3 = pt.indexOf(Et2);
      o3 >= 0 && pt.splice(o3, 1), o3 === J && Ot > 0 && J--, o3 = 0, pt.forEach((e3) => e3.scroller === Et2.scroller && (o3 = 1)), o3 || ye || (Et2.scroll.rec = 0), t2 && (t2.scrollTrigger = null, r3 && t2.revert({ kill: false }), s3 || t2.kill()), c2 && [c2, d2, p2, h2].forEach((e3) => e3.parentNode && e3.parentNode.removeChild(e3)), be === Et2 && (be = 0), ue2 && (i2 && (i2.uncache = 1), o3 = 0, pt.forEach((e3) => e3.pin === ue2 && o3++), o3 || (i2.spacer = 0)), e2.onKill && e2.onKill(Et2);
    }, pt.push(Et2), Et2.enable(false, false), ae2 && ae2(Et2), t2 && t2.add && !f2) {
      let e3 = Et2.update;
      Et2.update = () => {
        Et2.update = e3, n2 || l2 || Et2.refresh();
      }, X.delayedCall(0.01, Et2.update), f2 = 0.01, n2 = l2 = 0;
    } else
      Et2.refresh();
    ue2 && (() => {
      if (xe !== St) {
        let e3 = xe = St;
        requestAnimationFrame(() => e3 === St && Pt(true));
      }
    })();
  }
  static register(e2) {
    return z || (X = e2 || Ye(), z = Se), z;
  }
  static defaults(e2) {
    if (e2)
      for (let t2 in e2)
        at[t2] = e2[t2];
    return at;
  }
  static disable(e2, t2) {
    Se = 0, pt.forEach((r2) => r2[t2 ? "kill" : "disable"](e2)), it(L, "wheel", ut), it(N, "scroll", ut), clearInterval(j), it(N, "touchcancel", Ae), it(W, "touchstart", Ae), tt(it, N, "pointerdown,touchstart,mousedown", Me), tt(it, N, "pointerup,touchend,mouseup", Oe), q.kill(), Le(it);
    for (let e3 = 0; e3 < v.length; e3 += 3)
      st(it, v[e3], v[e3 + 1]), st(it, v[e3], v[e3 + 2]);
  }
  static enable() {
    if (L = void 0, N = void 0, F$1 = N.documentElement, W = N.body, X && (U = X.utils.toArray, V = X.utils.clamp, de = X.core.context || Ae, ie = X.core.suppressOverwrites || Ae, pe = L.history.scrollRestoration || "auto", Mt = L.pageYOffset, X.core.globals("ScrollTrigger", _Ut), W)) {
      Se = 1, he = (void 0).createElement("div"), he.style.height = "100vh", he.style.position = "absolute", Ct(), Pe(), I.register(X), _Ut.isTouch = I.isTouch, ce = I.isTouch && /(iPad|iPhone|iPod|Mac)/g.test((void 0).userAgent), ae = 1 === I.isTouch, rt(L, "wheel", ut), H = [L, N, F$1, W], X.matchMedia ? (_Ut.matchMedia = (e3) => {
        let t3, r3 = X.matchMedia();
        for (t3 in e3)
          r3.add(t3, e3[t3]);
        return r3;
      }, X.addEventListener("matchMediaInit", () => Tt()), X.addEventListener("matchMediaRevert", () => _t()), X.addEventListener("matchMedia", () => {
        Pt(0, 1), bt("matchMedia");
      }), X.matchMedia("(orientation: portrait)", () => (ft(), ft))) : console.warn("Requires GSAP 3.11.0 or later"), ft(), rt(N, "scroll", ut);
      let e2, t2, r2 = W.style, i2 = r2.borderTopStyle, s2 = X.core.Animation.prototype;
      for (s2.revert || Object.defineProperty(s2, "revert", { value: function() {
        return this.time(-0.01, true);
      } }), r2.borderTopStyle = "solid", e2 = $e(W), P.m = Math.round(e2.top + P.sc()) || 0, E$1.m = Math.round(e2.left + E$1.sc()) || 0, i2 ? r2.borderTopStyle = i2 : r2.removeProperty("border-top-style"), j = setInterval(), X.delayedCall(0.5, () => we = 0), rt(N, "touchcancel", Ae), rt(W, "touchstart", Ae), tt(rt, N, "pointerdown,touchstart,mousedown", Me), tt(rt, N, "pointerup,touchend,mouseup", Oe), $ = X.utils.checkPrefix("transform"), Dt.push($), z = _e(), q = X.delayedCall(0.2, Pt).pause(), te = [N, "visibilitychange", () => {
        let e3 = L.innerWidth, t3 = L.innerHeight;
        N.hidden ? (Q = e3, ee = t3) : Q === e3 && ee === t3 || mt();
      }, N, "DOMContentLoaded", Pt, L, "load", Pt, L, "resize", mt], Le(rt), pt.forEach((e3) => e3.enable(0, 1)), t2 = 0; t2 < v.length; t2 += 3)
        st(it, v[t2], v[t2 + 1]), st(it, v[t2], v[t2 + 2]);
    }
  }
  static config(e2) {
    "limitCallbacks" in e2 && (me = !!e2.limitCallbacks);
    let t2 = e2.syncInterval;
    t2 && clearInterval(j) || (j = t2) && setInterval(), "ignoreMobileResize" in e2 && (ae = 1 === _Ut.isTouch && e2.ignoreMobileResize), "autoRefreshEvents" in e2 && (Le(it) || Le(rt, e2.autoRefreshEvents || "none"), se = -1 === (e2.autoRefreshEvents + "").indexOf("resize"));
  }
  static scrollerProxy(e2, t2) {
    let r2 = M(e2), i2 = v.indexOf(r2), s2 = Be(r2);
    ~i2 && v.splice(i2, s2 ? 6 : 2), t2 && (s2 ? y$1.unshift(L, t2, W, t2, F$1, t2) : y$1.unshift(r2, t2));
  }
  static clearMatchMedia(e2) {
    pt.forEach((t2) => t2._ctx && t2._ctx.query === e2 && t2._ctx.kill(true, true));
  }
  static isInViewport(e2, t2, r2) {
    let i2 = (Ne(e2) ? M(e2) : e2).getBoundingClientRect(), s2 = i2[r2 ? "width" : "height"] * t2 || 0;
    return r2 ? i2.right - s2 > 0 && i2.left + s2 < L.innerWidth : i2.bottom - s2 > 0 && i2.top + s2 < L.innerHeight;
  }
  static positionInViewport(e2, t2, r2) {
    Ne(e2) && (e2 = M(e2));
    let i2 = e2.getBoundingClientRect(), s2 = i2[r2 ? "width" : "height"], o2 = null == t2 ? s2 / 2 : t2 in nt ? nt[t2] * s2 : ~t2.indexOf("%") ? parseFloat(t2) * s2 / 100 : parseFloat(t2) || 0;
    return r2 ? (i2.left + o2) / L.innerWidth : (i2.top + o2) / L.innerHeight;
  }
  static killAll(e2) {
    if (pt.slice(0).forEach((e3) => "ScrollSmoother" !== e3.vars.id && e3.kill()), true !== e2) {
      let e3 = vt.killAll || [];
      vt = {}, e3.forEach((e4) => e4());
    }
  }
};
Ut.version = "3.12.5", Ut.saveStyles = (e2) => e2 ? U(e2).forEach((e3) => {
  if (e3 && e3.style) {
    let t2 = wt.indexOf(e3);
    t2 >= 0 && wt.splice(t2, 5), wt.push(e3, e3.style.cssText, e3.getBBox && e3.getAttribute("transform"), X.core.getCache(e3), de());
  }
}) : wt, Ut.revert = (e2, t2) => Tt(!e2, t2), Ut.create = (e2, t2) => new Ut(e2, t2), Ut.refresh = (e2) => e2 ? mt() : (z || Ut.register()) && Pt(true), Ut.update = (e2) => ++v.cache && At(true === e2 ? 2 : 0), Ut.clearScrollMemory = kt, Ut.maxScroll = (e2, t2) => ze(e2, t2 ? E$1 : P), Ut.getScrollFunc = (e2, t2) => O(M(e2), t2 ? E$1 : P), Ut.getById = (e2) => ht[e2], Ut.getAll = () => pt.filter((e2) => "ScrollSmoother" !== e2.vars.id), Ut.isScrolling = () => !!ke, Ut.snapDirectional = et, Ut.addEventListener = (e2, t2) => {
  let r2 = vt[e2] || (vt[e2] = []);
  ~r2.indexOf(t2) || r2.push(t2);
}, Ut.removeEventListener = (e2, t2) => {
  let r2 = vt[e2], i2 = r2 && r2.indexOf(t2);
  i2 >= 0 && r2.splice(i2, 1);
}, Ut.batch = (e2, t2) => {
  let r2, i2 = [], s2 = {}, o2 = t2.interval || 0.016, a2 = t2.batchMax || 1e9, n2 = (e3, t3) => {
    let r3 = [], i3 = [], s3 = X.delayedCall(o2, () => {
      t3(r3, i3), r3 = [], i3 = [];
    }).pause();
    return (e4) => {
      r3.length || s3.restart(true), r3.push(e4.trigger), i3.push(e4), a2 <= r3.length && s3.progress(1);
    };
  };
  for (r2 in t2)
    s2[r2] = "on" === r2.substr(0, 2) && Fe(t2[r2]) && "onRefreshInit" !== r2 ? n2(0, t2[r2]) : t2[r2];
  return Fe(a2) && (a2 = a2(), rt(Ut, "refresh", () => a2 = t2.batchMax())), U(e2).forEach((e3) => {
    let t3 = {};
    for (r2 in s2)
      t3[r2] = s2[r2];
    t3.trigger = e3, i2.push(Ut.create(t3));
  }), i2;
};
var Vt;
var Gt = (e2, t2, r2, i2) => (t2 > i2 ? e2(i2) : t2 < 0 && e2(0), r2 > i2 ? (i2 - t2) / (r2 - t2) : r2 < 0 ? t2 / (t2 - r2) : 1);
var jt = (e2, t2) => {
  true === t2 ? e2.style.removeProperty("touch-action") : e2.style.touchAction = true === t2 ? "auto" : t2 ? "pan-" + t2 + (I.isTouch ? " pinch-zoom" : "") : "none", e2 === F$1 && jt(W, t2);
};
var Kt = { auto: 1, scroll: 1 };
var Zt = ({ event: e2, target: t2, axis: r2 }) => {
  let i2, s2 = (e2.changedTouches ? e2.changedTouches[0] : e2).target, o2 = s2._gsap || X.core.getCache(s2), a2 = _e();
  if (!o2._isScrollT || a2 - o2._isScrollT > 2e3) {
    for (; s2 && s2 !== W && (s2.scrollHeight <= s2.clientHeight && s2.scrollWidth <= s2.clientWidth || !Kt[(i2 = Ke(s2)).overflowY] && !Kt[i2.overflowX]); )
      s2 = s2.parentNode;
    o2._isScroll = s2 && s2 !== t2 && !Be(s2) && (Kt[(i2 = Ke(s2)).overflowY] || Kt[i2.overflowX]), o2._isScrollT = a2;
  }
  (o2._isScroll || "x" === r2) && (e2.stopPropagation(), e2._gsapAllow = true);
};
var $t = (e2, t2, r2, i2) => I.create({ target: e2, capture: true, debounce: false, lockAxis: true, type: t2, onWheel: i2 = i2 && Zt, onPress: i2, onDrag: i2, onScroll: i2, onEnable: () => r2 && rt(N, I.eventTypes[0], Qt, false, true), onDisable: () => it(N, I.eventTypes[0], Qt, true) });
var Jt = /(input|label|select|textarea)/i;
var Qt = (e2) => {
  let t2 = Jt.test(e2.target.tagName);
  (t2 || Vt) && (e2._gsapAllow = true, Vt = t2);
};
var er = (e2) => {
  He(e2) || (e2 = {}), e2.preventDefault = e2.isNormalizer = e2.allowClicks = true, e2.type || (e2.type = "wheel,touch"), e2.debounce = !!e2.debounce, e2.id = e2.id || "normalizer";
  let t2, r2, i2, s2, o2, a2, n2, l2, { normalizeScrollX: c2, momentum: d2, allowNestedScroll: p2, onRelease: h2 } = e2, g2 = M(e2.target) || F$1, u2 = X.core.globals().ScrollSmoother, f2 = u2 && u2.get(), m2 = ce && (e2.content && M(e2.content) || f2 && false !== e2.content && !f2.smooth() && f2.content()), y2 = O(g2, P), x2 = O(g2, E$1), b2 = 1, w2 = (I.isTouch && L.visualViewport ? L.visualViewport.scale * L.visualViewport.width : L.outerWidth) / L.innerWidth, _2 = 0, T2 = Fe(d2) ? () => d2(t2) : () => d2 || 2.8, k2 = $t(g2, e2.type, true, p2), S2 = () => s2 = false, C2 = Ae, A2 = Ae, R2 = () => {
    r2 = ze(g2, P), A2 = V(ce ? 1 : 0, r2), c2 && (C2 = V(0, ze(g2, E$1))), i2 = St;
  }, D2 = () => {
    m2._gsap.y = Re(parseFloat(m2._gsap.y) + y2.offset) + "px", m2.style.transform = "matrix3d(1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, " + parseFloat(m2._gsap.y) + ", 0, 1)", y2.offset = y2.cacheID = 0;
  }, Y2 = () => {
    R2(), o2.isActive() && o2.vars.scrollY > r2 && (y2() > r2 ? o2.progress(1) && y2(r2) : o2.resetTo("scrollY", r2));
  };
  return m2 && X.set(m2, { y: "+=0" }), e2.ignoreCheck = (e3) => ce && "touchmove" === e3.type && (() => {
    if (s2) {
      requestAnimationFrame(S2);
      let e4 = Re(t2.deltaY / 2), r3 = A2(y2.v - e4);
      if (m2 && r3 !== y2.v + y2.offset) {
        y2.offset = r3 - y2.v;
        let e5 = Re((parseFloat(m2 && m2._gsap.y) || 0) - y2.offset);
        m2.style.transform = "matrix3d(1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, " + e5 + ", 0, 1)", m2._gsap.y = e5 + "px", y2.cacheID = v.cache, At();
      }
      return true;
    }
    y2.offset && D2(), s2 = true;
  })() || b2 > 1.05 && "touchstart" !== e3.type || t2.isGesturing || e3.touches && e3.touches.length > 1, e2.onPress = () => {
    s2 = false;
    let e3 = b2;
    b2 = Re((L.visualViewport && L.visualViewport.scale || 1) / w2), o2.pause(), e3 !== b2 && jt(g2, b2 > 1.01 || !c2 && "x"), a2 = x2(), n2 = y2(), R2(), i2 = St;
  }, e2.onRelease = e2.onGestureStart = (e3, t3) => {
    if (y2.offset && D2(), t3) {
      v.cache++;
      let t4, i3, s3 = T2();
      c2 && (t4 = x2(), i3 = t4 + 0.05 * s3 * -e3.velocityX / 0.227, s3 *= Gt(x2, t4, i3, ze(g2, E$1)), o2.vars.scrollX = C2(i3)), t4 = y2(), i3 = t4 + 0.05 * s3 * -e3.velocityY / 0.227, s3 *= Gt(y2, t4, i3, ze(g2, P)), o2.vars.scrollY = A2(i3), o2.invalidate().duration(s3).play(0.01), (ce && o2.vars.scrollY >= r2 || t4 >= r2 - 1) && X.to({}, { onUpdate: Y2, duration: s3 });
    } else
      l2.restart(true);
    h2 && h2(e3);
  }, e2.onWheel = () => {
    o2._ts && o2.pause(), _e() - _2 > 1e3 && (i2 = 0, _2 = _e());
  }, e2.onChange = (e3, t3, r3, s3, o3) => {
    if (St !== i2 && R2(), t3 && c2 && x2(C2(s3[2] === t3 ? a2 + (e3.startX - e3.x) : x2() + t3 - s3[1])), r3) {
      y2.offset && D2();
      let t4 = o3[2] === r3, i3 = t4 ? n2 + e3.startY - e3.y : y2() + r3 - o3[1], s4 = A2(i3);
      t4 && i3 !== s4 && (n2 += s4 - i3), y2(s4);
    }
    (r3 || t3) && At();
  }, e2.onEnable = () => {
    jt(g2, !c2 && "x"), Ut.addEventListener("refresh", Y2), rt(L, "resize", Y2), y2.smooth && (y2.target.style.scrollBehavior = "auto", y2.smooth = x2.smooth = false), k2.enable();
  }, e2.onDisable = () => {
    jt(g2, true), it(L, "resize", Y2), Ut.removeEventListener("refresh", Y2), k2.kill();
  }, e2.lockAxis = false !== e2.lockAxis, t2 = new I(e2), t2.iOS = ce, ce && !y2() && y2(1), ce && X.ticker.add(Ae), l2 = t2._dc, o2 = X.to(t2, { ease: "power4", paused: true, inherit: false, scrollX: c2 ? "+=0.1" : "+=0", scrollY: "+=0.1", modifiers: { scrollY: Wt(y2, y2(), () => o2.pause()) }, onUpdate: At, onComplete: l2.vars.onComplete }), t2;
};
Ut.sort = (e2) => pt.sort(e2 || ((e3, t2) => -1e6 * (e3.vars.refreshPriority || 0) + e3.start - (t2.start + -1e6 * (t2.vars.refreshPriority || 0)))), Ut.observe = (e2) => new I(e2), Ut.normalizeScroll = (e2) => {
  if (void 0 === e2)
    return oe;
  if (true === e2 && oe)
    return oe.enable();
  if (false === e2)
    return oe && oe.kill(), void (oe = e2);
  let t2 = e2 instanceof I ? e2 : er(e2);
  return oe && oe.target === t2.target && oe.kill(), Be(t2.target) && (oe = t2), t2;
}, Ut.core = { _getVelocityProp: A$1, _inputObserver: $t, _scrollers: v, _proxies: y$1, bridge: { ss: () => {
  ke || bt("scrollStart"), ke = _e();
}, ref: () => K } }, Ye() && X.registerPlugin(Ut);
var ScrollTrigger_default = Ut;
/*! Bundled license information:

gsap/SplitText.js:
  (*!
   * SplitText 3.12.5
   * https://gsap.com
   * 
   * @license Copyright 2024, GreenSock. All rights reserved.
   *)
*/
const gsap_scroll_trigger_Oh1k47CFRg = /* @__PURE__ */ defineNuxtPlugin(() => {
  return {
    provide: {
      ScrollTrigger: ScrollTrigger_default
    }
  };
});
var u;
var e;
var t;
var F;
var C;
var i;
var n = /(?:\r|\n|\t\t)/g;
var s = /(?:\s\s+)/g;
var E = String.fromCharCode(160);
var l = (D2) => {
  u = void 0, e = void 0, F = F || D2 || e.gsap || console.warn("Please gsap.registerPlugin(SplitText)"), F && (i = F.utils.toArray, C = F.core.context || function() {
  }, t = 1);
};
var h = (D2) => e.getComputedStyle(D2);
var B = (D2) => "absolute" === D2.position || true === D2.absolute;
var A = (D2, u2) => {
  let e2, t2 = u2.length;
  for (; --t2 > -1; )
    if (e2 = u2[t2], D2.substr(0, e2.length) === e2)
      return e2.length;
};
var f = (D2 = "", u2) => {
  let e2 = ~D2.indexOf("++"), t2 = 1;
  return e2 && (D2 = D2.split("++").join("")), () => "<" + u2 + " style='position:relative;display:inline-block;'" + (D2 ? " class='" + D2 + (e2 ? t2++ : "") + "'>" : ">");
};
var c = (D2, u2, e2) => {
  let t2 = D2.nodeType;
  if (1 === t2 || 9 === t2 || 11 === t2)
    for (D2 = D2.firstChild; D2; D2 = D2.nextSibling)
      c(D2, u2, e2);
  else
    3 !== t2 && 4 !== t2 || (D2.nodeValue = D2.nodeValue.split(u2).join(e2));
};
var g = (D2, u2) => {
  let e2 = u2.length;
  for (; --e2 > -1; )
    D2.push(u2[e2]);
};
var x = (D2, u2, e2) => {
  let t2;
  for (; D2 && D2 !== u2; ) {
    if (t2 = D2._next || D2.nextSibling, t2)
      return t2.textContent.charAt(0) === e2;
    D2 = D2.parentNode || D2._parent;
  }
};
var y = (D2) => {
  let u2, e2, t2 = i(D2.childNodes), F2 = t2.length;
  for (u2 = 0; u2 < F2; u2++)
    e2 = t2[u2], e2._isSplit ? y(e2) : u2 && e2.previousSibling && 3 === e2.previousSibling.nodeType ? (e2.previousSibling.nodeValue += 3 === e2.nodeType ? e2.nodeValue : e2.firstChild.nodeValue, D2.removeChild(e2)) : 3 !== e2.nodeType && (D2.insertBefore(e2.firstChild, e2), D2.removeChild(e2));
};
var b = (D2, u2) => parseFloat(u2[D2]) || 0;
var _ = (D2, e2, t2, F2, C2, i2, n2) => {
  let s2, E2, l2, o2, r2, d2, a2, p2, A2, f2, _2, w2, S2 = h(D2), m2 = b("paddingLeft", S2), v2 = -999, T2 = b("borderBottomWidth", S2) + b("borderTopWidth", S2), N2 = b("borderLeftWidth", S2) + b("borderRightWidth", S2), L2 = b("paddingTop", S2) + b("paddingBottom", S2), W2 = b("paddingLeft", S2) + b("paddingRight", S2), O2 = b("fontSize", S2) * (e2.lineThreshold || 0.2), H2 = S2.textAlign, V2 = [], R2 = [], j2 = [], M2 = e2.wordDelimiter || " ", k2 = e2.tag ? e2.tag : e2.span ? "span" : "div", P2 = e2.type || e2.split || "chars,words,lines", z2 = C2 && ~P2.indexOf("lines") ? [] : null, $2 = ~P2.indexOf("words"), q2 = ~P2.indexOf("chars"), G2 = B(e2), I2 = e2.linesClass, J2 = ~(I2 || "").indexOf("++"), K2 = [], Q2 = "flex" === S2.display, U2 = D2.style.display;
  for (J2 && (I2 = I2.split("++").join("")), Q2 && (D2.style.display = "block"), E2 = D2.getElementsByTagName("*"), l2 = E2.length, r2 = [], s2 = 0; s2 < l2; s2++)
    r2[s2] = E2[s2];
  if (z2 || G2)
    for (s2 = 0; s2 < l2; s2++)
      o2 = r2[s2], d2 = o2.parentNode === D2, (d2 || G2 || q2 && !$2) && (w2 = o2.offsetTop, z2 && d2 && Math.abs(w2 - v2) > O2 && ("BR" !== o2.nodeName || 0 === s2) && (a2 = [], z2.push(a2), v2 = w2), G2 && (o2._x = o2.offsetLeft, o2._y = w2, o2._w = o2.offsetWidth, o2._h = o2.offsetHeight), z2 && ((o2._isSplit && d2 || !q2 && d2 || $2 && d2 || !$2 && o2.parentNode.parentNode === D2 && !o2.parentNode._isSplit) && (a2.push(o2), o2._x -= m2, x(o2, D2, M2) && (o2._wordEnd = true)), "BR" === o2.nodeName && (o2.nextSibling && "BR" === o2.nextSibling.nodeName || 0 === s2) && z2.push([])));
  for (s2 = 0; s2 < l2; s2++)
    if (o2 = r2[s2], d2 = o2.parentNode === D2, "BR" !== o2.nodeName)
      if (G2 && (A2 = o2.style, $2 || d2 || (o2._x += o2.parentNode._x, o2._y += o2.parentNode._y), A2.left = o2._x + "px", A2.top = o2._y + "px", A2.position = "absolute", A2.display = "block", A2.width = o2._w + 1 + "px", A2.height = o2._h + "px"), !$2 && q2)
        if (o2._isSplit)
          for (o2._next = E2 = o2.nextSibling, o2.parentNode.appendChild(o2); E2 && 3 === E2.nodeType && " " === E2.textContent; )
            o2._next = E2.nextSibling, o2.parentNode.appendChild(E2), E2 = E2.nextSibling;
        else
          o2.parentNode._isSplit ? (o2._parent = o2.parentNode, !o2.previousSibling && o2.firstChild && (o2.firstChild._isFirst = true), o2.nextSibling && " " === o2.nextSibling.textContent && !o2.nextSibling.nextSibling && K2.push(o2.nextSibling), o2._next = o2.nextSibling && o2.nextSibling._isFirst ? null : o2.nextSibling, o2.parentNode.removeChild(o2), r2.splice(s2--, 1), l2--) : d2 || (w2 = !o2.nextSibling && x(o2.parentNode, D2, M2), o2.parentNode._parent && o2.parentNode._parent.appendChild(o2), w2 && o2.parentNode.appendChild(u.createTextNode(" ")), "span" === k2 && (o2.style.display = "inline"), V2.push(o2));
      else
        o2.parentNode._isSplit && !o2._isSplit && "" !== o2.innerHTML ? R2.push(o2) : q2 && !o2._isSplit && ("span" === k2 && (o2.style.display = "inline"), V2.push(o2));
    else
      z2 || G2 ? (o2.parentNode && o2.parentNode.removeChild(o2), r2.splice(s2--, 1), l2--) : $2 || D2.appendChild(o2);
  for (s2 = K2.length; --s2 > -1; )
    K2[s2].parentNode.removeChild(K2[s2]);
  if (z2) {
    for (G2 && (f2 = u.createElement(k2), D2.appendChild(f2), _2 = f2.offsetWidth + "px", w2 = f2.offsetParent === D2 ? 0 : D2.offsetLeft, D2.removeChild(f2)), A2 = D2.style.cssText, D2.style.cssText = "display:none;"; D2.firstChild; )
      D2.removeChild(D2.firstChild);
    for (p2 = " " === M2 && (!G2 || !$2 && !q2), s2 = 0; s2 < z2.length; s2++) {
      for (a2 = z2[s2], f2 = u.createElement(k2), f2.style.cssText = "display:block;text-align:" + H2 + ";position:" + (G2 ? "absolute;" : "relative;"), I2 && (f2.className = I2 + (J2 ? s2 + 1 : "")), j2.push(f2), l2 = a2.length, E2 = 0; E2 < l2; E2++)
        "BR" !== a2[E2].nodeName && (o2 = a2[E2], f2.appendChild(o2), p2 && o2._wordEnd && f2.appendChild(u.createTextNode(" ")), G2 && (0 === E2 && (f2.style.top = o2._y + "px", f2.style.left = m2 + w2 + "px"), o2.style.top = "0px", w2 && (o2.style.left = o2._x - w2 + "px")));
      0 === l2 ? f2.innerHTML = "&nbsp;" : $2 || q2 || (y(f2), c(f2, String.fromCharCode(160), " ")), G2 && (f2.style.width = _2, f2.style.height = o2._h + "px"), D2.appendChild(f2);
    }
    D2.style.cssText = A2;
  }
  G2 && (n2 > D2.clientHeight && (D2.style.height = n2 - L2 + "px", D2.clientHeight < n2 && (D2.style.height = n2 + T2 + "px")), i2 > D2.clientWidth && (D2.style.width = i2 - W2 + "px", D2.clientWidth < i2 && (D2.style.width = i2 + N2 + "px"))), Q2 && (U2 ? D2.style.display = U2 : D2.style.removeProperty("display")), g(t2, V2), $2 && g(F2, R2), g(C2, j2);
};
var w = (e2, t2, F2, C2) => {
  let i2, l2, o2, r2, d2, a2, p2, h2, f2 = t2.tag ? t2.tag : t2.span ? "span" : "div", g2 = ~(t2.type || t2.split || "chars,words,lines").indexOf("chars"), x2 = B(t2), y2 = t2.wordDelimiter || " ", b2 = (D2) => D2 === y2 || D2 === E && " " === y2, _2 = " " !== y2 ? "" : x2 ? "&#173; " : " ", w2 = "</" + f2 + ">", S2 = 1, m2 = t2.specialChars ? "function" == typeof t2.specialChars ? t2.specialChars : A : null, v2 = u.createElement("div"), T2 = e2.parentNode;
  for (T2.insertBefore(v2, e2), v2.textContent = e2.nodeValue, T2.removeChild(e2), i2 = function D2(u2) {
    let e3 = u2.nodeType, t3 = "";
    if (1 === e3 || 9 === e3 || 11 === e3) {
      if ("string" == typeof u2.textContent)
        return u2.textContent;
      for (u2 = u2.firstChild; u2; u2 = u2.nextSibling)
        t3 += D2(u2);
    } else if (3 === e3 || 4 === e3)
      return u2.nodeValue;
    return t3;
  }(e2 = v2), p2 = -1 !== i2.indexOf("<"), false !== t2.reduceWhiteSpace && (i2 = i2.replace(s, " ").replace(n, "")), p2 && (i2 = i2.split("<").join("{{LT}}")), d2 = i2.length, l2 = (" " === i2.charAt(0) ? _2 : "") + F2(), o2 = 0; o2 < d2; o2++)
    if (a2 = i2.charAt(o2), m2 && (h2 = m2(i2.substr(o2), t2.specialChars)))
      a2 = i2.substr(o2, h2 || 1), l2 += g2 && " " !== a2 ? C2() + a2 + "</" + f2 + ">" : a2, o2 += h2 - 1;
    else if (b2(a2) && !b2(i2.charAt(o2 - 1)) && o2) {
      for (l2 += S2 ? w2 : "", S2 = 0; b2(i2.charAt(o2 + 1)); )
        l2 += _2, o2++;
      o2 === d2 - 1 ? l2 += _2 : ")" !== i2.charAt(o2 + 1) && (l2 += _2 + F2(), S2 = 1);
    } else
      "{" === a2 && "{{LT}}" === i2.substr(o2, 6) ? (l2 += g2 ? C2() + "{{LT}}</" + f2 + ">" : "{{LT}}", o2 += 5) : a2.charCodeAt(0) >= 55296 && a2.charCodeAt(0) <= 56319 || i2.charCodeAt(o2 + 1) >= 65024 && i2.charCodeAt(o2 + 1) <= 65039 ? (r2 = ((i2.substr(o2, 12).split(D) || [])[1] || "").length || 2, l2 += g2 && " " !== a2 ? C2() + i2.substr(o2, r2) + "</" + f2 + ">" : i2.substr(o2, r2), o2 += r2 - 1) : l2 += g2 && " " !== a2 ? C2() + a2 + "</" + f2 + ">" : a2;
  e2.outerHTML = l2 + (S2 ? w2 : ""), p2 && c(T2, "{{LT}}", "<");
};
var S$1 = (D2, u2, e2, t2) => {
  let F2, C2, n2 = i(D2.childNodes), s2 = n2.length, E2 = B(u2);
  if (3 !== D2.nodeType || s2 > 1) {
    for (u2.absolute = false, F2 = 0; F2 < s2; F2++)
      C2 = n2[F2], C2._next = C2._isFirst = C2._parent = C2._wordEnd = null, (3 !== C2.nodeType || /\S+/.test(C2.nodeValue)) && (E2 && 3 !== C2.nodeType && "inline" === h(C2).display && (C2.style.display = "inline-block", C2.style.position = "relative"), C2._isSplit = true, S$1(C2, u2, e2, t2));
    return u2.absolute = E2, void (D2._isSplit = true);
  }
  w(D2, u2, e2, t2);
};
var m = class _m {
  constructor(D2, u2) {
    t || l(), this.elements = i(D2), this.chars = [], this.words = [], this.lines = [], this._originals = [], this.vars = u2 || {}, C(this), this.split(u2);
  }
  split(D2) {
    this.isSplit && this.revert(), this.vars = D2 = D2 || this.vars, this._originals.length = this.chars.length = this.words.length = this.lines.length = 0;
    let u2, e2, t2, F2 = this.elements.length, C2 = D2.tag ? D2.tag : D2.span ? "span" : "div", i2 = f(D2.wordsClass, C2), n2 = f(D2.charsClass, C2);
    for (; --F2 > -1; )
      t2 = this.elements[F2], this._originals[F2] = {
        html: t2.innerHTML,
        style: t2.getAttribute("style")
      }, u2 = t2.clientHeight, e2 = t2.clientWidth, S$1(t2, D2, i2, n2), _(t2, D2, this.chars, this.words, this.lines, e2, u2);
    return this.chars.reverse(), this.words.reverse(), this.lines.reverse(), this.isSplit = true, this;
  }
  revert() {
    let D2 = this._originals;
    if (!D2)
      throw "revert() call wasn't scoped properly.";
    return this.elements.forEach(
      (u2, e2) => {
        u2.innerHTML = D2[e2].html, u2.setAttribute("style", D2[e2].style);
      }
    ), this.chars = [], this.words = [], this.lines = [], this.isSplit = false, this;
  }
  static create(D2, u2) {
    return new _m(D2, u2);
  }
};
m.version = "3.12.5", m.register = l;
var SplitText_default = m;
/*! Bundled license information:

gsap/SplitText.js:
  (*!
   * SplitText 3.12.5
   * https://gsap.com
   * 
   * @license Copyright 2024, GreenSock. All rights reserved.
   *)
*/
const gsap_split_text_N75TEmc7ji = /* @__PURE__ */ defineNuxtPlugin(() => {
  return {
    provide: {
      SplitText: SplitText_default
    }
  };
});
const plugins = [
  unhead_KgADcZ0jPj,
  plugin,
  revive_payload_server_eJ33V7gbc6,
  components_plugin_KR1HBZs4kY,
  plugin_IFbScM8fhe,
  gsap_scroll_smoother_QW85FHtwvF,
  gsap_scroll_trigger_Oh1k47CFRg,
  gsap_split_text_N75TEmc7ji
];
const layouts = {
  default: () => import('./default-CRUriWfA.mjs').then((m2) => m2.default || m2),
  "layout-five": () => import('./layout-five-CtI6m1B5.mjs').then((m2) => m2.default || m2),
  "layout-four": () => import('./layout-four-xevi11mH.mjs').then((m2) => m2.default || m2),
  "layout-one": () => import('./layout-one-C2v0b9gV.mjs').then((m2) => m2.default || m2),
  "layout-six": () => import('./layout-six-CbWLduSu.mjs').then((m2) => m2.default || m2),
  "layout-three": () => import('./layout-three-B6KiDLIn.mjs').then((m2) => m2.default || m2),
  "layout-two": () => import('./layout-two-DKZdv8JS.mjs').then((m2) => m2.default || m2),
  panel: () => import('./panel-DjnfSh_6.mjs').then((m2) => m2.default || m2)
};
const LayoutLoader = defineComponent({
  name: "LayoutLoader",
  inheritAttrs: false,
  props: {
    name: String,
    layoutProps: Object
  },
  async setup(props, context) {
    const LayoutComponent = await layouts[props.name]().then((r2) => r2.default || r2);
    return () => h$3(LayoutComponent, props.layoutProps, context.slots);
  }
});
const __nuxt_component_0 = defineComponent({
  name: "NuxtLayout",
  inheritAttrs: false,
  props: {
    name: {
      type: [String, Boolean, Object],
      default: null
    },
    fallback: {
      type: [String, Object],
      default: null
    }
  },
  setup(props, context) {
    const nuxtApp = /* @__PURE__ */ useNuxtApp();
    const injectedRoute = inject(PageRouteSymbol);
    const route = injectedRoute === useRoute() ? useRoute$1() : injectedRoute;
    const layout = computed(() => {
      let layout2 = unref(props.name) ?? route.meta.layout ?? "default";
      if (layout2 && !(layout2 in layouts)) {
        if (props.fallback) {
          layout2 = unref(props.fallback);
        }
      }
      return layout2;
    });
    const layoutRef = ref();
    context.expose({ layoutRef });
    const done = nuxtApp.deferHydration();
    return () => {
      const hasLayout = layout.value && layout.value in layouts;
      const transitionProps = route.meta.layoutTransition ?? appLayoutTransition;
      return _wrapIf(Transition, hasLayout && transitionProps, {
        default: () => h$3(Suspense, { suspensible: true, onResolve: () => {
          nextTick(done);
        } }, {
          default: () => h$3(
            LayoutProvider,
            {
              layoutProps: mergeProps(context.attrs, { ref: layoutRef }),
              key: layout.value || void 0,
              name: layout.value,
              shouldProvide: !props.name,
              hasTransition: !!transitionProps
            },
            context.slots
          )
        })
      }).default();
    };
  }
});
const LayoutProvider = defineComponent({
  name: "NuxtLayoutProvider",
  inheritAttrs: false,
  props: {
    name: {
      type: [String, Boolean]
    },
    layoutProps: {
      type: Object
    },
    hasTransition: {
      type: Boolean
    },
    shouldProvide: {
      type: Boolean
    }
  },
  setup(props, context) {
    const name = props.name;
    if (props.shouldProvide) {
      provide(LayoutMetaSymbol, {
        isCurrent: (route) => name === (route.meta.layout ?? "default")
      });
    }
    return () => {
      var _a, _b;
      if (!name || typeof name === "string" && !(name in layouts)) {
        return (_b = (_a = context.slots).default) == null ? void 0 : _b.call(_a);
      }
      return h$3(
        LayoutLoader,
        { key: name, layoutProps: props.layoutProps, name },
        context.slots
      );
    };
  }
});
const RouteProvider = defineComponent({
  props: {
    vnode: {
      type: Object,
      required: true
    },
    route: {
      type: Object,
      required: true
    },
    vnodeRef: Object,
    renderKey: String,
    trackRootNodes: Boolean
  },
  setup(props) {
    const previousKey = props.renderKey;
    const previousRoute = props.route;
    const route = {};
    for (const key in props.route) {
      Object.defineProperty(route, key, {
        get: () => previousKey === props.renderKey ? props.route[key] : previousRoute[key]
      });
    }
    provide(PageRouteSymbol, shallowReactive(route));
    return () => {
      return h$3(props.vnode, { ref: props.vnodeRef });
    };
  }
});
const __nuxt_component_1 = defineComponent({
  name: "NuxtPage",
  inheritAttrs: false,
  props: {
    name: {
      type: String
    },
    transition: {
      type: [Boolean, Object],
      default: void 0
    },
    keepalive: {
      type: [Boolean, Object],
      default: void 0
    },
    route: {
      type: Object
    },
    pageKey: {
      type: [Function, String],
      default: null
    }
  },
  setup(props, { attrs, expose }) {
    const nuxtApp = /* @__PURE__ */ useNuxtApp();
    const pageRef = ref();
    const forkRoute = inject(PageRouteSymbol, null);
    let previousPageKey;
    expose({ pageRef });
    inject(LayoutMetaSymbol, null);
    let vnode;
    const done = nuxtApp.deferHydration();
    if (props.pageKey) {
      watch(() => props.pageKey, (next, prev) => {
        if (next !== prev) {
          nuxtApp.callHook("page:loading:start");
        }
      });
    }
    return () => {
      return h$3(RouterView, { name: props.name, route: props.route, ...attrs }, {
        default: (routeProps) => {
          if (!routeProps.Component) {
            done();
            return;
          }
          const key = generateRouteKey$1(routeProps, props.pageKey);
          if (!nuxtApp.isHydrating && !hasChildrenRoutes(forkRoute, routeProps.route, routeProps.Component) && previousPageKey === key) {
            nuxtApp.callHook("page:loading:end");
          }
          previousPageKey = key;
          const hasTransition = !!(props.transition ?? routeProps.route.meta.pageTransition ?? appPageTransition);
          const transitionProps = hasTransition && _mergeTransitionProps([
            props.transition,
            routeProps.route.meta.pageTransition,
            appPageTransition,
            { onAfterLeave: () => {
              nuxtApp.callHook("page:transition:finish", routeProps.Component);
            } }
          ].filter(Boolean));
          const keepaliveConfig = props.keepalive ?? routeProps.route.meta.keepalive ?? appKeepalive;
          vnode = _wrapIf(
            Transition,
            hasTransition && transitionProps,
            wrapInKeepAlive(
              keepaliveConfig,
              h$3(Suspense, {
                suspensible: true,
                onPending: () => nuxtApp.callHook("page:start", routeProps.Component),
                onResolve: () => {
                  nextTick(() => nuxtApp.callHook("page:finish", routeProps.Component).then(() => nuxtApp.callHook("page:loading:end")).finally(done));
                }
              }, {
                default: () => {
                  const providerVNode = h$3(RouteProvider, {
                    key: key || void 0,
                    vnode: routeProps.Component,
                    route: routeProps.route,
                    renderKey: key || void 0,
                    trackRootNodes: hasTransition,
                    vnodeRef: pageRef
                  });
                  return providerVNode;
                }
              })
            )
          ).default();
          return vnode;
        }
      });
    };
  }
});
function _mergeTransitionProps(routeProps) {
  const _props = routeProps.map((prop) => ({
    ...prop,
    onAfterLeave: prop.onAfterLeave ? toArray(prop.onAfterLeave) : void 0
  }));
  return defu(..._props);
}
function hasChildrenRoutes(fork, newRoute, Component) {
  if (!fork) {
    return false;
  }
  const index = newRoute.matched.findIndex((m2) => {
    var _a;
    return ((_a = m2.components) == null ? void 0 : _a.default) === (Component == null ? void 0 : Component.type);
  });
  return index < newRoute.matched.length - 1;
}
function useThemeToggle() {
  const isActive = ref(false);
  const toggleTheme = () => {
    const themeScheme = localStorage.getItem("tp_theme_scheme");
    const themeToggle = (void 0).querySelector(".themepure-theme-toggle");
    if (themeScheme === "tp-theme-dark") {
      tpSetScheme("tp-theme-light");
      themeToggle.classList.remove("dark-active");
      themeToggle.classList.add("light-active");
    } else {
      tpSetScheme("tp-theme-dark");
      themeToggle.classList.remove("light-active");
      themeToggle.classList.add("dark-active");
    }
  };
  const tpSetScheme = (tp_theme) => {
    localStorage.setItem("tp_theme_scheme", tp_theme);
    (void 0).documentElement.setAttribute("tp-theme", tp_theme);
    isActive.value = tp_theme === "tp-theme-dark";
  };
  const tpInitTheme = () => {
    const themeToggle = (void 0).querySelector(".themepure-theme-toggle");
    const themeInput = (void 0).querySelector(".themepure-theme-toggle-input");
    if (localStorage.getItem("tp_theme_scheme") === "tp-theme-light") {
      tpSetScheme("tp-theme-light");
      themeToggle.classList.remove("dark-active");
      themeToggle.classList.add("light-active");
      themeInput.checked = false;
    } else {
      tpSetScheme("tp-theme-dark");
      themeInput.checked = true;
      themeToggle.classList.remove("light-active");
      themeToggle.classList.add("dark-active");
    }
  };
  return {
    isActive,
    toggleTheme,
    tpSetScheme,
    tpInitTheme
  };
}
const _sfc_main$2 = /* @__PURE__ */ defineComponent({
  __name: "app",
  __ssrInlineRender: true,
  setup(__props) {
    useThemeToggle();
    return (_ctx, _push, _parent, _attrs) => {
      const _component_nuxt_layout = __nuxt_component_0;
      const _component_nuxt_page = __nuxt_component_1;
      _push(ssrRenderComponent(_component_nuxt_layout, _attrs, {
        default: withCtx((_2, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(ssrRenderComponent(_component_nuxt_page, null, null, _parent2, _scopeId));
          } else {
            return [
              createVNode(_component_nuxt_page)
            ];
          }
        }),
        _: 1
      }, _parent));
    };
  }
});
const _sfc_setup$2 = _sfc_main$2.setup;
_sfc_main$2.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("app.vue");
  return _sfc_setup$2 ? _sfc_setup$2(props, ctx) : void 0;
};
const _sfc_main$1 = {
  __name: "nuxt-error-page",
  __ssrInlineRender: true,
  props: {
    error: Object
  },
  setup(__props) {
    const props = __props;
    const _error = props.error;
    _error.stack ? _error.stack.split("\n").splice(1).map((line) => {
      const text = line.replace("webpack:/", "").replace(".vue", ".js").trim();
      return {
        text,
        internal: line.includes("node_modules") && !line.includes(".cache") || line.includes("internal") || line.includes("new Promise")
      };
    }).map((i2) => `<span class="stack${i2.internal ? " internal" : ""}">${i2.text}</span>`).join("\n") : "";
    const statusCode = Number(_error.statusCode || 500);
    const is404 = statusCode === 404;
    const statusMessage = _error.statusMessage ?? (is404 ? "Page Not Found" : "Internal Server Error");
    const description = _error.message || _error.toString();
    const stack = void 0;
    const _Error404 = defineAsyncComponent(() => import('./error-404-b3e6ocHj.mjs').then((r2) => r2.default || r2));
    const _Error = defineAsyncComponent(() => import('./error-500-9HYyl8wB.mjs').then((r2) => r2.default || r2));
    const ErrorTemplate = is404 ? _Error404 : _Error;
    return (_ctx, _push, _parent, _attrs) => {
      _push(ssrRenderComponent(unref(ErrorTemplate), mergeProps({ statusCode: unref(statusCode), statusMessage: unref(statusMessage), description: unref(description), stack: unref(stack) }, _attrs), null, _parent));
    };
  }
};
const _sfc_setup$1 = _sfc_main$1.setup;
_sfc_main$1.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("node_modules/nuxt/dist/app/components/nuxt-error-page.vue");
  return _sfc_setup$1 ? _sfc_setup$1(props, ctx) : void 0;
};
const ErrorComponent = _sfc_main$1;
const _sfc_main = {
  __name: "nuxt-root",
  __ssrInlineRender: true,
  setup(__props) {
    const IslandRenderer = () => null;
    const nuxtApp = /* @__PURE__ */ useNuxtApp();
    nuxtApp.deferHydration();
    nuxtApp.ssrContext.url;
    const SingleRenderer = false;
    provide(PageRouteSymbol, useRoute());
    nuxtApp.hooks.callHookWith((hooks) => hooks.map((hook) => hook()), "vue:setup");
    const error = useError();
    onErrorCaptured((err, target, info) => {
      nuxtApp.hooks.callHook("vue:error", err, target, info).catch((hookError) => console.error("[nuxt] Error in `vue:error` hook", hookError));
      {
        const p2 = nuxtApp.runWithContext(() => showError(err));
        onServerPrefetch(() => p2);
        return false;
      }
    });
    const islandContext = nuxtApp.ssrContext.islandContext;
    return (_ctx, _push, _parent, _attrs) => {
      ssrRenderSuspense(_push, {
        default: () => {
          if (unref(error)) {
            _push(ssrRenderComponent(unref(ErrorComponent), { error: unref(error) }, null, _parent));
          } else if (unref(islandContext)) {
            _push(ssrRenderComponent(unref(IslandRenderer), { context: unref(islandContext) }, null, _parent));
          } else if (unref(SingleRenderer)) {
            ssrRenderVNode(_push, createVNode(resolveDynamicComponent(unref(SingleRenderer)), null, null), _parent);
          } else {
            _push(ssrRenderComponent(unref(_sfc_main$2), null, null, _parent));
          }
        },
        _: 1
      });
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("node_modules/nuxt/dist/app/components/nuxt-root.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
const RootComponent = _sfc_main;
let entry;
{
  entry = async function createNuxtAppServer(ssrContext) {
    const vueApp = createApp(RootComponent);
    const nuxt = createNuxtApp({ vueApp, ssrContext });
    try {
      await applyPlugins(nuxt, plugins);
      await nuxt.hooks.callHook("app:created", vueApp);
    } catch (error) {
      await nuxt.hooks.callHook("app:error", error);
      nuxt.payload.error = nuxt.payload.error || createError(error);
    }
    if (ssrContext == null ? void 0 : ssrContext._renderResponse) {
      throw new Error("skipping render");
    }
    return vueApp;
  };
}
const entry$1 = (ssrContext) => entry(ssrContext);

const server = /*#__PURE__*/Object.freeze({
  __proto__: null,
  _: __nuxt_component_0,
  a: useRouter,
  b: useRuntimeConfig,
  c: navigateTo,
  d: useSeoMeta,
  default: entry$1,
  e: useRoute,
  f: useNuxtApp,
  g: asyncDataDefaults,
  h: createError,
  i: fetchDefaults,
  j: useThemeToggle,
  k: defineNuxtRouteMiddleware,
  n: nuxtLinkDefaults,
  p: publicAssetsURL,
  s: setInterval,
  u: useHead
});

export { position as A, isDeepEqual as B, noop as C, isRuntimeSsrPreHydration as D, tabsKey as E, emptyRenderFn as F, defineNuxtRouteMiddleware as G, History as H, layoutKey as I, pageContainerKey as J, Plugin$1 as K, defaultLang as L, isObject as M, server as N, Platform as P, __nuxt_component_0 as _, useQuasar as a, useRouter as b, useHead as c, useRoute as d, nuxtLinkDefaults as e, useRuntimeConfig as f, fetchDefaults as g, asyncDataDefaults as h, useNuxtApp as i, createError as j, useThemeToggle as k, createComponent as l, stopAndPrevent as m, navigateTo as n, prevent as o, publicAssetsURL as p, stop as q, listenOpts as r, setInterval as s, createDirective as t, useSeoMeta as u, client as v, getEventPath as w, formKey as x, addEvt as y, cleanEvt as z };
//# sourceMappingURL=server.mjs.map
